/*******************************************************************************
* Flashing LED example for STM32L-Discovery board (STM32L152RBT6)
* B.Arenfeld, b.arenfeld <AT> arcor.de 
*******************************************************************************/

        .thumb
        .syntax unified
        .cpu cortex-m3
        // .fpu softvfp

        /* Processor specific defines */
        .include "stm32l1xx-md.s"				// Only defines. No program code inside ...

        /* Other variable processor defines */
        .equ SRAM_SIZE,   0x00004000				// STM32L152RBT6: 128k Flash, 16k SRAM
        .equ STACKINIT,   (SRAM_BASE+SRAM_SIZE)			// SP at top of SRAM (+1)

        /* Other defines */
        .equ LEDDELAY,    400000

.section .text							// Switch to program memory

        // .org	FLASH_BASE					// Base of flash (0x08000000) is set in linker script ...
        .org	0

/******************************************************************************/
/*           Interrupt vector table. Must be the first in flash memory ...    */
/******************************************************************************/

        // .include "stm32l1xx-md-ivt.s" Full version with complete vector table

        // Minimum version. Only stackpointer and Reset-Vector defined
        .word STACKINIT
        .word Reset_Handler	// Ensure, that Reset_Handler is defined as .thumb_func to set Bit 0 to 1 (thumb instruction set)

/******************************************************************************/
/*           Reset-Function.                                                  */
/******************************************************************************/

.thumb_func			// Needed to set bit 0 in interrupt vector table
Reset_Handler:

        /* Enable the GPIOs Clock */
        ldr	r3, = RCC_BASE					// r3 = RCC_BASE
        // ldr	r1, [r3, RCC_AHBENR_OFFSET]			// r1 = [RCC_AHBENRCFGR]
        // ldr	r2, = (RCC_AHBENR_GPIOAEN | RCC_AHBENR_GPIOBEN | RCC_AHBENR_GPIOCEN)	// Enable clock for GPIO A,B,C
        // orrs	r2, r1

        ldr	r2, [r3, RCC_AHBENR_OFFSET]			// r2 = (RCC_AHBENRCFGR)
        orr.w	r2, r2,	RCC_AHBENR_GPIOBEN	 		// Enable clock for GPIO B,
        str	r2, [r3, RCC_AHBENR_OFFSET]

        /* Configure GPIOB, pin 6+7 as Push-Pull output, 2MHz (LEDs) */

        // Set GPIOB6 + GPIOB7 to output mode
        ldr	r3, = GPIOB_BASE				// r3 = GPIOB_BASE
        ldr	r2, [r3, GPIO_MODER_OFFSET]			// r2 = [GPIOB_MODER]
        bic.w	r2, r2, GPIO_MODER_MODER6 | GPIO_MODER_MODER7 	// r2 &= ~(GPIO_MODER_MODER6 | GPIO_MODER_MODER7)
        orr.w	r2, r2,	GPIO_MODER_MODER6_0 | GPIO_MODER_MODER7_0 	// r2 &= ~(GPIO_MODER_MODER6_0 | GPIO_MODER_MODER7_0)
        str	r2, [r3, GPIO_MODER_OFFSET]			// [GPIOB_MODER] = r2

        // Set GPIOB6 + GPIOB7 output mode to push-pull
        // ldr	r3, = GPIOB_BASE (see above)			// r3 = GPIOB_BASE
        ldr	r2, [r3, GPIO_OTYPER_OFFSET]			// r2 = [GPIOB_OTYPER]
        bic.w	r2, r2, GPIO_OTYPER_OT_6 | GPIO_OTYPER_OT_7 	// r2 &= ~(GPIO_OTYPER_OT_6 | GPIO_OTYPER_OT_7)
        str	r2, [r3, GPIO_OTYPER_OFFSET]			// [GPIOB_OTYPER] = r2

        // Disable GPIOB6 + GPIOB7 pullup/pulldown
        // ldr	r3, = GPIOB_BASE (see above)			// r3 = GPIOB_BASE
        ldr	r2, [r3, GPIO_PUPDR_OFFSET]			// r2 = [GPIOB_PUPDR]
        bic.w	r2, r2, GPIO_PUPDR_PUPDR6 | GPIO_PUPDR_PUPDR7 	// r2 &= ~(GPIO_PUPDR_PUPDR6 | GPIO_OSPEEDER_PUPDR7)
        str	r2, [r3, GPIO_PUPDR_OFFSET]			// [GPIOB_PUPDR] = r2

        // Set GPIOB6 + GPIOB7 speed to 2MHz
        // ldr	r3, = GPIOB_BASE (see above)			// r3 = GPIOB_BASE
        ldr	r2, [r3, GPIO_OSPEEDR_OFFSET]			// r2 = [GPIOB_OSPEED]
        bic.w	r2, r2, GPIO_OSPEEDR_OSPEEDR6 | GPIO_OSPEEDR_OSPEEDR7 	// r2 &= ~(GPIO_OSPEEDR_OSPEEDR6 | GPIO_OSPEEDR_OSPEEDR7)
        orr.w	r2, r2,	GPIO_OSPEEDR_OSPEEDR6_0 | GPIO_OSPEEDR_OSPEEDR7_0 	// r2 &= ~(GPIO_OSPEEDR_OSPEEDR6_0 | GPIO_OSPEEDR_OSPEEDR7_0)
        str	r2, [r3, GPIO_OSPEEDR_OFFSET]			// [GPIOB_OSPEED] = r2
        // GPIOB6=Blue, GPIOB7=Green LED, low-activ
        ldr	r2, = (GPIO_PIN6_MASK << 16) | GPIO_PIN7_MASK	// Blue LED on, Green LED off (Bit set in high word of BSRR -> Reset)
        ldr	r3, = GPIO_PIN6_MASK | (GPIO_PIN7_MASK << 16)	// Blue LED off, Green LED on (Bit set in low word of BSRR  -> Set)
        ldr	r6, = (GPIOB_BASE+GPIO_BSRR_OFFSET)		// Address of Port B BSRR
loop:	str	r2, [r6]           				
        ldr	r1, = LEDDELAY
delay1:	subs	r1, 1
        bne	delay1
        str	r3, [r6]           				// LED off
        ldr	r1, = LEDDELAY
delay2:	subs	r1, 1
        bne	delay2
        b	loop

