/*******************************************************************************
* Interrupt-Vector table for STM32L15x medium density
* B.Arenfeld, b.arenfeld <AT> arcor.de
* 
* based on : startup_stm32l1xx_md.s from ST 
*
* External defines needed : 
* - Reset_Handler : Start of main program
* - STACKINIT : Stack init value
*
* Optional external defines :
* - Various Interrupt-Handler NMI_Handler, HardFault_Handler, ...
*******************************************************************************/


        .section .text

        /* Interrupt-Vector-Table */
        .word STACKINIT
        .word Reset_Handler		// Ensure, that Reset_Handler is defined as .thumb_func to set Bit 0 to 1 (thumb instruction set)
        .word NMI_Handler		// .thumb_set (see below) set bit 0 automatically
        .word HardFault_Handler
        .word MemManage_Handler
        .word BusFault_Handler
        .word UsageFault_Handler
        .word 0
        .word 0
        .word 0
        .word 0
        .word SVC_Handler
        .word DebugMon_Handler
        .word 0
        .word PendSV_Handler
        .word SysTick_Handler
        .word WWDG_IRQHandler
        .word PVD_IRQHandler
        .word TAMPER_STAMP_IRQHandler
        .word RTC_WKUP_IRQHandler
        .word FLASH_IRQHandler
        .word RCC_IRQHandler
        .word EXTI0_IRQHandler
        .word EXTI1_IRQHandler
        .word EXTI2_IRQHandler
        .word EXTI3_IRQHandler
        .word EXTI4_IRQHandler
        .word DMA1_Channel1_IRQHandler
        .word DMA1_Channel2_IRQHandler
        .word DMA1_Channel3_IRQHandler
        .word DMA1_Channel4_IRQHandler
        .word DMA1_Channel5_IRQHandler
        .word DMA1_Channel6_IRQHandler
        .word DMA1_Channel7_IRQHandler
        .word ADC1_IRQHandler
        .word USB_HP_IRQHandler
        .word USB_LP_IRQHandler
        .word DAC_IRQHandler
        .word COMP_IRQHandler
        .word EXTI9_5_IRQHandler
        .word LCD_IRQHandler
        .word TIM9_IRQHandler
        .word TIM10_IRQHandler
        .word TIM11_IRQHandler
        .word TIM2_IRQHandler
        .word TIM3_IRQHandler
        .word TIM4_IRQHandler
        .word I2C1_EV_IRQHandler
        .word I2C1_ER_IRQHandler
        .word I2C2_EV_IRQHandler
        .word I2C2_ER_IRQHandler
        .word SPI1_IRQHandler
        .word SPI2_IRQHandler
        .word USART1_IRQHandler
        .word USART2_IRQHandler
        .word USART3_IRQHandler
        .word EXTI15_10_IRQHandler
        .word RTC_Alarm_IRQHandler
        .word USB_FS_WKUP_IRQHandler
        .word TIM6_IRQHandler
        .word TIM7_IRQHandler
        .word 0
        .word 0
        .word 0
        .word 0
        .word 0
        .word BootRAM 		         	/* @0x108. This is for boot in RAM mode for STM32L15x ULtra Low Power Medium-density devices. */

        .equ  BootRAM, 0xF108F85F		/* Startaddresse for RAM-Boot on STM32L15x. I don't know what's this for ... no documentation found ?? */

/*******************************************************************************
* Endless loop for non used interrupts
*******************************************************************************/
Default_Handler:
Infinite_Loop:
        b Infinite_Loop			// Never ending story ...

/*******************************************************************************
* Provide weak aliases for each Exception handler to the Default_Handler. 
* As they are weak aliases, any function with the same name will override 
* this definition.
*******************************************************************************/

        .weak NMI_Handler
        .thumb_set NMI_Handler,Default_Handler

        .weak HardFault_Handler
        .thumb_set HardFault_Handler,Default_Handler

        .weak MemManage_Handler
        .thumb_set MemManage_Handler,Default_Handler

        .weak BusFault_Handler
        .thumb_set BusFault_Handler,Default_Handler

        .weak UsageFault_Handler
        .thumb_set UsageFault_Handler,Default_Handler

        .weak SVC_Handler
        .thumb_set SVC_Handler,Default_Handler

        .weak DebugMon_Handler
        .thumb_set DebugMon_Handler,Default_Handler

        .weak PendSV_Handler
        .thumb_set PendSV_Handler,Default_Handler

        .weak SysTick_Handler
        .thumb_set SysTick_Handler,Default_Handler

        .weak WWDG_IRQHandler
        .thumb_set WWDG_IRQHandler,Default_Handler

        .weak PVD_IRQHandler
        .thumb_set PVD_IRQHandler,Default_Handler

        .weak TAMPER_STAMP_IRQHandler
        .thumb_set TAMPER_STAMP_IRQHandler,Default_Handler

        .weak RTC_WKUP_IRQHandler
        .thumb_set RTC_WKUP_IRQHandler,Default_Handler

        .weak FLASH_IRQHandler
        .thumb_set FLASH_IRQHandler,Default_Handler

        .weak RCC_IRQHandler
        .thumb_set RCC_IRQHandler,Default_Handler

        .weak EXTI0_IRQHandler
        .thumb_set EXTI0_IRQHandler,Default_Handler

        .weak EXTI1_IRQHandler
        .thumb_set EXTI1_IRQHandler,Default_Handler

        .weak EXTI2_IRQHandler
        .thumb_set EXTI2_IRQHandler,Default_Handler

        .weak EXTI3_IRQHandler
        .thumb_set EXTI3_IRQHandler,Default_Handler

        .weak EXTI4_IRQHandler
        .thumb_set EXTI4_IRQHandler,Default_Handler

        .weak DMA1_Channel1_IRQHandler
        .thumb_set DMA1_Channel1_IRQHandler,Default_Handler

        .weak DMA1_Channel2_IRQHandler
        .thumb_set DMA1_Channel2_IRQHandler,Default_Handler

        .weak DMA1_Channel3_IRQHandler
        .thumb_set DMA1_Channel3_IRQHandler,Default_Handler

        .weak DMA1_Channel4_IRQHandler
        .thumb_set DMA1_Channel4_IRQHandler,Default_Handler

        .weak DMA1_Channel5_IRQHandler
        .thumb_set DMA1_Channel5_IRQHandler,Default_Handler

        .weak DMA1_Channel6_IRQHandler
        .thumb_set DMA1_Channel6_IRQHandler,Default_Handler

        .weak DMA1_Channel7_IRQHandler
        .thumb_set DMA1_Channel7_IRQHandler,Default_Handler

        .weak ADC1_IRQHandler
        .thumb_set ADC1_IRQHandler,Default_Handler

        .weak USB_HP_IRQHandler
        .thumb_set USB_HP_IRQHandler,Default_Handler

        .weak USB_LP_IRQHandler
        .thumb_set USB_LP_IRQHandler,Default_Handler

        .weak DAC_IRQHandler
        .thumb_set DAC_IRQHandler,Default_Handler

        .weak COMP_IRQHandler
        .thumb_set COMP_IRQHandler,Default_Handler

        .weak EXTI9_5_IRQHandler
        .thumb_set EXTI9_5_IRQHandler,Default_Handler

        .weak LCD_IRQHandler
        .thumb_set LCD_IRQHandler,Default_Handler

        .weak TIM9_IRQHandler
        .thumb_set TIM9_IRQHandler,Default_Handler

        .weak TIM10_IRQHandler
        .thumb_set TIM10_IRQHandler,Default_Handler

        .weak TIM11_IRQHandler
        .thumb_set TIM11_IRQHandler,Default_Handler

        .weak TIM2_IRQHandler
        .thumb_set TIM2_IRQHandler,Default_Handler

        .weak TIM3_IRQHandler
        .thumb_set TIM3_IRQHandler,Default_Handler

        .weak TIM4_IRQHandler
        .thumb_set TIM4_IRQHandler,Default_Handler

        .weak I2C1_EV_IRQHandler
        .thumb_set I2C1_EV_IRQHandler,Default_Handler

        .weak I2C1_ER_IRQHandler
        .thumb_set I2C1_ER_IRQHandler,Default_Handler

        .weak I2C2_EV_IRQHandler
        .thumb_set I2C2_EV_IRQHandler,Default_Handler

        .weak I2C2_ER_IRQHandler
        .thumb_set I2C2_ER_IRQHandler,Default_Handler

        .weak SPI1_IRQHandler
        .thumb_set SPI1_IRQHandler,Default_Handler

        .weak SPI2_IRQHandler
        .thumb_set SPI2_IRQHandler,Default_Handler

        .weak USART1_IRQHandler
        .thumb_set USART1_IRQHandler,Default_Handler

        .weak USART2_IRQHandler
        .thumb_set USART2_IRQHandler,Default_Handler

        .weak USART3_IRQHandler
        .thumb_set USART3_IRQHandler,Default_Handler

        .weak EXTI15_10_IRQHandler
        .thumb_set EXTI15_10_IRQHandler,Default_Handler

        .weak RTC_Alarm_IRQHandler
        .thumb_set RTC_Alarm_IRQHandler,Default_Handler

        .weak USB_FS_WKUP_IRQHandler
        .thumb_set USB_FS_WKUP_IRQHandler,Default_Handler

        .weak TIM6_IRQHandler
        .thumb_set TIM6_IRQHandler,Default_Handler

        .weak TIM7_IRQHandler
        .thumb_set TIM7_IRQHandler,Default_Handler


