/*******************************************************************************
* Definitions for STM32L15x
* This file contains all the peripheral register's definitions, bits 
* definitions and memory mapping for STM32L1xx devices.  
* B.Arenfeld, b.arenfeld <AT> arcor.de
* Some Register offset definitions missing ... Search for 'TypeDef' to find them 
* based on : stm32l1xx.h, V1.0.0 from ST 
*******************************************************************************/

.ifndef STM32L1XX_MD_S
        .equ	STM32L1XX_MD_S, 1

/******************************************************************************/
/*                        Memory map                                          */
/******************************************************************************/

        .equ	FLASH_BASE,           0x08000000	/* FLASH base address in the alias region */
        .equ	SRAM_BASE,            0x20000000	/* SRAM base address in the alias region */
        .equ	PERIPH_BASE,          0x40000000	/* Peripheral base address in the alias region */

        .equ	SRAM_BB_BASE,         0x22000000	/* SRAM base address in the bit-band region */
        .equ	PERIPH_BB_BASE,       0x42000000	/* Peripheral base address in the bit-band region */


/******************************************************************************/
/*                        Peripheral memory map                               */
/******************************************************************************/

        .equ	APB1PERIPH_BASE,      PERIPH_BASE
        .equ	APB2PERIPH_BASE,      (PERIPH_BASE + 0x10000)
        .equ	AHBPERIPH_BASE,       (PERIPH_BASE + 0x20000)

        .equ	TIM2_BASE,            (APB1PERIPH_BASE + 0x0000)
        .equ	TIM3_BASE,            (APB1PERIPH_BASE + 0x0400)
        .equ	TIM4_BASE,            (APB1PERIPH_BASE + 0x0800)
        .equ	TIM6_BASE,            (APB1PERIPH_BASE + 0x1000)
        .equ	TIM7_BASE,            (APB1PERIPH_BASE + 0x1400)
        .equ	LCD_BASE,             (APB1PERIPH_BASE + 0x2400)
        .equ	RTC_BASE,             (APB1PERIPH_BASE + 0x2800)
        .equ	WWDG_BASE,            (APB1PERIPH_BASE + 0x2C00)
        .equ	IWDG_BASE,            (APB1PERIPH_BASE + 0x3000)
        .equ	SPI2_BASE,            (APB1PERIPH_BASE + 0x3800)
        .equ	USART2_BASE,          (APB1PERIPH_BASE + 0x4400)
        .equ	USART3_BASE,          (APB1PERIPH_BASE + 0x4800)
        .equ	I2C1_BASE,            (APB1PERIPH_BASE + 0x5400)
        .equ	I2C2_BASE,            (APB1PERIPH_BASE + 0x5800)
        .equ	PWR_BASE,             (APB1PERIPH_BASE + 0x7000)
        .equ	DAC_BASE,             (APB1PERIPH_BASE + 0x7400)
        .equ	COMP_BASE,            (APB1PERIPH_BASE + 0x7C00)
        .equ	RI_BASE,              (APB1PERIPH_BASE + 0x7C04)

        .equ	SYSCFG_BASE,          (APB2PERIPH_BASE + 0x0000)
        .equ	EXTI_BASE,            (APB2PERIPH_BASE + 0x0400)
        .equ	TIM9_BASE,            (APB2PERIPH_BASE + 0x0800)
        .equ	TIM10_BASE,           (APB2PERIPH_BASE + 0x0C00)
        .equ	TIM11_BASE,           (APB2PERIPH_BASE + 0x1000)
        .equ	ADC1_BASE,            (APB2PERIPH_BASE + 0x2400)
        .equ	ADC_BASE,             (APB2PERIPH_BASE + 0x2700)
        .equ	SPI1_BASE,            (APB2PERIPH_BASE + 0x3000)
        .equ	USART1_BASE,          (APB2PERIPH_BASE + 0x3800)

        .equ	GPIOA_BASE,           (AHBPERIPH_BASE + 0x0000)
        .equ	GPIOB_BASE,           (AHBPERIPH_BASE + 0x0400)
        .equ	GPIOC_BASE,           (AHBPERIPH_BASE + 0x0800)
        .equ	GPIOD_BASE,           (AHBPERIPH_BASE + 0x0C00)
        .equ	GPIOE_BASE,           (AHBPERIPH_BASE + 0x1000)
        .equ	GPIOH_BASE,           (AHBPERIPH_BASE + 0x1400)
        .equ	CRC_BASE,             (AHBPERIPH_BASE + 0x3000)
        .equ	RCC_BASE,             (AHBPERIPH_BASE + 0x3800)


        .equ	FLASH_R_BASE,         (AHBPERIPH_BASE + 0x3C00) /* FLASH registers base address */
        .equ	OB_BASE,              0x1FF80000		/* FLASH Option Bytes base address */

        .equ	DMA1_BASE,            (AHBPERIPH_BASE + 0x6000)
        .equ	DMA1_Channel1_BASE,   (DMA1_BASE + 0x0008)
        .equ	DMA1_Channel2_BASE,   (DMA1_BASE + 0x001C)
        .equ	DMA1_Channel3_BASE,   (DMA1_BASE + 0x0030)
        .equ	DMA1_Channel4_BASE,   (DMA1_BASE + 0x0044)
        .equ	DMA1_Channel5_BASE,   (DMA1_BASE + 0x0058)
        .equ	DMA1_Channel6_BASE,   (DMA1_BASE + 0x006C)
        .equ	DMA1_Channel7_BASE,   (DMA1_BASE + 0x0080)

        .equ	DBGMCU_BASE,          0xE0042000		 /* Debug MCU registers base address */

/******************************************************************************/
/*                         Peripheral Declaration                             */
/*                C-typedefs replaced with register offset equations          */
/******************************************************************************/

        // Reset and Clock Control. Offsets relative to RCC_BASE
        .equ	RCC_CR_OFFSET,		0x00
        .equ	RCC_ICSCR_OFFSET,	0x04
        .equ	RCC_CFGR_OFFSET,	0x08
        .equ	RCC_CIR_OFFSET,		0x0C
        .equ	RCC_AHBRSTR_OFFSET,	0x10
        .equ	RCC_APB2RSTR_OFFSET,	0x14
        .equ	RCC_APB1RSTR_OFFSET,	0x18
        .equ	RCC_AHBENR_OFFSET,	0x1C
        .equ	RCC_APB2ENR_OFFSET,	0x20
        .equ	RCC_APB1ENR_OFFSET,	0x24
        .equ	RCC_AHBLPENR_OFFSET,	0x28
        .equ	RCC_APB2LPENR_OFFSET,	0x2C
        .equ	RCC_APB1LPENR_OFFSET,	0x30
        .equ	RCC_CSR_OFFSET,		0x34    

        // General Purpose IO
        .equ	GPIO_MODER_OFFSET,	0x00
        .equ	GPIO_OTYPER_OFFSET,	0x04
        .equ	GPIO_OSPEEDR_OFFSET,	0x08
        .equ	GPIO_PUPDR_OFFSET,	0x0C
        .equ	GPIO_IDR_OFFSET,	0x10
        .equ	GPIO_ODR_OFFSET,	0x14
        .equ	GPIO_BSRR_OFFSET,	0x18
        //.equ	GPIO_BSRRL_OFFSET,	0x18 	/* BSRR register is split to 2 * 16-bit fields BSRRL */
        //.equ	GPIO_BSRRH_OFFSET,	0x1A 	/* BSRR register is split to 2 * 16-bit fields BSRRH */
        .equ	GPIO_LCKR_OFFSET,	0x1C
        .equ	GPIO_AFRL_OFFSET,	0x20
        .equ	GPIO_AFRH_OFFSET,	0x24

        // Bitmask for 
        .equ	GPIO_PIN0_MASK,		0x0001
        .equ	GPIO_PIN1_MASK,		0x0002
        .equ	GPIO_PIN2_MASK,		0x0004
        .equ	GPIO_PIN3_MASK,		0x0008
        .equ	GPIO_PIN4_MASK,		0x0010
        .equ	GPIO_PIN5_MASK,		0x0020
        .equ	GPIO_PIN6_MASK,		0x0040
        .equ	GPIO_PIN7_MASK,		0x0080
        .equ	GPIO_PIN8_MASK,		0x0100
        .equ	GPIO_PIN9_MASK,		0x0200
        .equ	GPIO_PIN10_MASK,	0x0400
        .equ	GPIO_PIN11_MASK,	0x0800
        .equ	GPIO_PIN12_MASK,	0x1000
        .equ	GPIO_PIN13_MASK,	0x2000
        .equ	GPIO_PIN14_MASK,	0x4000
        .equ	GPIO_PIN15_MASK,	0x8000
        .equ	GPIO_PIN_ALL_MASK,	0xFFFF  /* All pins selected */


.if 0
        TODO : 
        .equ	TIM2,               ((TIM_TypeDef *) TIM2_BASE)
        .equ	TIM3,               ((TIM_TypeDef *) TIM3_BASE)
        .equ	TIM4,               ((TIM_TypeDef *) TIM4_BASE)
        .equ	TIM6,               ((TIM_TypeDef *) TIM6_BASE)
        .equ	TIM7,               ((TIM_TypeDef *) TIM7_BASE)
        .equ	LCD,                ((LCD_TypeDef *) LCD_BASE)
        .equ	RTC,                ((RTC_TypeDef *) RTC_BASE)
        .equ	WWDG,               ((WWDG_TypeDef *) WWDG_BASE)
        .equ	IWDG,               ((IWDG_TypeDef *) IWDG_BASE)
        .equ	SPI2,               ((SPI_TypeDef *) SPI2_BASE)
        .equ	USART2,             ((USART_TypeDef *) USART2_BASE)
        .equ	USART3,             ((USART_TypeDef *) USART3_BASE)
        .equ	I2C1,               ((I2C_TypeDef *) I2C1_BASE)
        .equ	I2C2,               ((I2C_TypeDef *) I2C2_BASE)
        .equ	PWR,                ((PWR_TypeDef *) PWR_BASE)
        .equ	DAC,                ((DAC_TypeDef *) DAC_BASE)
        .equ	COMP,               ((COMP_TypeDef *) COMP_BASE)
        .equ	RI,                 ((RI_TypeDef *) RI_BASE)
        .equ	SYSCFG,             ((SYSCFG_TypeDef *) SYSCFG_BASE)
        .equ	EXTI,               ((EXTI_TypeDef *) EXTI_BASE)

        .equ	ADC1,               ((ADC_TypeDef *) ADC1_BASE)
        .equ	ADC,                ((ADC_Common_TypeDef *) ADC_BASE)
        .equ	TIM9,               ((TIM_TypeDef *) TIM9_BASE)
        .equ	TIM10,              ((TIM_TypeDef *) TIM10_BASE)
        .equ	TIM11,              ((TIM_TypeDef *) TIM11_BASE)
        .equ	SPI1,               ((SPI_TypeDef *) SPI1_BASE)
        .equ	USART1,             ((USART_TypeDef *) USART1_BASE)
        .equ	DMA1,               ((DMA_TypeDef *) DMA1_BASE)
        .equ	DMA1_Channel1,      ((DMA_Channel_TypeDef *) DMA1_Channel1_BASE)
        .equ	DMA1_Channel2,      ((DMA_Channel_TypeDef *) DMA1_Channel2_BASE)
        .equ	DMA1_Channel3,      ((DMA_Channel_TypeDef *) DMA1_Channel3_BASE)
        .equ	DMA1_Channel4,      ((DMA_Channel_TypeDef *) DMA1_Channel4_BASE)
        .equ	DMA1_Channel5,      ((DMA_Channel_TypeDef *) DMA1_Channel5_BASE)
        .equ	DMA1_Channel6,      ((DMA_Channel_TypeDef *) DMA1_Channel6_BASE)
        .equ	DMA1_Channel7,      ((DMA_Channel_TypeDef *) DMA1_Channel7_BASE)
        .equ	CRC,                ((CRC_TypeDef *) CRC_BASE)

        .equ	FLASH,              ((FLASH_TypeDef *) FLASH_R_BASE)
        .equ	OB,                 ((OB_TypeDef *) OB_BASE) 

        .equ	DBGMCU,             ((DBGMCU_TypeDef *) DBGMCU_BASE)
.endif	// if 0
        





/******************************************************************************/
/*                         Peripheral Registers Bits Definition               */
/******************************************************************************/
/******************************************************************************/
/*                                                                            */
/*                      Analog to Digital Converter (ADC)                     */
/*                                                                            */
/******************************************************************************/

/********************  Bit definition for ADC_SR register  ********************/
        .equ	 ADC_SR_AWD,                         0x00000001	    /* Analog watchdog flag */
        .equ	 ADC_SR_EOC,                         0x00000002	    /* End of conversion */
        .equ	 ADC_SR_JEOC,                        0x00000004	    /* Injected channel end of conversion */
        .equ	 ADC_SR_JSTRT,                       0x00000008	    /* Injected channel Start flag */
        .equ	 ADC_SR_STRT,                        0x00000010	    /* Regular channel Start flag */
        .equ	 ADC_SR_OVR,                         0x00000020	    /* Overrun flag */
        .equ	 ADC_SR_ADONS,                       0x00000040	    /* ADC ON status */
        .equ	 ADC_SR_RCNR,                        0x00000100	    /* Regular channel not ready flag */
        .equ	 ADC_SR_JCNR,                        0x00000200	    /* Injected channel not ready flag */

/*******************  Bit definition for ADC_CR1 register  ********************/
        .equ	 ADC_CR1_AWDCH,                      0x0000001F	    /* AWDCH[4:0] bits (Analog watchdog channel select bits) */
        .equ	 ADC_CR1_AWDCH_0,                    0x00000001	    /* Bit 0 */
        .equ	 ADC_CR1_AWDCH_1,                    0x00000002	    /* Bit 1 */
        .equ	 ADC_CR1_AWDCH_2,                    0x00000004	    /* Bit 2 */
        .equ	 ADC_CR1_AWDCH_3,                    0x00000008	    /* Bit 3 */
        .equ	 ADC_CR1_AWDCH_4,                    0x00000010	    /* Bit 4 */

        .equ	 ADC_CR1_EOCIE,                      0x00000020	    /* Interrupt enable for EOC */
        .equ	 ADC_CR1_AWDIE,                      0x00000040	    /* Analog Watchdog interrupt enable */
        .equ	 ADC_CR1_JEOCIE,                     0x00000080	    /* Interrupt enable for injected channels */
        .equ	 ADC_CR1_SCAN,                       0x00000100	    /* Scan mode */
        .equ	 ADC_CR1_AWDSGL,                     0x00000200	    /* Enable the watchdog on a single channel in scan mode */
        .equ	 ADC_CR1_JAUTO,                      0x00000400	    /* Automatic injected group conversion */
        .equ	 ADC_CR1_DISCEN,                     0x00000800	    /* Discontinuous mode on regular channels */
        .equ	 ADC_CR1_JDISCEN,                    0x00001000	    /* Discontinuous mode on injected channels */

        .equ	 ADC_CR1_DISCNUM,                    0x0000E000	    /* DISCNUM[2:0] bits (Discontinuous mode channel count) */
        .equ	 ADC_CR1_DISCNUM_0,                  0x00002000	    /* Bit 0 */
        .equ	 ADC_CR1_DISCNUM_1,                  0x00004000	    /* Bit 1 */
        .equ	 ADC_CR1_DISCNUM_2,                  0x00008000	    /* Bit 2 */

        .equ	 ADC_CR1_PDD,                        0x00010000	    /* Power Down during Delay phase */
        .equ	 ADC_CR1_PDI,                        0x00020000	    /* Power Down during Idle phase */

        .equ	 ADC_CR1_JAWDEN,                     0x00400000	    /* Analog watchdog enable on injected channels */
        .equ	 ADC_CR1_AWDEN,                      0x00800000	    /* Analog watchdog enable on regular channels */

        .equ	 ADC_CR1_RES,                        0x03000000	    /* RES[1:0] bits (Resolution) */
        .equ	 ADC_CR1_RES_0,                      0x01000000	    /* Bit 0 */
        .equ	 ADC_CR1_RES_1,                      0x02000000	    /* Bit 1 */

        .equ	 ADC_CR1_OVRIE,                      0x04000000	    /* Overrun interrupt enable */
  
/*******************  Bit definition for ADC_CR2 register  ********************/
        .equ	 ADC_CR2_ADON,                       0x00000001	    /* A/D Converter ON / OFF */
        .equ	 ADC_CR2_CONT,                       0x00000002	    /* Continuous Conversion */

        .equ	 ADC_CR2_DELS,                       0x00000070	    /* DELS[2:0] bits (Delay selection) */
        .equ	 ADC_CR2_DELS_0,                     0x00000010	    /* Bit 0 */
        .equ	 ADC_CR2_DELS_1,                     0x00000020	    /* Bit 1 */
        .equ	 ADC_CR2_DELS_2,                     0x00000040	    /* Bit 2 */

        .equ	 ADC_CR2_DMA,                        0x00000100	    /* Direct Memory access mode */
        .equ	 ADC_CR2_DDS,                        0x00000200	    /* DMA disable selection (Single ADC) */
        .equ	 ADC_CR2_EOCS,                       0x00000400	    /* End of conversion selection */
        .equ	 ADC_CR2_ALIGN,                      0x00000800	    /* Data Alignment */

        .equ	 ADC_CR2_JEXTSEL,                    0x000F0000	    /* JEXTSEL[3:0] bits (External event select for injected group) */
        .equ	 ADC_CR2_JEXTSEL_0,                  0x00010000	    /* Bit 0 */
        .equ	 ADC_CR2_JEXTSEL_1,                  0x00020000	    /* Bit 1 */
        .equ	 ADC_CR2_JEXTSEL_2,                  0x00040000	    /* Bit 2 */
        .equ	 ADC_CR2_JEXTSEL_3,                  0x00080000	    /* Bit 3 */

        .equ	 ADC_CR2_JEXTEN,                     0x00300000	    /* JEXTEN[1:0] bits (External Trigger Conversion mode for injected channels) */
        .equ	 ADC_CR2_JEXTEN_0,                   0x00100000	    /* Bit 0 */
        .equ	 ADC_CR2_JEXTEN_1,                   0x00200000	    /* Bit 1 */

        .equ	 ADC_CR2_JSWSTART,                   0x00400000	    /* Start Conversion of injected channels */

        .equ	 ADC_CR2_EXTSEL,                     0x0F000000	    /* EXTSEL[3:0] bits (External Event Select for regular group) */
        .equ	 ADC_CR2_EXTSEL_0,                   0x01000000	    /* Bit 0 */
        .equ	 ADC_CR2_EXTSEL_1,                   0x02000000	    /* Bit 1 */
        .equ	 ADC_CR2_EXTSEL_2,                   0x04000000	    /* Bit 2 */
        .equ	 ADC_CR2_EXTSEL_3,                   0x08000000	    /* Bit 3 */

        .equ	 ADC_CR2_EXTEN,                      0x30000000	    /* EXTEN[1:0] bits (External Trigger Conversion mode for regular channels) */
        .equ	 ADC_CR2_EXTEN_0,                    0x10000000	    /* Bit 0 */
        .equ	 ADC_CR2_EXTEN_1,                    0x20000000	    /* Bit 1 */

        .equ	 ADC_CR2_SWSTART,                    0x40000000	    /* Start Conversion of regular channels */

/******************  Bit definition for ADC_SMPR1 register  *******************/
        .equ	 ADC_SMPR1_SMP20,                    0x00000007	    /* SMP20[2:0] bits (Channel 20 Sample time selection) */
        .equ	 ADC_SMPR1_SMP20_0,                  0x00000001	    /* Bit 0 */
        .equ	 ADC_SMPR1_SMP20_1,                  0x00000002	    /* Bit 1 */
        .equ	 ADC_SMPR1_SMP20_2,                  0x00000004	    /* Bit 2 */

        .equ	 ADC_SMPR1_SMP21,                    0x00000038	    /* SMP21[2:0] bits (Channel 21 Sample time selection) */
        .equ	 ADC_SMPR1_SMP21_0,                  0x00000008	    /* Bit 0 */
        .equ	 ADC_SMPR1_SMP21_1,                  0x00000010	    /* Bit 1 */
        .equ	 ADC_SMPR1_SMP21_2,                  0x00000020	    /* Bit 2 */

        .equ	 ADC_SMPR1_SMP22,                    0x000001C0	    /* SMP22[2:0] bits (Channel 22 Sample time selection) */
        .equ	 ADC_SMPR1_SMP22_0,                  0x00000040	    /* Bit 0 */
        .equ	 ADC_SMPR1_SMP22_1,                  0x00000080	    /* Bit 1 */
        .equ	 ADC_SMPR1_SMP22_2,                  0x00000100	    /* Bit 2 */

        .equ	 ADC_SMPR1_SMP23,                    0x00000E00	    /* SMP23[2:0] bits (Channel 23 Sample time selection) */
        .equ	 ADC_SMPR1_SMP23_0,                  0x00000200	    /* Bit 0 */
        .equ	 ADC_SMPR1_SMP23_1,                  0x00000400	    /* Bit 1 */
        .equ	 ADC_SMPR1_SMP23_2,                  0x00000800	    /* Bit 2 */

        .equ	 ADC_SMPR1_SMP24,                    0x00007000	    /* SMP24[2:0] bits (Channel 24 Sample time selection) */
        .equ	 ADC_SMPR1_SMP24_0,                  0x00001000	    /* Bit 0 */
        .equ	 ADC_SMPR1_SMP24_1,                  0x00002000	    /* Bit 1 */
        .equ	 ADC_SMPR1_SMP24_2,                  0x00004000	    /* Bit 2 */

        .equ	 ADC_SMPR1_SMP25,                    0x00038000	    /* SMP25[2:0] bits (Channel 25 Sample time selection) */
        .equ	 ADC_SMPR1_SMP25_0,                  0x00008000	    /* Bit 0 */
        .equ	 ADC_SMPR1_SMP25_1,                  0x00010000	    /* Bit 1 */
        .equ	 ADC_SMPR1_SMP25_2,                  0x00020000	    /* Bit 2 */

/******************  Bit definition for ADC_SMPR2 register  *******************/
        .equ	 ADC_SMPR2_SMP10,                    0x00000007	    /* SMP10[2:0] bits (Channel 10 Sample time selection) */
        .equ	 ADC_SMPR2_SMP10_0,                  0x00000001	    /* Bit 0 */
        .equ	 ADC_SMPR2_SMP10_1,                  0x00000002	    /* Bit 1 */
        .equ	 ADC_SMPR2_SMP10_2,                  0x00000004	    /* Bit 2 */

        .equ	 ADC_SMPR2_SMP11,                    0x00000038	    /* SMP11[2:0] bits (Channel 11 Sample time selection) */
        .equ	 ADC_SMPR2_SMP11_0,                  0x00000008	    /* Bit 0 */
        .equ	 ADC_SMPR2_SMP11_1,                  0x00000010	    /* Bit 1 */
        .equ	 ADC_SMPR2_SMP11_2,                  0x00000020	    /* Bit 2 */

        .equ	 ADC_SMPR2_SMP12,                    0x000001C0	    /* SMP12[2:0] bits (Channel 12 Sample time selection) */
        .equ	 ADC_SMPR2_SMP12_0,                  0x00000040	    /* Bit 0 */
        .equ	 ADC_SMPR2_SMP12_1,                  0x00000080	    /* Bit 1 */
        .equ	 ADC_SMPR2_SMP12_2,                  0x00000100	    /* Bit 2 */

        .equ	 ADC_SMPR2_SMP13,                    0x00000E00	    /* SMP13[2:0] bits (Channel 13 Sample time selection) */
        .equ	 ADC_SMPR2_SMP13_0,                  0x00000200	    /* Bit 0 */
        .equ	 ADC_SMPR2_SMP13_1,                  0x00000400	    /* Bit 1 */
        .equ	 ADC_SMPR2_SMP13_2,                  0x00000800	    /* Bit 2 */

        .equ	 ADC_SMPR2_SMP14,                    0x00007000	    /* SMP14[2:0] bits (Channel 14 Sample time selection) */
        .equ	 ADC_SMPR2_SMP14_0,                  0x00001000	    /* Bit 0 */
        .equ	 ADC_SMPR2_SMP14_1,                  0x00002000	    /* Bit 1 */
        .equ	 ADC_SMPR2_SMP14_2,                  0x00004000	    /* Bit 2 */

        .equ	 ADC_SMPR2_SMP15,                    0x00038000	    /* SMP15[2:0] bits (Channel 5 Sample time selection) */
        .equ	 ADC_SMPR2_SMP15_0,                  0x00008000	    /* Bit 0 */
        .equ	 ADC_SMPR2_SMP15_1,                  0x00010000	    /* Bit 1 */
        .equ	 ADC_SMPR2_SMP15_2,                  0x00020000	    /* Bit 2 */

        .equ	 ADC_SMPR2_SMP16,                    0x001C0000	    /* SMP16[2:0] bits (Channel 16 Sample time selection) */
        .equ	 ADC_SMPR2_SMP16_0,                  0x00040000	    /* Bit 0 */
        .equ	 ADC_SMPR2_SMP16_1,                  0x00080000	    /* Bit 1 */
        .equ	 ADC_SMPR2_SMP16_2,                  0x00100000	    /* Bit 2 */

        .equ	 ADC_SMPR2_SMP17,                    0x00E00000	    /* SMP17[2:0] bits (Channel 17 Sample time selection) */
        .equ	 ADC_SMPR2_SMP17_0,                  0x00200000	    /* Bit 0 */
        .equ	 ADC_SMPR2_SMP17_1,                  0x00400000	    /* Bit 1 */
        .equ	 ADC_SMPR2_SMP17_2,                  0x00800000	    /* Bit 2 */

        .equ	 ADC_SMPR2_SMP18,                    0x07000000	    /* SMP18[2:0] bits (Channel 18 Sample time selection) */
        .equ	 ADC_SMPR2_SMP18_0,                  0x01000000	    /* Bit 0 */
        .equ	 ADC_SMPR2_SMP18_1,                  0x02000000	    /* Bit 1 */
        .equ	 ADC_SMPR2_SMP18_2,                  0x04000000	    /* Bit 2 */

        .equ	 ADC_SMPR2_SMP19,                    0x38000000	    /* SMP19[2:0] bits (Channel 19 Sample time selection) */
        .equ	 ADC_SMPR2_SMP19_0,                  0x08000000	    /* Bit 0 */
        .equ	 ADC_SMPR2_SMP19_1,                  0x10000000	    /* Bit 1 */
        .equ	 ADC_SMPR2_SMP19_2,                  0x20000000	    /* Bit 2 */

/******************  Bit definition for ADC_SMPR3 register  *******************/
        .equ	 ADC_SMPR3_SMP0,                     0x00000007	    /* SMP0[2:0] bits (Channel 0 Sample time selection) */
        .equ	 ADC_SMPR3_SMP0_0,                   0x00000001	    /* Bit 0 */
        .equ	 ADC_SMPR3_SMP0_1,                   0x00000002	    /* Bit 1 */
        .equ	 ADC_SMPR3_SMP0_2,                   0x00000004	    /* Bit 2 */
 
        .equ	 ADC_SMPR3_SMP1,                     0x00000038	    /* SMP1[2:0] bits (Channel 1 Sample time selection) */
        .equ	 ADC_SMPR3_SMP1_0,                   0x00000008	    /* Bit 0 */
        .equ	 ADC_SMPR3_SMP1_1,                   0x00000010	    /* Bit 1 */
        .equ	 ADC_SMPR3_SMP1_2,                   0x00000020	    /* Bit 2 */

        .equ	 ADC_SMPR3_SMP2,                     0x000001C0	    /* SMP2[2:0] bits (Channel 2 Sample time selection) */
        .equ	 ADC_SMPR3_SMP2_0,                   0x00000040	    /* Bit 0 */
        .equ	 ADC_SMPR3_SMP2_1,                   0x00000080	    /* Bit 1 */
        .equ	 ADC_SMPR3_SMP2_2,                   0x00000100	    /* Bit 2 */

        .equ	 ADC_SMPR3_SMP3,                     0x00000E00	    /* SMP3[2:0] bits (Channel 3 Sample time selection) */
        .equ	 ADC_SMPR3_SMP3_0,                   0x00000200	    /* Bit 0 */
        .equ	 ADC_SMPR3_SMP3_1,                   0x00000400	    /* Bit 1 */
        .equ	 ADC_SMPR3_SMP3_2,                   0x00000800	    /* Bit 2 */

        .equ	 ADC_SMPR3_SMP4,                     0x00007000	    /* SMP4[2:0] bits (Channel 4 Sample time selection) */
        .equ	 ADC_SMPR3_SMP4_0,                   0x00001000	    /* Bit 0 */
        .equ	 ADC_SMPR3_SMP4_1,                   0x00002000	    /* Bit 1 */
        .equ	 ADC_SMPR3_SMP4_2,                   0x00004000	    /* Bit 2 */

        .equ	 ADC_SMPR3_SMP5,                     0x00038000	    /* SMP5[2:0] bits (Channel 5 Sample time selection) */
        .equ	 ADC_SMPR3_SMP5_0,                   0x00008000	    /* Bit 0 */
        .equ	 ADC_SMPR3_SMP5_1,                   0x00010000	    /* Bit 1 */
        .equ	 ADC_SMPR3_SMP5_2,                   0x00020000	    /* Bit 2 */

        .equ	 ADC_SMPR3_SMP6,                     0x001C0000	    /* SMP6[2:0] bits (Channel 6 Sample time selection) */
        .equ	 ADC_SMPR3_SMP6_0,                   0x00040000	    /* Bit 0 */
        .equ	 ADC_SMPR3_SMP6_1,                   0x00080000	    /* Bit 1 */
        .equ	 ADC_SMPR3_SMP6_2,                   0x00100000	    /* Bit 2 */

        .equ	 ADC_SMPR3_SMP7,                     0x00E00000	    /* SMP7[2:0] bits (Channel 7 Sample time selection) */
        .equ	 ADC_SMPR3_SMP7_0,                   0x00200000	    /* Bit 0 */
        .equ	 ADC_SMPR3_SMP7_1,                   0x00400000	    /* Bit 1 */
        .equ	 ADC_SMPR3_SMP7_2,                   0x00800000	    /* Bit 2 */

        .equ	 ADC_SMPR3_SMP8,                     0x07000000	    /* SMP8[2:0] bits (Channel 8 Sample time selection) */
        .equ	 ADC_SMPR3_SMP8_0,                   0x01000000	    /* Bit 0 */
        .equ	 ADC_SMPR3_SMP8_1,                   0x02000000	    /* Bit 1 */
        .equ	 ADC_SMPR3_SMP8_2,                   0x04000000	    /* Bit 2 */

        .equ	 ADC_SMPR3_SMP9,                     0x38000000	    /* SMP9[2:0] bits (Channel 9 Sample time selection) */
        .equ	 ADC_SMPR3_SMP9_0,                   0x08000000	    /* Bit 0 */
        .equ	 ADC_SMPR3_SMP9_1,                   0x10000000	    /* Bit 1 */
        .equ	 ADC_SMPR3_SMP9_2,                   0x20000000	    /* Bit 2 */


/******************  Bit definition for ADC_JOFR1 register  *******************/
        .equ	 ADC_JOFR1_JOFFSET1,                 0x00000FFF	    /* Data offset for injected channel 1 */

/******************  Bit definition for ADC_JOFR2 register  *******************/
        .equ	 ADC_JOFR2_JOFFSET2,                 0x00000FFF	    /* Data offset for injected channel 2 */

/******************  Bit definition for ADC_JOFR3 register  *******************/
        .equ	 ADC_JOFR3_JOFFSET3,                 0x00000FFF	    /* Data offset for injected channel 3 */

/******************  Bit definition for ADC_JOFR4 register  *******************/
        .equ	 ADC_JOFR4_JOFFSET4,                 0x00000FFF	    /* Data offset for injected channel 4 */

/*******************  Bit definition for ADC_HTR register  ********************/
        .equ	 ADC_HTR_HT,                         0x00000FFF	    /* Analog watchdog high threshold */

/*******************  Bit definition for ADC_LTR register  ********************/
        .equ	 ADC_LTR_LT,                         0x00000FFF	     /* Analog watchdog low threshold */

/*******************  Bit definition for ADC_SQR1 register  *******************/
        .equ	 ADC_SQR1_SQ25,                      0x0000001F	    /* SQ25[4:0] bits (25th conversion in regular sequence) */
        .equ	 ADC_SQR1_SQ25_0,                    0x00000001	    /* Bit 0 */
        .equ	 ADC_SQR1_SQ25_1,                    0x00000002	    /* Bit 1 */
        .equ	 ADC_SQR1_SQ25_2,                    0x00000004	    /* Bit 2 */
        .equ	 ADC_SQR1_SQ25_3,                    0x00000008	    /* Bit 3 */
        .equ	 ADC_SQR1_SQ25_4,                    0x00000010	    /* Bit 4 */

        .equ	 ADC_SQR1_SQ26,                      0x000003E0	    /* SQ26[4:0] bits (26th conversion in regular sequence) */
        .equ	 ADC_SQR1_SQ26_0,                    0x00000020	    /* Bit 0 */
        .equ	 ADC_SQR1_SQ26_1,                    0x00000040	    /* Bit 1 */
        .equ	 ADC_SQR1_SQ26_2,                    0x00000080	    /* Bit 2 */
        .equ	 ADC_SQR1_SQ26_3,                    0x00000100	    /* Bit 3 */
        .equ	 ADC_SQR1_SQ26_4,                    0x00000200	    /* Bit 4 */

        .equ	 ADC_SQR1_SQ27,                      0x00007C00	    /* SQ27[4:0] bits (27th conversion in regular sequence) */
        .equ	 ADC_SQR1_SQ27_0,                    0x00000400	    /* Bit 0 */
        .equ	 ADC_SQR1_SQ27_1,                    0x00000800	    /* Bit 1 */
        .equ	 ADC_SQR1_SQ27_2,                    0x00001000	    /* Bit 2 */
        .equ	 ADC_SQR1_SQ27_3,                    0x00002000	    /* Bit 3 */
        .equ	 ADC_SQR1_SQ27_4,                    0x00004000	    /* Bit 4 */

        .equ	 ADC_SQR1_L,                         0x00F00000	    /* L[3:0] bits (Regular channel sequence length) */
        .equ	 ADC_SQR1_L_0,                       0x00100000	    /* Bit 0 */
        .equ	 ADC_SQR1_L_1,                       0x00200000	    /* Bit 1 */
        .equ	 ADC_SQR1_L_2,                       0x00400000	    /* Bit 2 */
        .equ	 ADC_SQR1_L_3,                       0x00800000	    /* Bit 3 */

/*******************  Bit definition for ADC_SQR2 register  *******************/
        .equ	 ADC_SQR2_SQ19,                      0x0000001F	    /* SQ19[4:0] bits (19th conversion in regular sequence) */
        .equ	 ADC_SQR2_SQ19_0,                    0x00000001	    /* Bit 0 */
        .equ	 ADC_SQR2_SQ19_1,                    0x00000002	    /* Bit 1 */
        .equ	 ADC_SQR2_SQ19_2,                    0x00000004	    /* Bit 2 */
        .equ	 ADC_SQR2_SQ19_3,                    0x00000008	    /* Bit 3 */
        .equ	 ADC_SQR2_SQ19_4,                    0x00000010	    /* Bit 4 */

        .equ	 ADC_SQR2_SQ20,                      0x000003E0	    /* SQ20[4:0] bits (20th conversion in regular sequence) */
        .equ	 ADC_SQR2_SQ20_0,                    0x00000020	    /* Bit 0 */
        .equ	 ADC_SQR2_SQ20_1,                    0x00000040	    /* Bit 1 */
        .equ	 ADC_SQR2_SQ20_2,                    0x00000080	    /* Bit 2 */
        .equ	 ADC_SQR2_SQ20_3,                    0x00000100	    /* Bit 3 */
        .equ	 ADC_SQR2_SQ20_4,                    0x00000200	    /* Bit 4 */

        .equ	 ADC_SQR2_SQ21,                      0x00007C00	    /* SQ21[4:0] bits (21th conversion in regular sequence) */
        .equ	 ADC_SQR2_SQ21_0,                    0x00000400	    /* Bit 0 */
        .equ	 ADC_SQR2_SQ21_1,                    0x00000800	    /* Bit 1 */
        .equ	 ADC_SQR2_SQ21_2,                    0x00001000	    /* Bit 2 */
        .equ	 ADC_SQR2_SQ21_3,                    0x00002000	    /* Bit 3 */
        .equ	 ADC_SQR2_SQ21_4,                    0x00004000	    /* Bit 4 */

        .equ	 ADC_SQR2_SQ22,                      0x000F8000	    /* SQ22[4:0] bits (22th conversion in regular sequence) */
        .equ	 ADC_SQR2_SQ22_0,                    0x00008000	    /* Bit 0 */
        .equ	 ADC_SQR2_SQ22_1,                    0x00010000	    /* Bit 1 */
        .equ	 ADC_SQR2_SQ22_2,                    0x00020000	    /* Bit 2 */
        .equ	 ADC_SQR2_SQ22_3,                    0x00040000	    /* Bit 3 */
        .equ	 ADC_SQR2_SQ22_4,                    0x00080000	    /* Bit 4 */

        .equ	 ADC_SQR2_SQ23,                      0x01F00000	    /* SQ23[4:0] bits (23th conversion in regular sequence) */
        .equ	 ADC_SQR2_SQ23_0,                    0x00100000	    /* Bit 0 */
        .equ	 ADC_SQR2_SQ23_1,                    0x00200000	    /* Bit 1 */
        .equ	 ADC_SQR2_SQ23_2,                    0x00400000	    /* Bit 2 */
        .equ	 ADC_SQR2_SQ23_3,                    0x00800000	    /* Bit 3 */
        .equ	 ADC_SQR2_SQ23_4,                    0x01000000	    /* Bit 4 */

        .equ	 ADC_SQR2_SQ24,                      0x3E000000	    /* SQ24[4:0] bits (24th conversion in regular sequence) */
        .equ	 ADC_SQR2_SQ24_0,                    0x02000000	    /* Bit 0 */
        .equ	 ADC_SQR2_SQ24_1,                    0x04000000	    /* Bit 1 */
        .equ	 ADC_SQR2_SQ24_2,                    0x08000000	    /* Bit 2 */
        .equ	 ADC_SQR2_SQ24_3,                    0x10000000	    /* Bit 3 */
        .equ	 ADC_SQR2_SQ24_4,                    0x20000000	    /* Bit 4 */

/*******************  Bit definition for ADC_SQR3 register  *******************/
        .equ	 ADC_SQR3_SQ13,                      0x0000001F	    /* SQ13[4:0] bits (13th conversion in regular sequence) */
        .equ	 ADC_SQR3_SQ13_0,                    0x00000001	    /* Bit 0 */
        .equ	 ADC_SQR3_SQ13_1,                    0x00000002	    /* Bit 1 */
        .equ	 ADC_SQR3_SQ13_2,                    0x00000004	    /* Bit 2 */
        .equ	 ADC_SQR3_SQ13_3,                    0x00000008	    /* Bit 3 */
        .equ	 ADC_SQR3_SQ13_4,                    0x00000010	    /* Bit 4 */

        .equ	 ADC_SQR3_SQ14,                      0x000003E0	    /* SQ14[4:0] bits (14th conversion in regular sequence) */
        .equ	 ADC_SQR3_SQ14_0,                    0x00000020	    /* Bit 0 */
        .equ	 ADC_SQR3_SQ14_1,                    0x00000040	    /* Bit 1 */
        .equ	 ADC_SQR3_SQ14_2,                    0x00000080	    /* Bit 2 */
        .equ	 ADC_SQR3_SQ14_3,                    0x00000100	    /* Bit 3 */
        .equ	 ADC_SQR3_SQ14_4,                    0x00000200	    /* Bit 4 */

        .equ	 ADC_SQR3_SQ15,                      0x00007C00	    /* SQ15[4:0] bits (15th conversion in regular sequence) */
        .equ	 ADC_SQR3_SQ15_0,                    0x00000400	    /* Bit 0 */
        .equ	 ADC_SQR3_SQ15_1,                    0x00000800	    /* Bit 1 */
        .equ	 ADC_SQR3_SQ15_2,                    0x00001000	    /* Bit 2 */
        .equ	 ADC_SQR3_SQ15_3,                    0x00002000	    /* Bit 3 */
        .equ	 ADC_SQR3_SQ15_4,                    0x00004000	    /* Bit 4 */

        .equ	 ADC_SQR3_SQ16,                      0x000F8000	    /* SQ16[4:0] bits (16th conversion in regular sequence) */
        .equ	 ADC_SQR3_SQ16_0,                    0x00008000	    /* Bit 0 */
        .equ	 ADC_SQR3_SQ16_1,                    0x00010000	    /* Bit 1 */
        .equ	 ADC_SQR3_SQ16_2,                    0x00020000	    /* Bit 2 */
        .equ	 ADC_SQR3_SQ16_3,                    0x00040000	    /* Bit 3 */
        .equ	 ADC_SQR3_SQ16_4,                    0x00080000	    /* Bit 4 */

        .equ	 ADC_SQR3_SQ17,                      0x01F00000	    /* SQ17[4:0] bits (17th conversion in regular sequence) */
        .equ	 ADC_SQR3_SQ17_0,                    0x00100000	    /* Bit 0 */
        .equ	 ADC_SQR3_SQ17_1,                    0x00200000	    /* Bit 1 */
        .equ	 ADC_SQR3_SQ17_2,                    0x00400000	    /* Bit 2 */
        .equ	 ADC_SQR3_SQ17_3,                    0x00800000	    /* Bit 3 */
        .equ	 ADC_SQR3_SQ17_4,                    0x01000000	    /* Bit 4 */

        .equ	 ADC_SQR3_SQ18,                      0x3E000000	    /* SQ18[4:0] bits (18th conversion in regular sequence) */
        .equ	 ADC_SQR3_SQ18_0,                    0x02000000	    /* Bit 0 */
        .equ	 ADC_SQR3_SQ18_1,                    0x04000000	    /* Bit 1 */
        .equ	 ADC_SQR3_SQ18_2,                    0x08000000	    /* Bit 2 */
        .equ	 ADC_SQR3_SQ18_3,                    0x10000000	    /* Bit 3 */
        .equ	 ADC_SQR3_SQ18_4,                    0x20000000	    /* Bit 4 */

/*******************  Bit definition for ADC_SQR4 register  *******************/
        .equ	 ADC_SQR4_SQ7,                       0x0000001F	    /* SQ7[4:0] bits (7th conversion in regular sequence) */
        .equ	 ADC_SQR4_SQ7_0,                     0x00000001	    /* Bit 0 */
        .equ	 ADC_SQR4_SQ7_1,                     0x00000002	    /* Bit 1 */
        .equ	 ADC_SQR4_SQ7_2,                     0x00000004	    /* Bit 2 */
        .equ	 ADC_SQR4_SQ7_3,                     0x00000008	    /* Bit 3 */
        .equ	 ADC_SQR4_SQ7_4,                     0x00000010	    /* Bit 4 */

        .equ	 ADC_SQR4_SQ8,                       0x000003E0	    /* SQ8[4:0] bits (8th conversion in regular sequence) */
        .equ	 ADC_SQR4_SQ8_0,                     0x00000020	    /* Bit 0 */
        .equ	 ADC_SQR4_SQ8_1,                     0x00000040	    /* Bit 1 */
        .equ	 ADC_SQR4_SQ8_2,                     0x00000080	    /* Bit 2 */
        .equ	 ADC_SQR4_SQ8_3,                     0x00000100	    /* Bit 3 */
        .equ	 ADC_SQR4_SQ8_4,                     0x00000200	    /* Bit 4 */

        .equ	 ADC_SQR4_SQ9,                       0x00007C00	    /* SQ9[4:0] bits (9th conversion in regular sequence) */
        .equ	 ADC_SQR4_SQ9_0,                     0x00000400	    /* Bit 0 */
        .equ	 ADC_SQR4_SQ9_1,                     0x00000800	    /* Bit 1 */
        .equ	 ADC_SQR4_SQ9_2,                     0x00001000	    /* Bit 2 */
        .equ	 ADC_SQR4_SQ9_3,                     0x00002000	    /* Bit 3 */
        .equ	 ADC_SQR4_SQ9_4,                     0x00004000	    /* Bit 4 */

        .equ	 ADC_SQR4_SQ10,                      0x000F8000	    /* SQ10[4:0] bits (10th conversion in regular sequence) */
        .equ	 ADC_SQR4_SQ10_0,                    0x00008000	    /* Bit 0 */
        .equ	 ADC_SQR4_SQ10_1,                    0x00010000	    /* Bit 1 */
        .equ	 ADC_SQR4_SQ10_2,                    0x00020000	    /* Bit 2 */
        .equ	 ADC_SQR4_SQ10_3,                    0x00040000	    /* Bit 3 */
        .equ	 ADC_SQR4_SQ10_4,                    0x00080000	    /* Bit 4 */

        .equ	 ADC_SQR4_SQ11,                      0x01F00000	    /* SQ11[4:0] bits (11th conversion in regular sequence) */
        .equ	 ADC_SQR4_SQ11_0,                    0x00100000	    /* Bit 0 */
        .equ	 ADC_SQR4_SQ11_1,                    0x00200000	    /* Bit 1 */
        .equ	 ADC_SQR4_SQ11_2,                    0x00400000	    /* Bit 2 */
        .equ	 ADC_SQR4_SQ11_3,                    0x00800000	    /* Bit 3 */
        .equ	 ADC_SQR4_SQ11_4,                    0x01000000	    /* Bit 4 */

        .equ	 ADC_SQR4_SQ12,                      0x3E000000	    /* SQ12[4:0] bits (12th conversion in regular sequence) */
        .equ	 ADC_SQR4_SQ12_0,                    0x02000000	    /* Bit 0 */
        .equ	 ADC_SQR4_SQ12_1,                    0x04000000	    /* Bit 1 */
        .equ	 ADC_SQR4_SQ12_2,                    0x08000000	    /* Bit 2 */
        .equ	 ADC_SQR4_SQ12_3,                    0x10000000	    /* Bit 3 */
        .equ	 ADC_SQR4_SQ12_4,                    0x20000000	    /* Bit 4 */

/*******************  Bit definition for ADC_SQR5 register  *******************/
        .equ	 ADC_SQR5_SQ1,                       0x0000001F	    /* SQ1[4:0] bits (1st conversion in regular sequence) */
        .equ	 ADC_SQR5_SQ1_0,                     0x00000001	    /* Bit 0 */
        .equ	 ADC_SQR5_SQ1_1,                     0x00000002	    /* Bit 1 */
        .equ	 ADC_SQR5_SQ1_2,                     0x00000004	    /* Bit 2 */
        .equ	 ADC_SQR5_SQ1_3,                     0x00000008	    /* Bit 3 */
        .equ	 ADC_SQR5_SQ1_4,                     0x00000010	    /* Bit 4 */

        .equ	 ADC_SQR5_SQ2,                       0x000003E0	    /* SQ2[4:0] bits (2nd conversion in regular sequence) */
        .equ	 ADC_SQR5_SQ2_0,                     0x00000020	    /* Bit 0 */
        .equ	 ADC_SQR5_SQ2_1,                     0x00000040	    /* Bit 1 */
        .equ	 ADC_SQR5_SQ2_2,                     0x00000080	    /* Bit 2 */
        .equ	 ADC_SQR5_SQ2_3,                     0x00000100	    /* Bit 3 */
        .equ	 ADC_SQR5_SQ2_4,                     0x00000200	    /* Bit 4 */

        .equ	 ADC_SQR5_SQ3,                       0x00007C00	    /* SQ3[4:0] bits (3rd conversion in regular sequence) */
        .equ	 ADC_SQR5_SQ3_0,                     0x00000400	    /* Bit 0 */
        .equ	 ADC_SQR5_SQ3_1,                     0x00000800	    /* Bit 1 */
        .equ	 ADC_SQR5_SQ3_2,                     0x00001000	    /* Bit 2 */
        .equ	 ADC_SQR5_SQ3_3,                     0x00002000	    /* Bit 3 */
        .equ	 ADC_SQR5_SQ3_4,                     0x00004000	    /* Bit 4 */

        .equ	 ADC_SQR5_SQ4,                       0x000F8000	    /* SQ4[4:0] bits (4th conversion in regular sequence) */
        .equ	 ADC_SQR5_SQ4_0,                     0x00008000	    /* Bit 0 */
        .equ	 ADC_SQR5_SQ4_1,                     0x00010000	    /* Bit 1 */
        .equ	 ADC_SQR5_SQ4_2,                     0x00020000	    /* Bit 2 */
        .equ	 ADC_SQR5_SQ4_3,                     0x00040000	    /* Bit 3 */
        .equ	 ADC_SQR5_SQ4_4,                     0x00080000	    /* Bit 4 */

        .equ	 ADC_SQR5_SQ5,                       0x01F00000	    /* SQ5[4:0] bits (5th conversion in regular sequence) */
        .equ	 ADC_SQR5_SQ5_0,                     0x00100000	    /* Bit 0 */
        .equ	 ADC_SQR5_SQ5_1,                     0x00200000	    /* Bit 1 */
        .equ	 ADC_SQR5_SQ5_2,                     0x00400000	    /* Bit 2 */
        .equ	 ADC_SQR5_SQ5_3,                     0x00800000	    /* Bit 3 */
        .equ	 ADC_SQR5_SQ5_4,                     0x01000000	    /* Bit 4 */

        .equ	 ADC_SQR5_SQ6,                       0x3E000000	    /* SQ6[4:0] bits (6th conversion in regular sequence) */
        .equ	 ADC_SQR5_SQ6_0,                     0x02000000	    /* Bit 0 */
        .equ	 ADC_SQR5_SQ6_1,                     0x04000000	    /* Bit 1 */
        .equ	 ADC_SQR5_SQ6_2,                     0x08000000	    /* Bit 2 */
        .equ	 ADC_SQR5_SQ6_3,                     0x10000000	    /* Bit 3 */
        .equ	 ADC_SQR5_SQ6_4,                     0x20000000	    /* Bit 4 */


/*******************  Bit definition for ADC_JSQR register  *******************/
        .equ	 ADC_JSQR_JSQ1,                      0x0000001F	    /* JSQ1[4:0] bits (1st conversion in injected sequence) */  
        .equ	 ADC_JSQR_JSQ1_0,                    0x00000001	    /* Bit 0 */
        .equ	 ADC_JSQR_JSQ1_1,                    0x00000002	    /* Bit 1 */
        .equ	 ADC_JSQR_JSQ1_2,                    0x00000004	    /* Bit 2 */
        .equ	 ADC_JSQR_JSQ1_3,                    0x00000008	    /* Bit 3 */
        .equ	 ADC_JSQR_JSQ1_4,                    0x00000010	    /* Bit 4 */

        .equ	 ADC_JSQR_JSQ2,                      0x000003E0	    /* JSQ2[4:0] bits (2nd conversion in injected sequence) */
        .equ	 ADC_JSQR_JSQ2_0,                    0x00000020	    /* Bit 0 */
        .equ	 ADC_JSQR_JSQ2_1,                    0x00000040	    /* Bit 1 */
        .equ	 ADC_JSQR_JSQ2_2,                    0x00000080	    /* Bit 2 */
        .equ	 ADC_JSQR_JSQ2_3,                    0x00000100	    /* Bit 3 */
        .equ	 ADC_JSQR_JSQ2_4,                    0x00000200	    /* Bit 4 */

        .equ	 ADC_JSQR_JSQ3,                      0x00007C00	    /* JSQ3[4:0] bits (3rd conversion in injected sequence) */
        .equ	 ADC_JSQR_JSQ3_0,                    0x00000400	    /* Bit 0 */
        .equ	 ADC_JSQR_JSQ3_1,                    0x00000800	    /* Bit 1 */
        .equ	 ADC_JSQR_JSQ3_2,                    0x00001000	    /* Bit 2 */
        .equ	 ADC_JSQR_JSQ3_3,                    0x00002000	    /* Bit 3 */
        .equ	 ADC_JSQR_JSQ3_4,                    0x00004000	    /* Bit 4 */

        .equ	 ADC_JSQR_JSQ4,                      0x000F8000	    /* JSQ4[4:0] bits (4th conversion in injected sequence) */
        .equ	 ADC_JSQR_JSQ4_0,                    0x00008000	    /* Bit 0 */
        .equ	 ADC_JSQR_JSQ4_1,                    0x00010000	    /* Bit 1 */
        .equ	 ADC_JSQR_JSQ4_2,                    0x00020000	    /* Bit 2 */
        .equ	 ADC_JSQR_JSQ4_3,                    0x00040000	    /* Bit 3 */
        .equ	 ADC_JSQR_JSQ4_4,                    0x00080000	    /* Bit 4 */

        .equ	 ADC_JSQR_JL,                        0x00300000	    /* JL[1:0] bits (Injected Sequence length) */
        .equ	 ADC_JSQR_JL_0,                      0x00100000	    /* Bit 0 */
        .equ	 ADC_JSQR_JL_1,                      0x00200000	    /* Bit 1 */

/*******************  Bit definition for ADC_JDR1 register  *******************/
        .equ	 ADC_JDR1_JDATA,                     0x0000FFFF	    /* Injected data */

/*******************  Bit definition for ADC_JDR2 register  *******************/
        .equ	 ADC_JDR2_JDATA,                     0x0000FFFF	    /* Injected data */

/*******************  Bit definition for ADC_JDR3 register  *******************/
        .equ	 ADC_JDR3_JDATA,                     0x0000FFFF	    /* Injected data */

/*******************  Bit definition for ADC_JDR4 register  *******************/
        .equ	 ADC_JDR4_JDATA,                     0x0000FFFF	    /* Injected data */

/********************  Bit definition for ADC_DR register  ********************/
        .equ	 ADC_DR_DATA,                        0x0000FFFF	    /* Regular data */


/*******************  Bit definition for ADC_CSR register  ********************/
        .equ	 ADC_CSR_AWD1,                       0x00000001	    /* ADC1 Analog watchdog flag */
        .equ	 ADC_CSR_EOC1,                       0x00000002	    /* ADC1 End of conversion */
        .equ	 ADC_CSR_JEOC1,                      0x00000004	    /* ADC1 Injected channel end of conversion */
        .equ	 ADC_CSR_JSTRT1,                     0x00000008	    /* ADC1 Injected channel Start flag */
        .equ	 ADC_CSR_STRT1,                      0x00000010	    /* ADC1 Regular channel Start flag */
        .equ	 ADC_CSR_OVR1,                       0x00000020	    /* ADC1 overrun  flag */
        .equ	 ADC_CSR_ADONS1,                     0x00000040	    /* ADON status of ADC1 */

/*******************  Bit definition for ADC_CCR register  ********************/
        .equ	 ADC_CCR_ADCPRE,                     0x00030000	    /* ADC prescaler*/
        .equ	 ADC_CCR_ADCPRE_0,                   0x00010000	    /* Bit 0 */
        .equ	 ADC_CCR_ADCPRE_1,                   0x00020000	    /* Bit 1 */ 
        .equ	 ADC_CCR_TSVREFE,                    0x00800000	    /* Temperature Sensor and VREFINT Enable */

/******************************************************************************/
/*                                                                            */
/*                      Analog Comparators (COMP)                             */
/*                                                                            */
/******************************************************************************/

/******************  Bit definition for COMP_CSR register  ********************/
        .equ	 COMP_CSR_10KPU,                     0x00000001	    /* 10K pull-up resistor */
        .equ	 COMP_CSR_400KPU,                    0x00000002	    /* 400K pull-up resistor */
        .equ	 COMP_CSR_10KPD,                     0x00000004	    /* 10K pull-down resistor */
        .equ	 COMP_CSR_400KPD,                    0x00000008	    /* 400K pull-down resistor */

        .equ	 COMP_CSR_CMP1EN,                    0x00000010	    /* Comparator 1 enable */
        .equ	 COMP_CSR_CMP1OUT,                   0x00000080	    /* Comparator 1 output */

        .equ	 COMP_CSR_SPEED,                     0x00001000	    /* Comparator 2 speed */
        .equ	 COMP_CSR_CMP2OUT,                   0x00002000	    /* Comparator 2 ouput */

        .equ	 COMP_CSR_VREFOUTEN,                 0x00010000	    /* Comparator Vref Enable */
        .equ	 COMP_CSR_WNDWE,                     0x00020000	    /* Window mode enable */

        .equ	 COMP_CSR_INSEL,                     0x001C0000	    /* INSEL[2:0] Inversion input Selection */
        .equ	 COMP_CSR_INSEL_0,                   0x00040000	    /* Bit 0 */
        .equ	 COMP_CSR_INSEL_1,                   0x00080000	    /* Bit 1 */
        .equ	 COMP_CSR_INSEL_2,                   0x00100000	    /* Bit 2 */

        .equ	 COMP_CSR_OUTSEL,                    0x00E00000	    /* OUTSEL[2:0] comparator 2 output redirection */
        .equ	 COMP_CSR_OUTSEL_0,                  0x00200000	    /* Bit 0 */
        .equ	 COMP_CSR_OUTSEL_1,                  0x00400000	    /* Bit 1 */
        .equ	 COMP_CSR_OUTSEL_2,                  0x00800000	    /* Bit 2 */

/******************************************************************************/
/*                                                                            */
/*                       CRC calculation unit (CRC)                           */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for CRC_DR register  *********************/
        .equ	 CRC_DR_DR,                          0xFFFFFFFF     /* Data register bits */

/*******************  Bit definition for CRC_IDR register  ********************/
        .equ	 CRC_IDR_IDR,                        0xFF	    /* General-purpose 8-bit data register bits */

/********************  Bit definition for CRC_CR register  ********************/
        .equ	 CRC_CR_RESET,                       0x00000001     /* RESET bit */

/******************************************************************************/
/*                                                                            */
/*                    Digital to Analog Converter (DAC)                       */
/*                                                                            */
/******************************************************************************/

/********************  Bit definition for DAC_CR register  ********************/
        .equ	 DAC_CR_EN1,                         0x00000001	    /*DAC channel1 enable */
        .equ	 DAC_CR_BOFF1,                       0x00000002	    /*DAC channel1 output buffer disable */
        .equ	 DAC_CR_TEN1,                        0x00000004	    /*DAC channel1 Trigger enable */

        .equ	 DAC_CR_TSEL1,                       0x00000038	    /*TSEL1[2:0] (DAC channel1 Trigger selection) */
        .equ	 DAC_CR_TSEL1_0,                     0x00000008	    /*Bit 0 */
        .equ	 DAC_CR_TSEL1_1,                     0x00000010	    /*Bit 1 */
        .equ	 DAC_CR_TSEL1_2,                     0x00000020	    /*Bit 2 */

        .equ	 DAC_CR_WAVE1,                       0x000000C0	    /*WAVE1[1:0] (DAC channel1 noise/triangle wave generation enable) */
        .equ	 DAC_CR_WAVE1_0,                     0x00000040	    /*Bit 0 */
        .equ	 DAC_CR_WAVE1_1,                     0x00000080	    /*Bit 1 */

        .equ	 DAC_CR_MAMP1,                       0x00000F00	    /*MAMP1[3:0] (DAC channel1 Mask/Amplitude selector) */
        .equ	 DAC_CR_MAMP1_0,                     0x00000100	    /*Bit 0 */
        .equ	 DAC_CR_MAMP1_1,                     0x00000200	    /*Bit 1 */
        .equ	 DAC_CR_MAMP1_2,                     0x00000400	    /*Bit 2 */
        .equ	 DAC_CR_MAMP1_3,                     0x00000800	    /*Bit 3 */

        .equ	 DAC_CR_DMAEN1,                      0x00001000	    /*DAC channel1 DMA enable */
        .equ	 DAC_CR_EN2,                         0x00010000	    /*DAC channel2 enable */
        .equ	 DAC_CR_BOFF2,                       0x00020000	    /*DAC channel2 output buffer disable */
        .equ	 DAC_CR_TEN2,                        0x00040000	    /*DAC channel2 Trigger enable */

        .equ	 DAC_CR_TSEL2,                       0x00380000	    /*TSEL2[2:0] (DAC channel2 Trigger selection) */
        .equ	 DAC_CR_TSEL2_0,                     0x00080000	    /*Bit 0 */
        .equ	 DAC_CR_TSEL2_1,                     0x00100000	    /*Bit 1 */
        .equ	 DAC_CR_TSEL2_2,                     0x00200000	    /*Bit 2 */

        .equ	 DAC_CR_WAVE2,                       0x00C00000	    /*WAVE2[1:0] (DAC channel2 noise/triangle wave generation enable) */
        .equ	 DAC_CR_WAVE2_0,                     0x00400000	    /*Bit 0 */
        .equ	 DAC_CR_WAVE2_1,                     0x00800000	    /*Bit 1 */

        .equ	 DAC_CR_MAMP2,                       0x0F000000	    /*MAMP2[3:0] (DAC channel2 Mask/Amplitude selector) */
        .equ	 DAC_CR_MAMP2_0,                     0x01000000	    /*Bit 0 */
        .equ	 DAC_CR_MAMP2_1,                     0x02000000	    /*Bit 1 */
        .equ	 DAC_CR_MAMP2_2,                     0x04000000	    /*Bit 2 */
        .equ	 DAC_CR_MAMP2_3,                     0x08000000	    /*Bit 3 */

        .equ	 DAC_CR_DMAEN2,                      0x10000000	    /*DAC channel2 DMA enabled */

/*****************  Bit definition for DAC_SWTRIGR register  ******************/
        .equ	 DAC_SWTRIGR_SWTRIG1,                0x01	           /*DAC channel1 software trigger */
        .equ	 DAC_SWTRIGR_SWTRIG2,                0x02	           /*DAC channel2 software trigger */

/*****************  Bit definition for DAC_DHR12R1 register  ******************/
        .equ	 DAC_DHR12R1_DACC1DHR,               0x0FFF	        /*DAC channel1 12-bit Right aligned data */

/*****************  Bit definition for DAC_DHR12L1 register  ******************/
        .equ	 DAC_DHR12L1_DACC1DHR,               0xFFF0	        /*DAC channel1 12-bit Left aligned data */

/******************  Bit definition for DAC_DHR8R1 register  ******************/
        .equ	 DAC_DHR8R1_DACC1DHR,                0xFF	           /*DAC channel1 8-bit Right aligned data */

/*****************  Bit definition for DAC_DHR12R2 register  ******************/
        .equ	 DAC_DHR12R2_DACC2DHR,               0x0FFF	        /*DAC channel2 12-bit Right aligned data */

/*****************  Bit definition for DAC_DHR12L2 register  ******************/
        .equ	 DAC_DHR12L2_DACC2DHR,               0xFFF0	        /*DAC channel2 12-bit Left aligned data */

/******************  Bit definition for DAC_DHR8R2 register  ******************/
        .equ	 DAC_DHR8R2_DACC2DHR,                0xFF	           /*DAC channel2 8-bit Right aligned data */

/*****************  Bit definition for DAC_DHR12RD register  ******************/
        .equ	 DAC_DHR12RD_DACC1DHR,               0x00000FFF	    /*DAC channel1 12-bit Right aligned data */
        .equ	 DAC_DHR12RD_DACC2DHR,               0x0FFF0000	    /*DAC channel2 12-bit Right aligned data */

/*****************  Bit definition for DAC_DHR12LD register  ******************/
        .equ	 DAC_DHR12LD_DACC1DHR,               0x0000FFF0	    /*DAC channel1 12-bit Left aligned data */
        .equ	 DAC_DHR12LD_DACC2DHR,               0xFFF00000	    /*DAC channel2 12-bit Left aligned data */

/******************  Bit definition for DAC_DHR8RD register  ******************/
        .equ	 DAC_DHR8RD_DACC1DHR,                0x00FF	        /*DAC channel1 8-bit Right aligned data */
        .equ	 DAC_DHR8RD_DACC2DHR,                0xFF00	        /*DAC channel2 8-bit Right aligned data */

/*******************  Bit definition for DAC_DOR1 register  *******************/
        .equ	 DAC_DOR1_DACC1DOR,                  0x0FFF	        /*DAC channel1 data output */

/*******************  Bit definition for DAC_DOR2 register  *******************/
        .equ	 DAC_DOR2_DACC2DOR,                  0x0FFF	        /*DAC channel2 data output */

/********************  Bit definition for DAC_SR register  ********************/
        .equ	 DAC_SR_DMAUDR1,                     0x00002000	    /*DAC channel1 DMA underrun flag */
        .equ	 DAC_SR_DMAUDR2,                     0x20000000	    /*DAC channel2 DMA underrun flag */

/******************************************************************************/
/*                                                                            */
/*                           Debug MCU (DBGMCU)                               */
/*                                                                            */
/******************************************************************************/

/****************  Bit definition for DBGMCU_IDCODE register  *****************/
        .equ	 DBGMCU_IDCODE_DEV_ID,               0x00000FFF	    /* Device Identifier */

        .equ	 DBGMCU_IDCODE_REV_ID,               0xFFFF0000	    /* REV_ID[15:0] bits (Revision Identifier) */
        .equ	 DBGMCU_IDCODE_REV_ID_0,             0x00010000	    /* Bit 0 */
        .equ	 DBGMCU_IDCODE_REV_ID_1,             0x00020000	    /* Bit 1 */
        .equ	 DBGMCU_IDCODE_REV_ID_2,             0x00040000	    /* Bit 2 */
        .equ	 DBGMCU_IDCODE_REV_ID_3,             0x00080000	    /* Bit 3 */
        .equ	 DBGMCU_IDCODE_REV_ID_4,             0x00100000	    /* Bit 4 */
        .equ	 DBGMCU_IDCODE_REV_ID_5,             0x00200000	    /* Bit 5 */
        .equ	 DBGMCU_IDCODE_REV_ID_6,             0x00400000	    /* Bit 6 */
        .equ	 DBGMCU_IDCODE_REV_ID_7,             0x00800000	    /* Bit 7 */
        .equ	 DBGMCU_IDCODE_REV_ID_8,             0x01000000	    /* Bit 8 */
        .equ	 DBGMCU_IDCODE_REV_ID_9,             0x02000000	    /* Bit 9 */
        .equ	 DBGMCU_IDCODE_REV_ID_10,            0x04000000	    /* Bit 10 */
        .equ	 DBGMCU_IDCODE_REV_ID_11,            0x08000000	    /* Bit 11 */
        .equ	 DBGMCU_IDCODE_REV_ID_12,            0x10000000	    /* Bit 12 */
        .equ	 DBGMCU_IDCODE_REV_ID_13,            0x20000000	    /* Bit 13 */
        .equ	 DBGMCU_IDCODE_REV_ID_14,            0x40000000	    /* Bit 14 */
        .equ	 DBGMCU_IDCODE_REV_ID_15,            0x80000000	    /* Bit 15 */

/******************  Bit definition for DBGMCU_CR register  *******************/
        .equ	 DBGMCU_CR_DBG_SLEEP,                0x00000001	    /* Debug Sleep Mode */
        .equ	 DBGMCU_CR_DBG_STOP,                 0x00000002	    /* Debug Stop Mode */
        .equ	 DBGMCU_CR_DBG_STANDBY,              0x00000004	    /* Debug Standby mode */
        .equ	 DBGMCU_CR_TRACE_IOEN,               0x00000020	    /* Trace Pin Assignment Control */

        .equ	 DBGMCU_CR_TRACE_MODE,               0x000000C0	    /* TRACE_MODE[1:0] bits (Trace Pin Assignment Control) */
        .equ	 DBGMCU_CR_TRACE_MODE_0,             0x00000040	    /* Bit 0 */
        .equ	 DBGMCU_CR_TRACE_MODE_1,             0x00000080	    /* Bit 1 */

/******************  Bit definition for DBGMCU_APB1_FZ register  **************/

        .equ	 DBGMCU_APB1_FZ_DBG_TIM2_STOP,            0x00000001	    /* TIM2 counter stopped when core is halted */
        .equ	 DBGMCU_APB1_FZ_DBG_TIM3_STOP,            0x00000002	    /* TIM3 counter stopped when core is halted */
        .equ	 DBGMCU_APB1_FZ_DBG_TIM4_STOP,            0x00000004	    /* TIM4 counter stopped when core is halted */
        .equ	 DBGMCU_APB1_FZ_DBG_TIM6_STOP,            0x00000010	    /* TIM6 counter stopped when core is halted */
        .equ	 DBGMCU_APB1_FZ_DBG_TIM7_STOP,            0x00000020	    /* TIM7 counter stopped when core is halted */
        .equ	 DBGMCU_APB1_FZ_DBG_WWDG_STOP,            0x00000800	    /* Debug Window Watchdog stopped when Core is halted */
        .equ	 DBGMCU_APB1_FZ_DBG_IWDG_STOP,            0x00001000	    /* Debug Independent Watchdog stopped when Core is halted */
        .equ	 DBGMCU_APB1_FZ_DBG_I2C1_SMBUS_TIMEOUT,   0x00200000	    /* SMBUS timeout mode stopped when Core is halted */
        .equ	 DBGMCU_APB1_FZ_DBG_I2C2_SMBUS_TIMEOUT,   0x00400000	    /* SMBUS timeout mode stopped when Core is halted */

/******************  Bit definition for DBGMCU_APB2_FZ register  **************/

        .equ	 DBGMCU_APB2_FZ_DBG_TIM9_STOP,            0x00000004	    /* TIM9 counter stopped when core is halted */
        .equ	 DBGMCU_APB2_FZ_DBG_TIM10_STOP,           0x00000008	    /* TIM10 counter stopped when core is halted */
        .equ	 DBGMCU_APB2_FZ_DBG_TIM11_STOP,           0x00000010	    /* TIM11 counter stopped when core is halted */

/******************************************************************************/
/*                                                                            */
/*                           DMA Controller (DMA)                             */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for DMA_ISR register  ********************/
        .equ	 DMA_ISR_GIF1,                       0x00000001	    /* Channel 1 Global interrupt flag */
        .equ	 DMA_ISR_TCIF1,                      0x00000002	    /* Channel 1 Transfer Complete flag */
        .equ	 DMA_ISR_HTIF1,                      0x00000004	    /* Channel 1 Half Transfer flag */
        .equ	 DMA_ISR_TEIF1,                      0x00000008	    /* Channel 1 Transfer Error flag */
        .equ	 DMA_ISR_GIF2,                       0x00000010	    /* Channel 2 Global interrupt flag */
        .equ	 DMA_ISR_TCIF2,                      0x00000020	    /* Channel 2 Transfer Complete flag */
        .equ	 DMA_ISR_HTIF2,                      0x00000040	    /* Channel 2 Half Transfer flag */
        .equ	 DMA_ISR_TEIF2,                      0x00000080	    /* Channel 2 Transfer Error flag */
        .equ	 DMA_ISR_GIF3,                       0x00000100	    /* Channel 3 Global interrupt flag */
        .equ	 DMA_ISR_TCIF3,                      0x00000200	    /* Channel 3 Transfer Complete flag */
        .equ	 DMA_ISR_HTIF3,                      0x00000400	    /* Channel 3 Half Transfer flag */
        .equ	 DMA_ISR_TEIF3,                      0x00000800	    /* Channel 3 Transfer Error flag */
        .equ	 DMA_ISR_GIF4,                       0x00001000	    /* Channel 4 Global interrupt flag */
        .equ	 DMA_ISR_TCIF4,                      0x00002000	    /* Channel 4 Transfer Complete flag */
        .equ	 DMA_ISR_HTIF4,                      0x00004000	    /* Channel 4 Half Transfer flag */
        .equ	 DMA_ISR_TEIF4,                      0x00008000	    /* Channel 4 Transfer Error flag */
        .equ	 DMA_ISR_GIF5,                       0x00010000	    /* Channel 5 Global interrupt flag */
        .equ	 DMA_ISR_TCIF5,                      0x00020000	    /* Channel 5 Transfer Complete flag */
        .equ	 DMA_ISR_HTIF5,                      0x00040000	    /* Channel 5 Half Transfer flag */
        .equ	 DMA_ISR_TEIF5,                      0x00080000	    /* Channel 5 Transfer Error flag */
        .equ	 DMA_ISR_GIF6,                       0x00100000	    /* Channel 6 Global interrupt flag */
        .equ	 DMA_ISR_TCIF6,                      0x00200000	    /* Channel 6 Transfer Complete flag */
        .equ	 DMA_ISR_HTIF6,                      0x00400000	    /* Channel 6 Half Transfer flag */
        .equ	 DMA_ISR_TEIF6,                      0x00800000	    /* Channel 6 Transfer Error flag */
        .equ	 DMA_ISR_GIF7,                       0x01000000	    /* Channel 7 Global interrupt flag */
        .equ	 DMA_ISR_TCIF7,                      0x02000000	    /* Channel 7 Transfer Complete flag */
        .equ	 DMA_ISR_HTIF7,                      0x04000000	    /* Channel 7 Half Transfer flag */
        .equ	 DMA_ISR_TEIF7,                      0x08000000	    /* Channel 7 Transfer Error flag */

/*******************  Bit definition for DMA_IFCR register  *******************/
        .equ	 DMA_IFCR_CGIF1,                     0x00000001	    /* Channel 1 Global interrupt clearr */
        .equ	 DMA_IFCR_CTCIF1,                    0x00000002	    /* Channel 1 Transfer Complete clear */
        .equ	 DMA_IFCR_CHTIF1,                    0x00000004	    /* Channel 1 Half Transfer clear */
        .equ	 DMA_IFCR_CTEIF1,                    0x00000008	    /* Channel 1 Transfer Error clear */
        .equ	 DMA_IFCR_CGIF2,                     0x00000010	    /* Channel 2 Global interrupt clear */
        .equ	 DMA_IFCR_CTCIF2,                    0x00000020	    /* Channel 2 Transfer Complete clear */
        .equ	 DMA_IFCR_CHTIF2,                    0x00000040	    /* Channel 2 Half Transfer clear */
        .equ	 DMA_IFCR_CTEIF2,                    0x00000080	    /* Channel 2 Transfer Error clear */
        .equ	 DMA_IFCR_CGIF3,                     0x00000100	    /* Channel 3 Global interrupt clear */
        .equ	 DMA_IFCR_CTCIF3,                    0x00000200	    /* Channel 3 Transfer Complete clear */
        .equ	 DMA_IFCR_CHTIF3,                    0x00000400	    /* Channel 3 Half Transfer clear */
        .equ	 DMA_IFCR_CTEIF3,                    0x00000800	    /* Channel 3 Transfer Error clear */
        .equ	 DMA_IFCR_CGIF4,                     0x00001000	    /* Channel 4 Global interrupt clear */
        .equ	 DMA_IFCR_CTCIF4,                    0x00002000	    /* Channel 4 Transfer Complete clear */
        .equ	 DMA_IFCR_CHTIF4,                    0x00004000	    /* Channel 4 Half Transfer clear */
        .equ	 DMA_IFCR_CTEIF4,                    0x00008000	    /* Channel 4 Transfer Error clear */
        .equ	 DMA_IFCR_CGIF5,                     0x00010000	    /* Channel 5 Global interrupt clear */
        .equ	 DMA_IFCR_CTCIF5,                    0x00020000	    /* Channel 5 Transfer Complete clear */
        .equ	 DMA_IFCR_CHTIF5,                    0x00040000	    /* Channel 5 Half Transfer clear */
        .equ	 DMA_IFCR_CTEIF5,                    0x00080000	    /* Channel 5 Transfer Error clear */
        .equ	 DMA_IFCR_CGIF6,                     0x00100000	    /* Channel 6 Global interrupt clear */
        .equ	 DMA_IFCR_CTCIF6,                    0x00200000	    /* Channel 6 Transfer Complete clear */
        .equ	 DMA_IFCR_CHTIF6,                    0x00400000	    /* Channel 6 Half Transfer clear */
        .equ	 DMA_IFCR_CTEIF6,                    0x00800000	    /* Channel 6 Transfer Error clear */
        .equ	 DMA_IFCR_CGIF7,                     0x01000000	    /* Channel 7 Global interrupt clear */
        .equ	 DMA_IFCR_CTCIF7,                    0x02000000	    /* Channel 7 Transfer Complete clear */
        .equ	 DMA_IFCR_CHTIF7,                    0x04000000	    /* Channel 7 Half Transfer clear */
        .equ	 DMA_IFCR_CTEIF7,                    0x08000000	    /* Channel 7 Transfer Error clear */

/*******************  Bit definition for DMA_CCR1 register  *******************/
        .equ	 DMA_CCR1_EN,                        0x0001	        /* Channel enable*/
        .equ	 DMA_CCR1_TCIE,                      0x0002	        /* Transfer complete interrupt enable */
        .equ	 DMA_CCR1_HTIE,                      0x0004	        /* Half Transfer interrupt enable */
        .equ	 DMA_CCR1_TEIE,                      0x0008	        /* Transfer error interrupt enable */
        .equ	 DMA_CCR1_DIR,                       0x0010	        /* Data transfer direction */
        .equ	 DMA_CCR1_CIRC,                      0x0020	        /* Circular mode */
        .equ	 DMA_CCR1_PINC,                      0x0040	        /* Peripheral increment mode */
        .equ	 DMA_CCR1_MINC,                      0x0080	        /* Memory increment mode */

        .equ	 DMA_CCR1_PSIZE,                     0x0300	        /* PSIZE[1:0] bits (Peripheral size) */
        .equ	 DMA_CCR1_PSIZE_0,                   0x0100	        /* Bit 0 */
        .equ	 DMA_CCR1_PSIZE_1,                   0x0200	        /* Bit 1 */

        .equ	 DMA_CCR1_MSIZE,                     0x0C00	        /* MSIZE[1:0] bits (Memory size) */
        .equ	 DMA_CCR1_MSIZE_0,                   0x0400	        /* Bit 0 */
        .equ	 DMA_CCR1_MSIZE_1,                   0x0800	        /* Bit 1 */

        .equ	 DMA_CCR1_PL,                        0x3000	        /* PL[1:0] bits(Channel Priority level) */
        .equ	 DMA_CCR1_PL_0,                      0x1000	        /* Bit 0 */
        .equ	 DMA_CCR1_PL_1,                      0x2000	        /* Bit 1 */

        .equ	 DMA_CCR1_MEM2MEM,                   0x4000	        /* Memory to memory mode */

/*******************  Bit definition for DMA_CCR2 register  *******************/
        .equ	 DMA_CCR2_EN,                        0x0001	        /* Channel enable */
        .equ	 DMA_CCR2_TCIE,                      0x0002	        /* ransfer complete interrupt enable */
        .equ	 DMA_CCR2_HTIE,                      0x0004	        /* Half Transfer interrupt enable */
        .equ	 DMA_CCR2_TEIE,                      0x0008	        /* Transfer error interrupt enable */
        .equ	 DMA_CCR2_DIR,                       0x0010	        /* Data transfer direction */
        .equ	 DMA_CCR2_CIRC,                      0x0020	        /* Circular mode */
        .equ	 DMA_CCR2_PINC,                      0x0040	        /* Peripheral increment mode */
        .equ	 DMA_CCR2_MINC,                      0x0080	        /* Memory increment mode */

        .equ	 DMA_CCR2_PSIZE,                     0x0300	        /* PSIZE[1:0] bits (Peripheral size) */
        .equ	 DMA_CCR2_PSIZE_0,                   0x0100	        /* Bit 0 */
        .equ	 DMA_CCR2_PSIZE_1,                   0x0200	        /* Bit 1 */

        .equ	 DMA_CCR2_MSIZE,                     0x0C00	        /* MSIZE[1:0] bits (Memory size) */
        .equ	 DMA_CCR2_MSIZE_0,                   0x0400	        /* Bit 0 */
        .equ	 DMA_CCR2_MSIZE_1,                   0x0800	        /* Bit 1 */

        .equ	 DMA_CCR2_PL,                        0x3000	        /* PL[1:0] bits (Channel Priority level) */
        .equ	 DMA_CCR2_PL_0,                      0x1000	        /* Bit 0 */
        .equ	 DMA_CCR2_PL_1,                      0x2000	        /* Bit 1 */

        .equ	 DMA_CCR2_MEM2MEM,                   0x4000	        /* Memory to memory mode */

/*******************  Bit definition for DMA_CCR3 register  *******************/
        .equ	 DMA_CCR3_EN,                        0x0001	        /* Channel enable */
        .equ	 DMA_CCR3_TCIE,                      0x0002	        /* Transfer complete interrupt enable */
        .equ	 DMA_CCR3_HTIE,                      0x0004	        /* Half Transfer interrupt enable */
        .equ	 DMA_CCR3_TEIE,                      0x0008	        /* Transfer error interrupt enable */
        .equ	 DMA_CCR3_DIR,                       0x0010	        /* Data transfer direction */
        .equ	 DMA_CCR3_CIRC,                      0x0020	        /* Circular mode */
        .equ	 DMA_CCR3_PINC,                      0x0040	        /* Peripheral increment mode */
        .equ	 DMA_CCR3_MINC,                      0x0080	        /* Memory increment mode */

        .equ	 DMA_CCR3_PSIZE,                     0x0300	        /* PSIZE[1:0] bits (Peripheral size) */
        .equ	 DMA_CCR3_PSIZE_0,                   0x0100	        /* Bit 0 */
        .equ	 DMA_CCR3_PSIZE_1,                   0x0200	        /* Bit 1 */

        .equ	 DMA_CCR3_MSIZE,                     0x0C00	        /* MSIZE[1:0] bits (Memory size) */
        .equ	 DMA_CCR3_MSIZE_0,                   0x0400	        /* Bit 0 */
        .equ	 DMA_CCR3_MSIZE_1,                   0x0800	        /* Bit 1 */

        .equ	 DMA_CCR3_PL,                        0x3000	        /* PL[1:0] bits (Channel Priority level) */
        .equ	 DMA_CCR3_PL_0,                      0x1000	        /* Bit 0 */
        .equ	 DMA_CCR3_PL_1,                      0x2000	        /* Bit 1 */

        .equ	 DMA_CCR3_MEM2MEM,                   0x4000	        /* Memory to memory mode */

/*******************  Bit definition for DMA_CCR4 register  *******************/
        .equ	 DMA_CCR4_EN,                        0x0001	        /* Channel enable */
        .equ	 DMA_CCR4_TCIE,                      0x0002	        /* Transfer complete interrupt enable */
        .equ	 DMA_CCR4_HTIE,                      0x0004	        /* Half Transfer interrupt enable */
        .equ	 DMA_CCR4_TEIE,                      0x0008	        /* Transfer error interrupt enable */
        .equ	 DMA_CCR4_DIR,                       0x0010	        /* Data transfer direction */
        .equ	 DMA_CCR4_CIRC,                      0x0020	        /* Circular mode */
        .equ	 DMA_CCR4_PINC,                      0x0040	        /* Peripheral increment mode */
        .equ	 DMA_CCR4_MINC,                      0x0080	        /* Memory increment mode */

        .equ	 DMA_CCR4_PSIZE,                     0x0300	        /* PSIZE[1:0] bits (Peripheral size) */
        .equ	 DMA_CCR4_PSIZE_0,                   0x0100	        /* Bit 0 */
        .equ	 DMA_CCR4_PSIZE_1,                   0x0200	        /* Bit 1 */

        .equ	 DMA_CCR4_MSIZE,                     0x0C00	        /* MSIZE[1:0] bits (Memory size) */
        .equ	 DMA_CCR4_MSIZE_0,                   0x0400	        /* Bit 0 */
        .equ	 DMA_CCR4_MSIZE_1,                   0x0800	        /* Bit 1 */

        .equ	 DMA_CCR4_PL,                        0x3000	        /* PL[1:0] bits (Channel Priority level) */
        .equ	 DMA_CCR4_PL_0,                      0x1000	        /* Bit 0 */
        .equ	 DMA_CCR4_PL_1,                      0x2000	        /* Bit 1 */

        .equ	 DMA_CCR4_MEM2MEM,                   0x4000	        /* Memory to memory mode */

/******************  Bit definition for DMA_CCR5 register  *******************/
        .equ	 DMA_CCR5_EN,                        0x0001	        /* Channel enable */
        .equ	 DMA_CCR5_TCIE,                      0x0002	        /* Transfer complete interrupt enable */
        .equ	 DMA_CCR5_HTIE,                      0x0004	        /* Half Transfer interrupt enable */
        .equ	 DMA_CCR5_TEIE,                      0x0008	        /* Transfer error interrupt enable */
        .equ	 DMA_CCR5_DIR,                       0x0010	        /* Data transfer direction */
        .equ	 DMA_CCR5_CIRC,                      0x0020	        /* Circular mode */
        .equ	 DMA_CCR5_PINC,                      0x0040	        /* Peripheral increment mode */
        .equ	 DMA_CCR5_MINC,                      0x0080	        /* Memory increment mode */

        .equ	 DMA_CCR5_PSIZE,                     0x0300	        /* PSIZE[1:0] bits (Peripheral size) */
        .equ	 DMA_CCR5_PSIZE_0,                   0x0100	        /* Bit 0 */
        .equ	 DMA_CCR5_PSIZE_1,                   0x0200	        /* Bit 1 */

        .equ	 DMA_CCR5_MSIZE,                     0x0C00	        /* MSIZE[1:0] bits (Memory size) */
        .equ	 DMA_CCR5_MSIZE_0,                   0x0400	        /* Bit 0 */
        .equ	 DMA_CCR5_MSIZE_1,                   0x0800	        /* Bit 1 */

        .equ	 DMA_CCR5_PL,                        0x3000	        /* PL[1:0] bits (Channel Priority level) */
        .equ	 DMA_CCR5_PL_0,                      0x1000	        /* Bit 0 */
        .equ	 DMA_CCR5_PL_1,                      0x2000	        /* Bit 1 */

        .equ	 DMA_CCR5_MEM2MEM,                   0x4000	        /* Memory to memory mode enable */

/*******************  Bit definition for DMA_CCR6 register  *******************/
        .equ	 DMA_CCR6_EN,                        0x0001	        /* Channel enable */
        .equ	 DMA_CCR6_TCIE,                      0x0002	        /* Transfer complete interrupt enable */
        .equ	 DMA_CCR6_HTIE,                      0x0004	        /* Half Transfer interrupt enable */
        .equ	 DMA_CCR6_TEIE,                      0x0008	        /* Transfer error interrupt enable */
        .equ	 DMA_CCR6_DIR,                       0x0010	        /* Data transfer direction */
        .equ	 DMA_CCR6_CIRC,                      0x0020	        /* Circular mode */
        .equ	 DMA_CCR6_PINC,                      0x0040	        /* Peripheral increment mode */
        .equ	 DMA_CCR6_MINC,                      0x0080	        /* Memory increment mode */

        .equ	 DMA_CCR6_PSIZE,                     0x0300	        /* PSIZE[1:0] bits (Peripheral size) */
        .equ	 DMA_CCR6_PSIZE_0,                   0x0100	        /* Bit 0 */
        .equ	 DMA_CCR6_PSIZE_1,                   0x0200	        /* Bit 1 */

        .equ	 DMA_CCR6_MSIZE,                     0x0C00	        /* MSIZE[1:0] bits (Memory size) */
        .equ	 DMA_CCR6_MSIZE_0,                   0x0400	        /* Bit 0 */
        .equ	 DMA_CCR6_MSIZE_1,                   0x0800	        /* Bit 1 */

        .equ	 DMA_CCR6_PL,                        0x3000	        /* PL[1:0] bits (Channel Priority level) */
        .equ	 DMA_CCR6_PL_0,                      0x1000	        /* Bit 0 */
        .equ	 DMA_CCR6_PL_1,                      0x2000	        /* Bit 1 */

        .equ	 DMA_CCR6_MEM2MEM,                   0x4000	        /* Memory to memory mode */

/*******************  Bit definition for DMA_CCR7 register  *******************/
        .equ	 DMA_CCR7_EN,                        0x0001	        /* Channel enable */
        .equ	 DMA_CCR7_TCIE,                      0x0002	        /* Transfer complete interrupt enable */
        .equ	 DMA_CCR7_HTIE,                      0x0004	        /* Half Transfer interrupt enable */
        .equ	 DMA_CCR7_TEIE,                      0x0008	        /* Transfer error interrupt enable */
        .equ	 DMA_CCR7_DIR,                       0x0010	        /* Data transfer direction */
        .equ	 DMA_CCR7_CIRC,                      0x0020	        /* Circular mode */
        .equ	 DMA_CCR7_PINC,                      0x0040	        /* Peripheral increment mode */
        .equ	 DMA_CCR7_MINC,                      0x0080	        /* Memory increment mode */

        .equ	 DMA_CCR7_PSIZE            ,         0x0300	        /* PSIZE[1:0] bits (Peripheral size) */
        .equ	 DMA_CCR7_PSIZE_0,                   0x0100	        /* Bit 0 */
        .equ	 DMA_CCR7_PSIZE_1,                   0x0200	        /* Bit 1 */

        .equ	 DMA_CCR7_MSIZE,                     0x0C00	        /* MSIZE[1:0] bits (Memory size) */
        .equ	 DMA_CCR7_MSIZE_0,                   0x0400	        /* Bit 0 */
        .equ	 DMA_CCR7_MSIZE_1,                   0x0800	        /* Bit 1 */

        .equ	 DMA_CCR7_PL,                        0x3000	        /* PL[1:0] bits (Channel Priority level) */
        .equ	 DMA_CCR7_PL_0,                      0x1000	        /* Bit 0 */
        .equ	 DMA_CCR7_PL_1,                      0x2000	        /* Bit 1 */

        .equ	 DMA_CCR7_MEM2MEM,                   0x4000	        /* Memory to memory mode enable */

/******************  Bit definition for DMA_CNDTR1 register  ******************/
        .equ	 DMA_CNDTR1_NDT,                     0xFFFF	        /* Number of data to Transfer */

/******************  Bit definition for DMA_CNDTR2 register  ******************/
        .equ	 DMA_CNDTR2_NDT,                     0xFFFF	        /* Number of data to Transfer */

/******************  Bit definition for DMA_CNDTR3 register  ******************/
        .equ	 DMA_CNDTR3_NDT,                     0xFFFF	        /* Number of data to Transfer */

/******************  Bit definition for DMA_CNDTR4 register  ******************/
        .equ	 DMA_CNDTR4_NDT,                     0xFFFF	        /* Number of data to Transfer */

/******************  Bit definition for DMA_CNDTR5 register  ******************/
        .equ	 DMA_CNDTR5_NDT,                     0xFFFF	        /* Number of data to Transfer */

/******************  Bit definition for DMA_CNDTR6 register  ******************/
        .equ	 DMA_CNDTR6_NDT,                     0xFFFF	        /* Number of data to Transfer */

/******************  Bit definition for DMA_CNDTR7 register  ******************/
        .equ	 DMA_CNDTR7_NDT,                     0xFFFF	        /* Number of data to Transfer */

/******************  Bit definition for DMA_CPAR1 register  *******************/
        .equ	 DMA_CPAR1_PA,                       0xFFFFFFFF	    /* Peripheral Address */

/******************  Bit definition for DMA_CPAR2 register  *******************/
        .equ	 DMA_CPAR2_PA,                       0xFFFFFFFF	    /* Peripheral Address */

/******************  Bit definition for DMA_CPAR3 register  *******************/
        .equ	 DMA_CPAR3_PA,                       0xFFFFFFFF	    /* Peripheral Address */


/******************  Bit definition for DMA_CPAR4 register  *******************/
        .equ	 DMA_CPAR4_PA,                       0xFFFFFFFF	    /* Peripheral Address */

/******************  Bit definition for DMA_CPAR5 register  *******************/
        .equ	 DMA_CPAR5_PA,                       0xFFFFFFFF	    /* Peripheral Address */

/******************  Bit definition for DMA_CPAR6 register  *******************/
        .equ	 DMA_CPAR6_PA,                       0xFFFFFFFF	    /* Peripheral Address */


/******************  Bit definition for DMA_CPAR7 register  *******************/
        .equ	 DMA_CPAR7_PA,                       0xFFFFFFFF	    /* Peripheral Address */

/******************  Bit definition for DMA_CMAR1 register  *******************/
        .equ	 DMA_CMAR1_MA,                       0xFFFFFFFF	    /* Memory Address */

/******************  Bit definition for DMA_CMAR2 register  *******************/
        .equ	 DMA_CMAR2_MA,                       0xFFFFFFFF	    /* Memory Address */

/******************  Bit definition for DMA_CMAR3 register  *******************/
        .equ	 DMA_CMAR3_MA,                       0xFFFFFFFF	    /* Memory Address */


/******************  Bit definition for DMA_CMAR4 register  *******************/
        .equ	 DMA_CMAR4_MA,                       0xFFFFFFFF	    /* Memory Address */

/******************  Bit definition for DMA_CMAR5 register  *******************/
        .equ	 DMA_CMAR5_MA,                       0xFFFFFFFF	    /* Memory Address */

/******************  Bit definition for DMA_CMAR6 register  *******************/
        .equ	 DMA_CMAR6_MA,                       0xFFFFFFFF	    /* Memory Address */

/******************  Bit definition for DMA_CMAR7 register  *******************/
        .equ	 DMA_CMAR7_MA,                       0xFFFFFFFF	    /* Memory Address */

/******************************************************************************/
/*                                                                            */
/*                  External Interrupt/Event Controller (EXTI)                */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for EXTI_IMR register  *******************/
        .equ	 EXTI_IMR_MR0,                       0x00000001	    /* Interrupt Mask on line 0 */
        .equ	 EXTI_IMR_MR1,                       0x00000002	    /* Interrupt Mask on line 1 */
        .equ	 EXTI_IMR_MR2,                       0x00000004	    /* Interrupt Mask on line 2 */
        .equ	 EXTI_IMR_MR3,                       0x00000008	    /* Interrupt Mask on line 3 */
        .equ	 EXTI_IMR_MR4,                       0x00000010	    /* Interrupt Mask on line 4 */
        .equ	 EXTI_IMR_MR5,                       0x00000020	    /* Interrupt Mask on line 5 */
        .equ	 EXTI_IMR_MR6,                       0x00000040	    /* Interrupt Mask on line 6 */
        .equ	 EXTI_IMR_MR7,                       0x00000080	    /* Interrupt Mask on line 7 */
        .equ	 EXTI_IMR_MR8,                       0x00000100	    /* Interrupt Mask on line 8 */
        .equ	 EXTI_IMR_MR9,                       0x00000200	    /* Interrupt Mask on line 9 */
        .equ	 EXTI_IMR_MR10,                      0x00000400	    /* Interrupt Mask on line 10 */
        .equ	 EXTI_IMR_MR11,                      0x00000800	    /* Interrupt Mask on line 11 */
        .equ	 EXTI_IMR_MR12,                      0x00001000	    /* Interrupt Mask on line 12 */
        .equ	 EXTI_IMR_MR13,                      0x00002000	    /* Interrupt Mask on line 13 */
        .equ	 EXTI_IMR_MR14,                      0x00004000	    /* Interrupt Mask on line 14 */
        .equ	 EXTI_IMR_MR15,                      0x00008000	    /* Interrupt Mask on line 15 */
        .equ	 EXTI_IMR_MR16,                      0x00010000	    /* Interrupt Mask on line 16 */
        .equ	 EXTI_IMR_MR17,                      0x00020000	    /* Interrupt Mask on line 17 */
        .equ	 EXTI_IMR_MR18,                      0x00040000	    /* Interrupt Mask on line 18 */
        .equ	 EXTI_IMR_MR19,                      0x00080000	    /* Interrupt Mask on line 19 */
        .equ	 EXTI_IMR_MR20,                      0x00100000	    /* Interrupt Mask on line 20 */
        .equ	 EXTI_IMR_MR21,                      0x00200000	    /* Interrupt Mask on line 21 */
        .equ	 EXTI_IMR_MR22,                      0x00400000	    /* Interrupt Mask on line 22 */

/*******************  Bit definition for EXTI_EMR register  *******************/
        .equ	 EXTI_EMR_MR0,                       0x00000001	    /* Event Mask on line 0 */
        .equ	 EXTI_EMR_MR1,                       0x00000002	    /* Event Mask on line 1 */
        .equ	 EXTI_EMR_MR2,                       0x00000004	    /* Event Mask on line 2 */
        .equ	 EXTI_EMR_MR3,                       0x00000008	    /* Event Mask on line 3 */
        .equ	 EXTI_EMR_MR4,                       0x00000010	    /* Event Mask on line 4 */
        .equ	 EXTI_EMR_MR5,                       0x00000020	    /* Event Mask on line 5 */
        .equ	 EXTI_EMR_MR6,                       0x00000040	    /* Event Mask on line 6 */
        .equ	 EXTI_EMR_MR7,                       0x00000080	    /* Event Mask on line 7 */
        .equ	 EXTI_EMR_MR8,                       0x00000100	    /* Event Mask on line 8 */
        .equ	 EXTI_EMR_MR9,                       0x00000200	    /* Event Mask on line 9 */
        .equ	 EXTI_EMR_MR10,                      0x00000400	    /* Event Mask on line 10 */
        .equ	 EXTI_EMR_MR11,                      0x00000800	    /* Event Mask on line 11 */
        .equ	 EXTI_EMR_MR12,                      0x00001000	    /* Event Mask on line 12 */
        .equ	 EXTI_EMR_MR13,                      0x00002000	    /* Event Mask on line 13 */
        .equ	 EXTI_EMR_MR14,                      0x00004000	    /* Event Mask on line 14 */
        .equ	 EXTI_EMR_MR15,                      0x00008000	    /* Event Mask on line 15 */
        .equ	 EXTI_EMR_MR16,                      0x00010000	    /* Event Mask on line 16 */
        .equ	 EXTI_EMR_MR17,                      0x00020000	    /* Event Mask on line 17 */
        .equ	 EXTI_EMR_MR18,                      0x00040000	    /* Event Mask on line 18 */
        .equ	 EXTI_EMR_MR19,                      0x00080000	    /* Event Mask on line 19 */
        .equ	 EXTI_EMR_MR20,                      0x00100000	    /* Event Mask on line 20 */
        .equ	 EXTI_EMR_MR21,                      0x00200000	    /* Event Mask on line 21 */
        .equ	 EXTI_EMR_MR22,                      0x00400000	    /* Event Mask on line 22 */

/******************  Bit definition for EXTI_RTSR register  *******************/
        .equ	 EXTI_RTSR_TR0,                      0x00000001	    /* Rising trigger event configuration bit of line 0 */
        .equ	 EXTI_RTSR_TR1,                      0x00000002	    /* Rising trigger event configuration bit of line 1 */
        .equ	 EXTI_RTSR_TR2,                      0x00000004	    /* Rising trigger event configuration bit of line 2 */
        .equ	 EXTI_RTSR_TR3,                      0x00000008	    /* Rising trigger event configuration bit of line 3 */
        .equ	 EXTI_RTSR_TR4,                      0x00000010	    /* Rising trigger event configuration bit of line 4 */
        .equ	 EXTI_RTSR_TR5,                      0x00000020	    /* Rising trigger event configuration bit of line 5 */
        .equ	 EXTI_RTSR_TR6,                      0x00000040	    /* Rising trigger event configuration bit of line 6 */
        .equ	 EXTI_RTSR_TR7,                      0x00000080	    /* Rising trigger event configuration bit of line 7 */
        .equ	 EXTI_RTSR_TR8,                      0x00000100	    /* Rising trigger event configuration bit of line 8 */
        .equ	 EXTI_RTSR_TR9,                      0x00000200	    /* Rising trigger event configuration bit of line 9 */
        .equ	 EXTI_RTSR_TR10,                     0x00000400	    /* Rising trigger event configuration bit of line 10 */
        .equ	 EXTI_RTSR_TR11,                     0x00000800	    /* Rising trigger event configuration bit of line 11 */
        .equ	 EXTI_RTSR_TR12,                     0x00001000	    /* Rising trigger event configuration bit of line 12 */
        .equ	 EXTI_RTSR_TR13,                     0x00002000	    /* Rising trigger event configuration bit of line 13 */
        .equ	 EXTI_RTSR_TR14,                     0x00004000	    /* Rising trigger event configuration bit of line 14 */
        .equ	 EXTI_RTSR_TR15,                     0x00008000	    /* Rising trigger event configuration bit of line 15 */
        .equ	 EXTI_RTSR_TR16,                     0x00010000	    /* Rising trigger event configuration bit of line 16 */
        .equ	 EXTI_RTSR_TR17,                     0x00020000	    /* Rising trigger event configuration bit of line 17 */
        .equ	 EXTI_RTSR_TR18,                     0x00040000	    /* Rising trigger event configuration bit of line 18 */
        .equ	 EXTI_RTSR_TR19,                     0x00080000	    /* Rising trigger event configuration bit of line 19 */
        .equ	 EXTI_RTSR_TR20,                     0x00100000	    /* Rising trigger event configuration bit of line 20 */
        .equ	 EXTI_RTSR_TR21,                     0x00200000	    /* Rising trigger event configuration bit of line 21 */
        .equ	 EXTI_RTSR_TR22,                     0x00400000	    /* Rising trigger event configuration bit of line 22 */

/******************  Bit definition for EXTI_FTSR register  *******************/
        .equ	 EXTI_FTSR_TR0,                      0x00000001	    /* Falling trigger event configuration bit of line 0 */
        .equ	 EXTI_FTSR_TR1,                      0x00000002	    /* Falling trigger event configuration bit of line 1 */
        .equ	 EXTI_FTSR_TR2,                      0x00000004	    /* Falling trigger event configuration bit of line 2 */
        .equ	 EXTI_FTSR_TR3,                      0x00000008	    /* Falling trigger event configuration bit of line 3 */
        .equ	 EXTI_FTSR_TR4,                      0x00000010	    /* Falling trigger event configuration bit of line 4 */
        .equ	 EXTI_FTSR_TR5,                      0x00000020	    /* Falling trigger event configuration bit of line 5 */
        .equ	 EXTI_FTSR_TR6,                      0x00000040	    /* Falling trigger event configuration bit of line 6 */
        .equ	 EXTI_FTSR_TR7,                      0x00000080	    /* Falling trigger event configuration bit of line 7 */
        .equ	 EXTI_FTSR_TR8,                      0x00000100	    /* Falling trigger event configuration bit of line 8 */
        .equ	 EXTI_FTSR_TR9,                      0x00000200	    /* Falling trigger event configuration bit of line 9 */
        .equ	 EXTI_FTSR_TR10,                     0x00000400	    /* Falling trigger event configuration bit of line 10 */
        .equ	 EXTI_FTSR_TR11,                     0x00000800	    /* Falling trigger event configuration bit of line 11 */
        .equ	 EXTI_FTSR_TR12,                     0x00001000	    /* Falling trigger event configuration bit of line 12 */
        .equ	 EXTI_FTSR_TR13,                     0x00002000	    /* Falling trigger event configuration bit of line 13 */
        .equ	 EXTI_FTSR_TR14,                     0x00004000	    /* Falling trigger event configuration bit of line 14 */
        .equ	 EXTI_FTSR_TR15,                     0x00008000	    /* Falling trigger event configuration bit of line 15 */
        .equ	 EXTI_FTSR_TR16,                     0x00010000	    /* Falling trigger event configuration bit of line 16 */
        .equ	 EXTI_FTSR_TR17,                     0x00020000	    /* Falling trigger event configuration bit of line 17 */
        .equ	 EXTI_FTSR_TR18,                     0x00040000	    /* Falling trigger event configuration bit of line 18 */
        .equ	 EXTI_FTSR_TR19,                     0x00080000	    /* Falling trigger event configuration bit of line 19 */
        .equ	 EXTI_FTSR_TR20,                     0x00100000	    /* Falling trigger event configuration bit of line 20 */
        .equ	 EXTI_FTSR_TR21,                     0x00200000	    /* Falling trigger event configuration bit of line 21 */
        .equ	 EXTI_FTSR_TR22,                     0x00400000	    /* Falling trigger event configuration bit of line 22 */

/******************  Bit definition for EXTI_SWIER register  ******************/
        .equ	 EXTI_SWIER_SWIER0,                  0x00000001	    /* Software Interrupt on line 0 */
        .equ	 EXTI_SWIER_SWIER1,                  0x00000002	    /* Software Interrupt on line 1 */
        .equ	 EXTI_SWIER_SWIER2,                  0x00000004	    /* Software Interrupt on line 2 */
        .equ	 EXTI_SWIER_SWIER3,                  0x00000008	    /* Software Interrupt on line 3 */
        .equ	 EXTI_SWIER_SWIER4,                  0x00000010	    /* Software Interrupt on line 4 */
        .equ	 EXTI_SWIER_SWIER5,                  0x00000020	    /* Software Interrupt on line 5 */
        .equ	 EXTI_SWIER_SWIER6,                  0x00000040	    /* Software Interrupt on line 6 */
        .equ	 EXTI_SWIER_SWIER7,                  0x00000080	    /* Software Interrupt on line 7 */
        .equ	 EXTI_SWIER_SWIER8,                  0x00000100	    /* Software Interrupt on line 8 */
        .equ	 EXTI_SWIER_SWIER9,                  0x00000200	    /* Software Interrupt on line 9 */
        .equ	 EXTI_SWIER_SWIER10,                 0x00000400	    /* Software Interrupt on line 10 */
        .equ	 EXTI_SWIER_SWIER11,                 0x00000800	    /* Software Interrupt on line 11 */
        .equ	 EXTI_SWIER_SWIER12,                 0x00001000	    /* Software Interrupt on line 12 */
        .equ	 EXTI_SWIER_SWIER13,                 0x00002000	    /* Software Interrupt on line 13 */
        .equ	 EXTI_SWIER_SWIER14,                 0x00004000	    /* Software Interrupt on line 14 */
        .equ	 EXTI_SWIER_SWIER15,                 0x00008000	    /* Software Interrupt on line 15 */
        .equ	 EXTI_SWIER_SWIER16,                 0x00010000	    /* Software Interrupt on line 16 */
        .equ	 EXTI_SWIER_SWIER17,                 0x00020000	    /* Software Interrupt on line 17 */
        .equ	 EXTI_SWIER_SWIER18,                 0x00040000	    /* Software Interrupt on line 18 */
        .equ	 EXTI_SWIER_SWIER19,                 0x00080000	    /* Software Interrupt on line 19 */
        .equ	 EXTI_SWIER_SWIER20,                 0x00100000	    /* Software Interrupt on line 20 */
        .equ	 EXTI_SWIER_SWIER21,                 0x00200000	    /* Software Interrupt on line 21 */
        .equ	 EXTI_SWIER_SWIER22,                 0x00400000	    /* Software Interrupt on line 22 */

/*******************  Bit definition for EXTI_PR register  ********************/
        .equ	 EXTI_PR_PR0,                        0x00000001	    /* Pending bit 0 */
        .equ	 EXTI_PR_PR1,                        0x00000002	    /* Pending bit 1 */
        .equ	 EXTI_PR_PR2,                        0x00000004	    /* Pending bit 2 */
        .equ	 EXTI_PR_PR3,                        0x00000008	    /* Pending bit 3 */
        .equ	 EXTI_PR_PR4,                        0x00000010	    /* Pending bit 4 */
        .equ	 EXTI_PR_PR5,                        0x00000020	    /* Pending bit 5 */
        .equ	 EXTI_PR_PR6,                        0x00000040	    /* Pending bit 6 */
        .equ	 EXTI_PR_PR7,                        0x00000080	    /* Pending bit 7 */
        .equ	 EXTI_PR_PR8,                        0x00000100	    /* Pending bit 8 */
        .equ	 EXTI_PR_PR9,                        0x00000200	    /* Pending bit 9 */
        .equ	 EXTI_PR_PR10,                       0x00000400	    /* Pending bit 10 */
        .equ	 EXTI_PR_PR11,                       0x00000800	    /* Pending bit 11 */
        .equ	 EXTI_PR_PR12,                       0x00001000	    /* Pending bit 12 */
        .equ	 EXTI_PR_PR13,                       0x00002000	    /* Pending bit 13 */
        .equ	 EXTI_PR_PR14,                       0x00004000	    /* Pending bit 14 */
        .equ	 EXTI_PR_PR15,                       0x00008000	    /* Pending bit 15 */
        .equ	 EXTI_PR_PR16,                       0x00010000	    /* Pending bit 16 */
        .equ	 EXTI_PR_PR17,                       0x00020000	    /* Pending bit 17 */
        .equ	 EXTI_PR_PR18,                       0x00040000	    /* Pending bit 18 */
        .equ	 EXTI_PR_PR19,                       0x00080000	    /* Pending bit 19 */
        .equ	 EXTI_PR_PR20,                       0x00100000	    /* Pending bit 20 */
        .equ	 EXTI_PR_PR21,                       0x00200000	    /* Pending bit 21 */
        .equ	 EXTI_PR_PR22,                       0x00400000	    /* Pending bit 22 */

/******************************************************************************/
/*                                                                            */
/*                FLASH, DATA EEPROM and Option Bytes Registers               */
/*,                       (FLASH, DATA_EEPROM, OB)                            */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for FLASH_ACR register  ******************/
        .equ	 FLASH_ACR_LATENCY,                  0x00000001	    /* Latency */
        .equ	 FLASH_ACR_PRFTEN,                   0x00000002	    /* Prefetch Buffer Enable */
        .equ	 FLASH_ACR_ACC64,                    0x00000004	    /* Access 64 bits */
        .equ	 FLASH_ACR_SLEEP_PD,                 0x00000008	    /* Flash mode during sleep mode */
        .equ	 FLASH_ACR_RUN_PD,                   0x00000010	    /* Flash mode during RUN mode */

/*******************  Bit definition for FLASH_PECR register  ******************/
        .equ	FLASH_PECR_PELOCK,                   0x00000001	    /* FLASH_PECR and Flash data Lock */
        .equ	FLASH_PECR_PRGLOCK,                  0x00000002	    /* Program matrix Lock */
        .equ	FLASH_PECR_OPTLOCK,                  0x00000004	    /* Option byte matrix Lock */
        .equ	FLASH_PECR_PROG,                     0x00000008	    /* Program matrix selection */
        .equ	FLASH_PECR_DATA,                     0x00000010	    /* Data matrix selection */
        .equ	FLASH_PECR_FTDW,                     0x00000100	    /* Fixed Time Data write for Word/Half Word/Byte programming */
        .equ	FLASH_PECR_ERASE,                    0x00000200	    /* Page erasing mode */
        .equ	FLASH_PECR_FPRG,                     0x00000400	    /* Fast Page/Half Page programming mode */
        .equ	FLASH_PECR_EOPIE,                    0x00010000	    /* End of programming interrupt */ 
        .equ	FLASH_PECR_ERRIE,                    0x00020000	    /* Error interrupt */ 
        .equ	FLASH_PECR_OBL_LAUNCH,               0x00040000	    /* Launch the option byte loading */ 

/******************  Bit definition for FLASH_PDKEYR register  ******************/
        .equ	 FLASH_PDKEYR_PDKEYR,                0xFFFFFFFF	   /* FLASH_PEC and data matrix Key */

/******************  Bit definition for FLASH_PEKEYR register  ******************/
        .equ	 FLASH_PEKEYR_PEKEYR,                0xFFFFFFFF	   /* FLASH_PEC and data matrix Key */

/******************  Bit definition for FLASH_PRGKEYR register  ******************/
        .equ	 FLASH_PRGKEYR_PRGKEYR,              0xFFFFFFFF	    /* Program matrix Key */

/******************  Bit definition for FLASH_OPTKEYR register  ******************/
        .equ	 FLASH_OPTKEYR_OPTKEYR,              0xFFFFFFFF	    /* Option bytes matrix Key */

/******************  Bit definition for FLASH_SR register  *******************/
        .equ	 FLASH_SR_BSY,                       0x00000001	    /* Busy */
        .equ	 FLASH_SR_EOP,                       0x00000002	    /* End Of Programming*/
        .equ	 FLASH_SR_ENHV,                      0x00000004	    /* End of high voltage */
        .equ	 FLASH_SR_READY,                     0x00000008	    /* Flash ready after low power mode */

        .equ	 FLASH_SR_WRPERR,                    0x00000100	    /* Write protected error */
        .equ	 FLASH_SR_PGAERR,                    0x00000200	    /* Programming Alignment Error */
        .equ	 FLASH_SR_SIZERR,                    0x00000400	    /* Size error */
        .equ	 FLASH_SR_OPTVERR,                   0x00000800	    /* Option validity error */

/******************  Bit definition for FLASH_OBR register  *******************/
        .equ	 FLASH_OBR_RDPRT,                    0x000000AA	    /* Read Protection */
        .equ	 FLASH_OBR_BOR_LEV,                  0x000F0000	    /* BOR_LEV[3:0] Brown Out Reset Threshold Level*/
        .equ	 FLASH_OBR_USER,                     0x00700000	    /* User Option Bytes */
        .equ	 FLASH_OBR_IWDG_SW,                  0x00100000	    /* IWDG_SW */
        .equ	 FLASH_OBR_nRST_STOP,                0x00200000	    /* nRST_STOP */
        .equ	 FLASH_OBR_nRST_STDBY,               0x00400000	    /* nRST_STDBY */

/******************  Bit definition for FLASH_WRPR register  ******************/
        .equ	 FLASH_WRPR_WRP,                     0xFFFFFFFF	    /* Write Protect */

/******************************************************************************/
/*                                                                            */
/*                      General Purpose IOs (GPIO)                            */
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for GPIO_MODER register  *****************/  
        .equ	GPIO_MODER_MODER0,         0x00000003
        .equ	GPIO_MODER_MODER0_0,       0x00000001
        .equ	GPIO_MODER_MODER0_1,       0x00000002
        .equ	GPIO_MODER_MODER1,         0x0000000C
        .equ	GPIO_MODER_MODER1_0,       0x00000004
        .equ	GPIO_MODER_MODER1_1,       0x00000008
        .equ	GPIO_MODER_MODER2,         0x00000030
        .equ	GPIO_MODER_MODER2_0,       0x00000010
        .equ	GPIO_MODER_MODER2_1,       0x00000020
        .equ	GPIO_MODER_MODER3,         0x000000C0
        .equ	GPIO_MODER_MODER3_0,       0x00000040
        .equ	GPIO_MODER_MODER3_1,       0x00000080
        .equ	GPIO_MODER_MODER4,         0x00000300
        .equ	GPIO_MODER_MODER4_0,       0x00000100
        .equ	GPIO_MODER_MODER4_1,       0x00000200
        .equ	GPIO_MODER_MODER5,         0x00000C00
        .equ	GPIO_MODER_MODER5_0,       0x00000400
        .equ	GPIO_MODER_MODER5_1,       0x00000800
        .equ	GPIO_MODER_MODER6,         0x00003000
        .equ	GPIO_MODER_MODER6_0,       0x00001000
        .equ	GPIO_MODER_MODER6_1,       0x00002000
        .equ	GPIO_MODER_MODER7,         0x0000C000
        .equ	GPIO_MODER_MODER7_0,       0x00004000
        .equ	GPIO_MODER_MODER7_1,       0x00008000
        .equ	GPIO_MODER_MODER8,         0x00030000
        .equ	GPIO_MODER_MODER8_0,       0x00010000
        .equ	GPIO_MODER_MODER8_1,       0x00020000
        .equ	GPIO_MODER_MODER9,         0x000C0000
        .equ	GPIO_MODER_MODER9_0,       0x00040000
        .equ	GPIO_MODER_MODER9_1,       0x00080000
        .equ	GPIO_MODER_MODER10,        0x00300000
        .equ	GPIO_MODER_MODER10_0,      0x00100000
        .equ	GPIO_MODER_MODER10_1,      0x00200000
        .equ	GPIO_MODER_MODER11,        0x00C00000
        .equ	GPIO_MODER_MODER11_0,      0x00400000
        .equ	GPIO_MODER_MODER11_1,      0x00800000
        .equ	GPIO_MODER_MODER12,        0x03000000
        .equ	GPIO_MODER_MODER12_0,      0x01000000
        .equ	GPIO_MODER_MODER12_1,      0x02000000
        .equ	GPIO_MODER_MODER13,        0x0C000000
        .equ	GPIO_MODER_MODER13_0,      0x04000000
        .equ	GPIO_MODER_MODER13_1,      0x08000000
        .equ	GPIO_MODER_MODER14,        0x30000000
        .equ	GPIO_MODER_MODER14_0,      0x10000000
        .equ	GPIO_MODER_MODER14_1,      0x20000000
        .equ	GPIO_MODER_MODER15,        0xC0000000
        .equ	GPIO_MODER_MODER15_0,      0x40000000
        .equ	GPIO_MODER_MODER15_1,      0x80000000

/*******************  Bit definition for GPIO_OTYPER register  ****************/   
        .equ	GPIO_OTYPER_OT_0,          0x00000001
        .equ	GPIO_OTYPER_OT_1,          0x00000002
        .equ	GPIO_OTYPER_OT_2,          0x00000004
        .equ	GPIO_OTYPER_OT_3,          0x00000008
        .equ	GPIO_OTYPER_OT_4,          0x00000010
        .equ	GPIO_OTYPER_OT_5,          0x00000020
        .equ	GPIO_OTYPER_OT_6,          0x00000040
        .equ	GPIO_OTYPER_OT_7,          0x00000080
        .equ	GPIO_OTYPER_OT_8,          0x00000100
        .equ	GPIO_OTYPER_OT_9,          0x00000200
        .equ	GPIO_OTYPER_OT_10,         0x00000400
        .equ	GPIO_OTYPER_OT_11,         0x00000800
        .equ	GPIO_OTYPER_OT_12,         0x00001000
        .equ	GPIO_OTYPER_OT_13,         0x00002000
        .equ	GPIO_OTYPER_OT_14,         0x00004000
        .equ	GPIO_OTYPER_OT_15,         0x00008000

/*******************  Bit definition for GPIO_OSPEEDR register  ***************/  
        .equ	GPIO_OSPEEDR_OSPEEDR0,    0x00000003
        .equ	GPIO_OSPEEDR_OSPEEDR0_0,  0x00000001
        .equ	GPIO_OSPEEDR_OSPEEDR0_1,  0x00000002
        .equ	GPIO_OSPEEDR_OSPEEDR1,    0x0000000C
        .equ	GPIO_OSPEEDR_OSPEEDR1_0,  0x00000004
        .equ	GPIO_OSPEEDR_OSPEEDR1_1,  0x00000008
        .equ	GPIO_OSPEEDR_OSPEEDR2,    0x00000030
        .equ	GPIO_OSPEEDR_OSPEEDR2_0,  0x00000010
        .equ	GPIO_OSPEEDR_OSPEEDR2_1,  0x00000020
        .equ	GPIO_OSPEEDR_OSPEEDR3,    0x000000C0
        .equ	GPIO_OSPEEDR_OSPEEDR3_0,  0x00000040
        .equ	GPIO_OSPEEDR_OSPEEDR3_1,  0x00000080
        .equ	GPIO_OSPEEDR_OSPEEDR4,    0x00000300
        .equ	GPIO_OSPEEDR_OSPEEDR4_0,  0x00000100
        .equ	GPIO_OSPEEDR_OSPEEDR4_1,  0x00000200
        .equ	GPIO_OSPEEDR_OSPEEDR5,    0x00000C00
        .equ	GPIO_OSPEEDR_OSPEEDR5_0,  0x00000400
        .equ	GPIO_OSPEEDR_OSPEEDR5_1,  0x00000800
        .equ	GPIO_OSPEEDR_OSPEEDR6,    0x00003000
        .equ	GPIO_OSPEEDR_OSPEEDR6_0,  0x00001000
        .equ	GPIO_OSPEEDR_OSPEEDR6_1,  0x00002000
        .equ	GPIO_OSPEEDR_OSPEEDR7,    0x0000C000
        .equ	GPIO_OSPEEDR_OSPEEDR7_0,  0x00004000
        .equ	GPIO_OSPEEDR_OSPEEDR7_1,  0x00008000
        .equ	GPIO_OSPEEDR_OSPEEDR8,    0x00030000
        .equ	GPIO_OSPEEDR_OSPEEDR8_0,  0x00010000
        .equ	GPIO_OSPEEDR_OSPEEDR8_1,  0x00020000
        .equ	GPIO_OSPEEDR_OSPEEDR9,    0x000C0000
        .equ	GPIO_OSPEEDR_OSPEEDR9_0,  0x00040000
        .equ	GPIO_OSPEEDR_OSPEEDR9_1,  0x00080000
        .equ	GPIO_OSPEEDR_OSPEEDR10,   0x00300000
        .equ	GPIO_OSPEEDR_OSPEEDR10_0, 0x00100000
        .equ	GPIO_OSPEEDR_OSPEEDR10_1, 0x00200000
        .equ	GPIO_OSPEEDR_OSPEEDR11,   0x00C00000
        .equ	GPIO_OSPEEDR_OSPEEDR11_0, 0x00400000
        .equ	GPIO_OSPEEDR_OSPEEDR11_1, 0x00800000
        .equ	GPIO_OSPEEDR_OSPEEDR12,   0x03000000
        .equ	GPIO_OSPEEDR_OSPEEDR12_0, 0x01000000
        .equ	GPIO_OSPEEDR_OSPEEDR12_1, 0x02000000
        .equ	GPIO_OSPEEDR_OSPEEDR13,   0x0C000000
        .equ	GPIO_OSPEEDR_OSPEEDR13_0, 0x04000000
        .equ	GPIO_OSPEEDR_OSPEEDR13_1, 0x08000000
        .equ	GPIO_OSPEEDR_OSPEEDR14,   0x30000000
        .equ	GPIO_OSPEEDR_OSPEEDR14_0, 0x10000000
        .equ	GPIO_OSPEEDR_OSPEEDR14_1, 0x20000000
        .equ	GPIO_OSPEEDR_OSPEEDR15,   0xC0000000
        .equ	GPIO_OSPEEDR_OSPEEDR15_0, 0x40000000
        .equ	GPIO_OSPEEDR_OSPEEDR15_1, 0x80000000

/*******************  Bit definition for GPIO_PUPDR register  *****************/  
        .equ	GPIO_PUPDR_PUPDR0,         0x00000003
        .equ	GPIO_PUPDR_PUPDR0_0,       0x00000001
        .equ	GPIO_PUPDR_PUPDR0_1,       0x00000002
        .equ	GPIO_PUPDR_PUPDR1,         0x0000000C
        .equ	GPIO_PUPDR_PUPDR1_0,       0x00000004
        .equ	GPIO_PUPDR_PUPDR1_1,       0x00000008
        .equ	GPIO_PUPDR_PUPDR2,         0x00000030
        .equ	GPIO_PUPDR_PUPDR2_0,       0x00000010
        .equ	GPIO_PUPDR_PUPDR2_1,       0x00000020
        .equ	GPIO_PUPDR_PUPDR3,         0x000000C0
        .equ	GPIO_PUPDR_PUPDR3_0,       0x00000040
        .equ	GPIO_PUPDR_PUPDR3_1,       0x00000080
        .equ	GPIO_PUPDR_PUPDR4,         0x00000300
        .equ	GPIO_PUPDR_PUPDR4_0,       0x00000100
        .equ	GPIO_PUPDR_PUPDR4_1,       0x00000200
        .equ	GPIO_PUPDR_PUPDR5,         0x00000C00
        .equ	GPIO_PUPDR_PUPDR5_0,       0x00000400
        .equ	GPIO_PUPDR_PUPDR5_1,       0x00000800
        .equ	GPIO_PUPDR_PUPDR6,         0x00003000
        .equ	GPIO_PUPDR_PUPDR6_0,       0x00001000
        .equ	GPIO_PUPDR_PUPDR6_1,       0x00002000
        .equ	GPIO_PUPDR_PUPDR7,         0x0000C000
        .equ	GPIO_PUPDR_PUPDR7_0,       0x00004000
        .equ	GPIO_PUPDR_PUPDR7_1,       0x00008000
        .equ	GPIO_PUPDR_PUPDR8,         0x00030000
        .equ	GPIO_PUPDR_PUPDR8_0,       0x00010000
        .equ	GPIO_PUPDR_PUPDR8_1,       0x00020000
        .equ	GPIO_PUPDR_PUPDR9,         0x000C0000
        .equ	GPIO_PUPDR_PUPDR9_0,       0x00040000
        .equ	GPIO_PUPDR_PUPDR9_1,       0x00080000
        .equ	GPIO_PUPDR_PUPDR10,        0x00300000
        .equ	GPIO_PUPDR_PUPDR10_0,      0x00100000
        .equ	GPIO_PUPDR_PUPDR10_1,      0x00200000
        .equ	GPIO_PUPDR_PUPDR11,        0x00C00000
        .equ	GPIO_PUPDR_PUPDR11_0,      0x00400000
        .equ	GPIO_PUPDR_PUPDR11_1,      0x00800000
        .equ	GPIO_PUPDR_PUPDR12,        0x03000000
        .equ	GPIO_PUPDR_PUPDR12_0,      0x01000000
        .equ	GPIO_PUPDR_PUPDR12_1,      0x02000000
        .equ	GPIO_PUPDR_PUPDR13,        0x0C000000
        .equ	GPIO_PUPDR_PUPDR13_0,      0x04000000
        .equ	GPIO_PUPDR_PUPDR13_1,      0x08000000
        .equ	GPIO_PUPDR_PUPDR14,        0x30000000
        .equ	GPIO_PUPDR_PUPDR14_0,      0x10000000
        .equ	GPIO_PUPDR_PUPDR14_1,      0x20000000
        .equ	GPIO_PUPDR_PUPDR15,        0xC0000000
        .equ	GPIO_PUPDR_PUPDR15_0,      0x40000000
        .equ	GPIO_PUPDR_PUPDR15_1,      0x80000000

/*******************  Bit definition for GPIO_IDR register  *******************/  
        .equ	GPIO_OTYPER_IDR_0,         0x00000001
        .equ	GPIO_OTYPER_IDR_1,         0x00000002
        .equ	GPIO_OTYPER_IDR_2,         0x00000004
        .equ	GPIO_OTYPER_IDR_3,         0x00000008
        .equ	GPIO_OTYPER_IDR_4,         0x00000010
        .equ	GPIO_OTYPER_IDR_5,         0x00000020
        .equ	GPIO_OTYPER_IDR_6,         0x00000040
        .equ	GPIO_OTYPER_IDR_7,         0x00000080
        .equ	GPIO_OTYPER_IDR_8,         0x00000100
        .equ	GPIO_OTYPER_IDR_9,         0x00000200
        .equ	GPIO_OTYPER_IDR_10,        0x00000400
        .equ	GPIO_OTYPER_IDR_11,        0x00000800
        .equ	GPIO_OTYPER_IDR_12,        0x00001000
        .equ	GPIO_OTYPER_IDR_13,        0x00002000
        .equ	GPIO_OTYPER_IDR_14,        0x00004000
        .equ	GPIO_OTYPER_IDR_15,        0x00008000

/*******************  Bit definition for GPIO_ODR register  *******************/   
        .equ	GPIO_OTYPER_ODR_0,         0x00000001
        .equ	GPIO_OTYPER_ODR_1,         0x00000002
        .equ	GPIO_OTYPER_ODR_2,         0x00000004
        .equ	GPIO_OTYPER_ODR_3,         0x00000008
        .equ	GPIO_OTYPER_ODR_4,         0x00000010
        .equ	GPIO_OTYPER_ODR_5,         0x00000020
        .equ	GPIO_OTYPER_ODR_6,         0x00000040
        .equ	GPIO_OTYPER_ODR_7,         0x00000080
        .equ	GPIO_OTYPER_ODR_8,         0x00000100
        .equ	GPIO_OTYPER_ODR_9,         0x00000200
        .equ	GPIO_OTYPER_ODR_10,        0x00000400
        .equ	GPIO_OTYPER_ODR_11,        0x00000800
        .equ	GPIO_OTYPER_ODR_12,        0x00001000
        .equ	GPIO_OTYPER_ODR_13,        0x00002000
        .equ	GPIO_OTYPER_ODR_14,        0x00004000
        .equ	GPIO_OTYPER_ODR_15,        0x00008000

/*******************  Bit definition for GPIO_BSRR register  ******************/  
        .equ	GPIO_BSRR_BS_0,            0x00000001
        .equ	GPIO_BSRR_BS_1,            0x00000002
        .equ	GPIO_BSRR_BS_2,            0x00000004
        .equ	GPIO_BSRR_BS_3,            0x00000008
        .equ	GPIO_BSRR_BS_4,            0x00000010
        .equ	GPIO_BSRR_BS_5,            0x00000020
        .equ	GPIO_BSRR_BS_6,            0x00000040
        .equ	GPIO_BSRR_BS_7,            0x00000080
        .equ	GPIO_BSRR_BS_8,            0x00000100
        .equ	GPIO_BSRR_BS_9,            0x00000200
        .equ	GPIO_BSRR_BS_10,           0x00000400
        .equ	GPIO_BSRR_BS_11,           0x00000800
        .equ	GPIO_BSRR_BS_12,           0x00001000
        .equ	GPIO_BSRR_BS_13,           0x00002000
        .equ	GPIO_BSRR_BS_14,           0x00004000
        .equ	GPIO_BSRR_BS_15,           0x00008000
        .equ	GPIO_BSRR_BR_0,            0x00010000
        .equ	GPIO_BSRR_BR_1,            0x00020000
        .equ	GPIO_BSRR_BR_2,            0x00040000
        .equ	GPIO_BSRR_BR_3,            0x00080000
        .equ	GPIO_BSRR_BR_4,            0x00100000
        .equ	GPIO_BSRR_BR_5,            0x00200000
        .equ	GPIO_BSRR_BR_6,            0x00400000
        .equ	GPIO_BSRR_BR_7,            0x00800000
        .equ	GPIO_BSRR_BR_8,            0x01000000
        .equ	GPIO_BSRR_BR_9,            0x02000000
        .equ	GPIO_BSRR_BR_10,           0x04000000
        .equ	GPIO_BSRR_BR_11,           0x08000000
        .equ	GPIO_BSRR_BR_12,           0x10000000
        .equ	GPIO_BSRR_BR_13,           0x20000000
        .equ	GPIO_BSRR_BR_14,           0x40000000
        .equ	GPIO_BSRR_BR_15,           0x80000000

/*******************  Bit definition for GPIO_LCKR register  ******************/
        .equ	GPIO_LCKR_LCK0,            0x00000001
        .equ	GPIO_LCKR_LCK1,            0x00000002
        .equ	GPIO_LCKR_LCK2,            0x00000004
        .equ	GPIO_LCKR_LCK3,            0x00000008
        .equ	GPIO_LCKR_LCK4,            0x00000010
        .equ	GPIO_LCKR_LCK5,            0x00000020
        .equ	GPIO_LCKR_LCK6,            0x00000040
        .equ	GPIO_LCKR_LCK7,            0x00000080
        .equ	GPIO_LCKR_LCK8,            0x00000100
        .equ	GPIO_LCKR_LCK9,            0x00000200
        .equ	GPIO_LCKR_LCK10,           0x00000400
        .equ	GPIO_LCKR_LCK11,           0x00000800
        .equ	GPIO_LCKR_LCK12,           0x00001000
        .equ	GPIO_LCKR_LCK13,           0x00002000
        .equ	GPIO_LCKR_LCK14,           0x00004000
        .equ	GPIO_LCKR_LCK15,           0x00008000
        .equ	GPIO_LCKR_LCKK,            0x00010000

/*******************  Bit definition for GPIO_AFRL register  ******************/
        .equ	GPIO_AFRL_AFRL0,           0x0000000F
        .equ	GPIO_AFRL_AFRL1,           0x000000F0
        .equ	GPIO_AFRL_AFRL2,           0x00000F00
        .equ	GPIO_AFRL_AFRL3,           0x0000F000
        .equ	GPIO_AFRL_AFRL4,           0x000F0000
        .equ	GPIO_AFRL_AFRL5,           0x00F00000
        .equ	GPIO_AFRL_AFRL6,           0x0F000000
        .equ	GPIO_AFRL_AFRL7,           0xF0000000

/*******************  Bit definition for GPIO_AFRH register  ******************/
        .equ	GPIO_AFRH_AFRH8,           0x0000000F
        .equ	GPIO_AFRH_AFRH9,           0x000000F0
        .equ	GPIO_AFRH_AFRH10,          0x00000F00
        .equ	GPIO_AFRH_AFRH11,          0x0000F000
        .equ	GPIO_AFRH_AFRH12,          0x000F0000
        .equ	GPIO_AFRH_AFRH13,          0x00F00000
        .equ	GPIO_AFRH_AFRH14,          0x0F000000
        .equ	GPIO_AFRH_AFRH15,          0xF0000000

/******************************************************************************/
/*                                                                            */
/*                   Inter-integrated Circuit Interface (I2C)                 */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for I2C_CR1 register  ********************/
        .equ	 I2C_CR1_PE,                         0x0001	        /* Peripheral Enable */
        .equ	 I2C_CR1_SMBUS,                      0x0002	        /* SMBus Mode */
        .equ	 I2C_CR1_SMBTYPE,                    0x0008	        /* SMBus Type */
        .equ	 I2C_CR1_ENARP,                      0x0010	        /* ARP Enable */
        .equ	 I2C_CR1_ENPEC,                      0x0020	        /* PEC Enable */
        .equ	 I2C_CR1_ENGC,                       0x0040	        /* General Call Enable */
        .equ	 I2C_CR1_NOSTRETCH,                  0x0080	        /* Clock Stretching Disable (Slave mode) */
        .equ	 I2C_CR1_START,                      0x0100	        /* Start Generation */
        .equ	 I2C_CR1_STOP,                       0x0200	        /* Stop Generation */
        .equ	 I2C_CR1_ACK,                        0x0400	        /* Acknowledge Enable */
        .equ	 I2C_CR1_POS,                        0x0800	        /* Acknowledge/PEC Position (for data reception) */
        .equ	 I2C_CR1_PEC,                        0x1000	        /* Packet Error Checking */
        .equ	 I2C_CR1_ALERT,                      0x2000	        /* SMBus Alert */
        .equ	 I2C_CR1_SWRST,                      0x8000	        /* Software Reset */

/*******************  Bit definition for I2C_CR2 register  ********************/
        .equ	 I2C_CR2_FREQ,                       0x003F	        /* FREQ[5:0] bits (Peripheral Clock Frequency) */
        .equ	 I2C_CR2_FREQ_0,                     0x0001	        /* Bit 0 */
        .equ	 I2C_CR2_FREQ_1,                     0x0002	        /* Bit 1 */
        .equ	 I2C_CR2_FREQ_2,                     0x0004	        /* Bit 2 */
        .equ	 I2C_CR2_FREQ_3,                     0x0008	        /* Bit 3 */
        .equ	 I2C_CR2_FREQ_4,                     0x0010	        /* Bit 4 */
        .equ	 I2C_CR2_FREQ_5,                     0x0020	        /* Bit 5 */

        .equ	 I2C_CR2_ITERREN,                    0x0100	        /* Error Interrupt Enable */
        .equ	 I2C_CR2_ITEVTEN,                    0x0200	        /* Event Interrupt Enable */
        .equ	 I2C_CR2_ITBUFEN,                    0x0400	        /* Buffer Interrupt Enable */
        .equ	 I2C_CR2_DMAEN,                      0x0800	        /* DMA Requests Enable */
        .equ	 I2C_CR2_LAST,                       0x1000	        /* DMA Last Transfer */

/*******************  Bit definition for I2C_OAR1 register  *******************/
        .equ	 I2C_OAR1_ADD1_7,                    0x00FE	        /* Interface Address */
        .equ	 I2C_OAR1_ADD8_9,                    0x0300	        /* Interface Address */

        .equ	 I2C_OAR1_ADD0,                      0x0001	        /* Bit 0 */
        .equ	 I2C_OAR1_ADD1,                      0x0002	        /* Bit 1 */
        .equ	 I2C_OAR1_ADD2,                      0x0004	        /* Bit 2 */
        .equ	 I2C_OAR1_ADD3,                      0x0008	        /* Bit 3 */
        .equ	 I2C_OAR1_ADD4,                      0x0010	        /* Bit 4 */
        .equ	 I2C_OAR1_ADD5,                      0x0020	        /* Bit 5 */
        .equ	 I2C_OAR1_ADD6,                      0x0040	        /* Bit 6 */
        .equ	 I2C_OAR1_ADD7,                      0x0080	        /* Bit 7 */
        .equ	 I2C_OAR1_ADD8,                      0x0100	        /* Bit 8 */
        .equ	 I2C_OAR1_ADD9,                      0x0200	        /* Bit 9 */

        .equ	 I2C_OAR1_ADDMODE,                   0x8000	        /* Addressing Mode (Slave mode) */

/*******************  Bit definition for I2C_OAR2 register  *******************/
        .equ	 I2C_OAR2_ENDUAL,                    0x01	           /* Dual addressing mode enable */
        .equ	 I2C_OAR2_ADD2,                      0xFE	           /* Interface address */

/********************  Bit definition for I2C_DR register  ********************/
        .equ	 I2C_DR_DR,                          0xFF	           /* 8-bit Data Register */

/*******************  Bit definition for I2C_SR1 register  ********************/
        .equ	 I2C_SR1_SB,                         0x0001	        /* Start Bit (Master mode) */
        .equ	 I2C_SR1_ADDR,                       0x0002	        /* Address sent (master mode)/matched (slave mode) */
        .equ	 I2C_SR1_BTF,                        0x0004	        /* Byte Transfer Finished */
        .equ	 I2C_SR1_ADD10,                      0x0008	        /* 10-bit header sent (Master mode) */
        .equ	 I2C_SR1_STOPF,                      0x0010	        /* Stop detection (Slave mode) */
        .equ	 I2C_SR1_RXNE,                       0x0040	        /* Data Register not Empty (receivers) */
        .equ	 I2C_SR1_TXE,                        0x0080	        /* Data Register Empty (transmitters) */
        .equ	 I2C_SR1_BERR,                       0x0100	        /* Bus Error */
        .equ	 I2C_SR1_ARLO,                       0x0200	        /* Arbitration Lost (master mode) */
        .equ	 I2C_SR1_AF,                         0x0400	        /* Acknowledge Failure */
        .equ	 I2C_SR1_OVR,                        0x0800	        /* Overrun/Underrun */
        .equ	 I2C_SR1_PECERR,                     0x1000	        /* PEC Error in reception */
        .equ	 I2C_SR1_TIMEOUT,                    0x4000	        /* Timeout or Tlow Error */
        .equ	 I2C_SR1_SMBALERT,                   0x8000	        /* SMBus Alert */

/*******************  Bit definition for I2C_SR2 register  ********************/
        .equ	 I2C_SR2_MSL,                        0x0001	        /* Master/Slave */
        .equ	 I2C_SR2_BUSY,                       0x0002	        /* Bus Busy */
        .equ	 I2C_SR2_TRA,                        0x0004	        /* Transmitter/Receiver */
        .equ	 I2C_SR2_GENCALL,                    0x0010	        /* General Call Address (Slave mode) */
        .equ	 I2C_SR2_SMBDEFAULT,                 0x0020	        /* SMBus Device Default Address (Slave mode) */
        .equ	 I2C_SR2_SMBHOST,                    0x0040	        /* SMBus Host Header (Slave mode) */
        .equ	 I2C_SR2_DUALF,                      0x0080	        /* Dual Flag (Slave mode) */
        .equ	 I2C_SR2_PEC,                        0xFF00	        /* Packet Error Checking Register */

/*******************  Bit definition for I2C_CCR register  ********************/
        .equ	 I2C_CCR_CCR,                        0x0FFF	        /* Clock Control Register in Fast/Standard mode (Master mode) */
        .equ	 I2C_CCR_DUTY,                       0x4000	        /* Fast Mode Duty Cycle */
        .equ	 I2C_CCR_FS,                         0x8000	        /* I2C Master Mode Selection */

/******************  Bit definition for I2C_TRISE register  *******************/
        .equ	 I2C_TRISE_TRISE,                    0x3F	           /* Maximum Rise Time in Fast/Standard mode (Master mode) */

/******************************************************************************/
/*                                                                            */
/*                        Independent WATCHDOG (IWDG)                         */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for IWDG_KR register  ********************/
        .equ	 IWDG_KR_KEY,                        0xFFFF	        /* Key value (write only, read 0000h) */

/*******************  Bit definition for IWDG_PR register  ********************/
        .equ	 IWDG_PR_PR,                         0x07	           /* PR[2:0] (Prescaler divider) */
        .equ	 IWDG_PR_PR_0,                       0x01	           /* Bit 0 */
        .equ	 IWDG_PR_PR_1,                       0x02	           /* Bit 1 */
        .equ	 IWDG_PR_PR_2,                       0x04	           /* Bit 2 */

/*******************  Bit definition for IWDG_RLR register  *******************/
        .equ	 IWDG_RLR_RL,                        0x0FFF	        /* Watchdog counter reload value */

/*******************  Bit definition for IWDG_SR register  ********************/
        .equ	 IWDG_SR_PVU,                        0x01	           /* Watchdog prescaler value update */
        .equ	 IWDG_SR_RVU,                        0x02	           /* Watchdog counter reload value update */

/******************************************************************************/
/*                                                                            */
/*                          LCD Controller (LCD)                              */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for LCD_CR register  *********************/
        .equ	LCD_CR_LCDEN,              0x00000001	 /* LCD Enable Bit */
        .equ	LCD_CR_VSEL,               0x00000002	 /* Voltage source selector Bit */

        .equ	LCD_CR_DUTY,               0x0000001C	 /* DUTY[2:0] bits (Duty selector) */
        .equ	LCD_CR_DUTY_0,             0x00000004	 /* Duty selector Bit 0 */
        .equ	LCD_CR_DUTY_1,             0x00000008	 /* Duty selector Bit 1 */
        .equ	LCD_CR_DUTY_2,             0x00000010	 /* Duty selector Bit 2 */

        .equ	LCD_CR_BIAS,               0x00000060	 /* BIAS[1:0] bits (Bias selector) */
        .equ	LCD_CR_BIAS_0,             0x00000020	 /* Bias selector Bit 0 */
        .equ	LCD_CR_BIAS_1,             0x00000040	 /* Bias selector Bit 1 */

        .equ	LCD_CR_MUX_SEG,            0x00000080	 /* Mux Segment Enable Bit */

/*******************  Bit definition for LCD_FCR register  ********************/
        .equ	LCD_FCR_HD,                0x00000001	 /* High Drive Enable Bit */
        .equ	LCD_FCR_SOFIE,             0x00000002	 /* Start of Frame Interrupt Enable Bit */
        .equ	LCD_FCR_UDDIE,             0x00000008	 /* Update Display Done Interrupt Enable Bit */

        .equ	LCD_FCR_PON,               0x00000070	 /* PON[2:0] bits (Puls ON Duration) */
        .equ	LCD_FCR_PON_0,             0x00000010	 /* Bit 0 */
        .equ	LCD_FCR_PON_1,             0x00000020	 /* Bit 1 */
        .equ	LCD_FCR_PON_2,             0x00000040	 /* Bit 2 */

        .equ	LCD_FCR_DEAD,              0x00000380	 /* DEAD[2:0] bits (DEAD Time) */
        .equ	LCD_FCR_DEAD_0,            0x00000080	 /* Bit 0 */
        .equ	LCD_FCR_DEAD_1,            0x00000100	 /* Bit 1 */
        .equ	LCD_FCR_DEAD_2,            0x00000200	 /* Bit 2 */

        .equ	LCD_FCR_CC,                0x00001C00	 /* CC[2:0] bits (Contrast Control) */
        .equ	LCD_FCR_CC_0,              0x00000400	 /* Bit 0 */
        .equ	LCD_FCR_CC_1,              0x00000800	 /* Bit 1 */
        .equ	LCD_FCR_CC_2,              0x00001000	 /* Bit 2 */

        .equ	LCD_FCR_BLINKF,            0x0000E000	 /* BLINKF[2:0] bits (Blink Frequency) */
        .equ	LCD_FCR_BLINKF_0,          0x00002000	 /* Bit 0 */
        .equ	LCD_FCR_BLINKF_1,          0x00004000	 /* Bit 1 */
        .equ	LCD_FCR_BLINKF_2,          0x00008000	 /* Bit 2 */

        .equ	LCD_FCR_BLINK,             0x00030000	 /* BLINK[1:0] bits (Blink Enable) */
        .equ	LCD_FCR_BLINK_0,           0x00010000	 /* Bit 0 */
        .equ	LCD_FCR_BLINK_1,           0x00020000	 /* Bit 1 */

        .equ	LCD_FCR_DIV,               0x003C0000	 /* DIV[3:0] bits (Divider) */
        .equ	LCD_FCR_PS,                0x03C00000	 /* PS[3:0] bits (Prescaler) */

/*******************  Bit definition for LCD_SR register  *********************/
        .equ	LCD_SR_ENS,                0x00000001	 /* LCD Enabled Bit */
        .equ	LCD_SR_SOF,                0x00000002	 /* Start Of Frame Flag Bit */
        .equ	LCD_SR_UDR,                0x00000004	 /* Update Display Request Bit */
        .equ	LCD_SR_UDD,                0x00000008	 /* Update Display Done Flag Bit */
        .equ	LCD_SR_RDY,                0x00000010	 /* Ready Flag Bit */
        .equ	LCD_SR_FCRSR,              0x00000020	 /* LCD FCR Register Synchronization Flag Bit */

/*******************  Bit definition for LCD_CLR register  ********************/
        .equ	LCD_CLR_SOFC,              0x00000002	 /* Start Of Frame Flag Clear Bit */
        .equ	LCD_CLR_UDDC,              0x00000008	 /* Update Display Done Flag Clear Bit */

/*******************  Bit definition for LCD_RAM register  ********************/
        .equ	LCD_RAM_SEGMENT_DATA,      0xFFFFFFFF	 /* Segment Data Bits */

/******************************************************************************/
/*                                                                            */
/*                          Power Control (PWR)                               */
/*                                                                            */
/******************************************************************************/

/********************  Bit definition for PWR_CR register  ********************/
        .equ	 PWR_CR_LPSDSR,                      0x0001	 /* Low-power deepsleep/sleep/low power run */
        .equ	 PWR_CR_PDDS,                        0x0002	 /* Power Down Deepsleep */
        .equ	 PWR_CR_CWUF,                        0x0004	 /* Clear Wakeup Flag */
        .equ	 PWR_CR_CSBF,                        0x0008	 /* Clear Standby Flag */
        .equ	 PWR_CR_PVDE,                        0x0010	 /* Power Voltage Detector Enable */

        .equ	 PWR_CR_PLS,                         0x00E0	 /* PLS[2:0] bits (PVD Level Selection) */
        .equ	 PWR_CR_PLS_0,                       0x0020	 /* Bit 0 */
        .equ	 PWR_CR_PLS_1,                       0x0040	 /* Bit 1 */
        .equ	 PWR_CR_PLS_2,                       0x0080	 /* Bit 2 */

/* PVD level configuration */
        .equ	 PWR_CR_PLS_LEV0,                    0x0000	 /* PVD level 0 */
        .equ	 PWR_CR_PLS_LEV1,                    0x0020	 /* PVD level 1 */
        .equ	 PWR_CR_PLS_LEV2,                    0x0040	 /* PVD level 2 */
        .equ	 PWR_CR_PLS_LEV3,                    0x0060	 /* PVD level 3 */
        .equ	 PWR_CR_PLS_LEV4,                    0x0080	 /* PVD level 4 */
        .equ	 PWR_CR_PLS_LEV5,                    0x00A0	 /* PVD level 5 */
        .equ	 PWR_CR_PLS_LEV6,                    0x00C0	 /* PVD level 6 */
        .equ	 PWR_CR_PLS_LEV7,                    0x00E0	 /* PVD level 7 */

        .equ	 PWR_CR_DBP,                         0x0100	 /* Disable Backup Domain write protection */
        .equ	 PWR_CR_ULP,                         0x0200	 /* Ultra Low Power mode */
        .equ	 PWR_CR_FWU,                         0x0400	 /* Fast wakeup */

        .equ	 PWR_CR_VOS,                         0x1800	 /* VOS[1:0] bits (Voltage scaling range selection) */
        .equ	 PWR_CR_VOS_0,                       0x0800	 /* Bit 0 */
        .equ	 PWR_CR_VOS_1,                       0x1000	 /* Bit 1 */
        .equ	 PWR_CR_LPRUN,                       0x4000	 /* Low power run mode */

/*******************  Bit definition for PWR_CSR register  ********************/
        .equ	 PWR_CSR_WUF,                        0x0001	 /* Wakeup Flag */
        .equ	 PWR_CSR_SBF,                        0x0002	 /* Standby Flag */
        .equ	 PWR_CSR_PVDO,                       0x0004	 /* PVD Output */
        .equ	 PWR_CSR_VREFINTRDYF,                0x0008	 /* Internal voltage reference (VREFINT) ready flag */
        .equ	 PWR_CSR_VOSF,                       0x0010	 /* Voltage Scaling select flag */
        .equ	 PWR_CSR_REGLPF,                     0x0020	 /* Regulator LP flag */

        .equ	 PWR_CSR_EWUP1,                      0x0100	 /* Enable WKUP pin 1 */
        .equ	 PWR_CSR_EWUP2,                      0x0200	 /* Enable WKUP pin 2 */
        .equ	 PWR_CSR_EWUP3,                      0x0400	 /* Enable WKUP pin 3 */

/******************************************************************************/
/*                                                                            */
/*                      Reset and Clock Control (RCC)                         */
/*                                                                            */
/******************************************************************************/



/********************  Bit definition for RCC_CR register  ********************/
        .equ	 RCC_CR_HSION,                       0x00000001	    /* Internal High Speed clock enable */
        .equ	 RCC_CR_HSIRDY,                      0x00000002	    /* Internal High Speed clock ready flag */

        .equ	 RCC_CR_MSION,                       0x00000100	    /* Internal Multi Speed clock enable */
        .equ	 RCC_CR_MSIRDY,                      0x00000200	    /* Internal Multi Speed clock ready flag */

        .equ	 RCC_CR_HSEON,                       0x00010000	    /* External High Speed clock enable */
        .equ	 RCC_CR_HSERDY,                      0x00020000	    /* External High Speed clock ready flag */
        .equ	 RCC_CR_HSEBYP,                      0x00040000	    /* External High Speed clock Bypass */

        .equ	 RCC_CR_PLLON,                       0x01000000	    /* PLL enable */
        .equ	 RCC_CR_PLLRDY,                      0x02000000	    /* PLL clock ready flag */
        .equ	 RCC_CR_CSSON,                       0x10000000	    /* Clock Security System enable */

        .equ	 RCC_CR_RTCPRE,                      0x60000000	    /* RTC/LCD Prescaler */
        .equ	 RCC_CR_RTCPRE_0,                    0x20000000	    /* Bit0 */
        .equ	 RCC_CR_RTCPRE_1,                    0x40000000	    /* Bit1 */

/********************  Bit definition for RCC_ICSCR register  *****************/
        .equ	 RCC_ICSCR_HSICAL,                   0x000000FF	    /* Internal High Speed clock Calibration */
        .equ	 RCC_ICSCR_HSITRIM,                  0x00001F00	    /* Internal High Speed clock trimming */

        .equ	 RCC_ICSCR_MSIRANGE,                 0x0000E000	    /* Internal Multi Speed clock Range */
        .equ	 RCC_ICSCR_MSIRANGE_0,               0x00000000	    /* Internal Multi Speed clock Range 65.536 KHz */
        .equ	 RCC_ICSCR_MSIRANGE_1,               0x00002000	    /* Internal Multi Speed clock Range 131.072 KHz */
        .equ	 RCC_ICSCR_MSIRANGE_2,               0x00004000	    /* Internal Multi Speed clock Range 262.144 KHz */
        .equ	 RCC_ICSCR_MSIRANGE_3,               0x00006000	    /* Internal Multi Speed clock Range 524.288 KHz */
        .equ	 RCC_ICSCR_MSIRANGE_4,               0x00008000	    /* Internal Multi Speed clock Range 1.048 MHz */
        .equ	 RCC_ICSCR_MSIRANGE_5,               0x0000A000	    /* Internal Multi Speed clock Range 2.097 MHz */
        .equ	 RCC_ICSCR_MSIRANGE_6,               0x0000C000	    /* Internal Multi Speed clock Range 4.194 MHz */
        .equ	 RCC_ICSCR_MSICAL,                   0x00FF0000	    /* Internal Multi Speed clock Calibration */
        .equ	 RCC_ICSCR_MSITRIM,                  0xFF000000	    /* Internal Multi Speed clock trimming */

/********************  Bit definition for RCC_CFGR register  ******************/
        .equ	 RCC_CFGR_SW,                        0x00000003	    /* SW[1:0] bits (System clock Switch) */
        .equ	 RCC_CFGR_SW_0,                      0x00000001	    /* Bit 0 */
        .equ	 RCC_CFGR_SW_1,                      0x00000002	    /* Bit 1 */

/* SW configuration */
        .equ	 RCC_CFGR_SW_MSI,                    0x00000000	    /* MSI selected as system clock */
        .equ	 RCC_CFGR_SW_HSI,                    0x00000001	    /* HSI selected as system clock */
        .equ	 RCC_CFGR_SW_HSE,                    0x00000002	    /* HSE selected as system clock */
        .equ	 RCC_CFGR_SW_PLL,                    0x00000003	    /* PLL selected as system clock */

        .equ	 RCC_CFGR_SWS,                       0x0000000C	    /* SWS[1:0] bits (System Clock Switch Status) */
        .equ	 RCC_CFGR_SWS_0,                     0x00000004	    /* Bit 0 */
        .equ	 RCC_CFGR_SWS_1,                     0x00000008	    /* Bit 1 */

/* SWS configuration */
        .equ	 RCC_CFGR_SWS_MSI,                   0x00000000	    /* MSI oscillator used as system clock */
        .equ	 RCC_CFGR_SWS_HSI,                   0x00000004	    /* HSI oscillator used as system clock */
        .equ	 RCC_CFGR_SWS_HSE,                   0x00000008	    /* HSE oscillator used as system clock */
        .equ	 RCC_CFGR_SWS_PLL,                   0x0000000C	    /* PLL used as system clock */

        .equ	 RCC_CFGR_HPRE,                      0x000000F0	    /* HPRE[3:0] bits (AHB prescaler) */
        .equ	 RCC_CFGR_HPRE_0,                    0x00000010	    /* Bit 0 */
        .equ	 RCC_CFGR_HPRE_1,                    0x00000020	    /* Bit 1 */
        .equ	 RCC_CFGR_HPRE_2,                    0x00000040	    /* Bit 2 */
        .equ	 RCC_CFGR_HPRE_3,                    0x00000080	    /* Bit 3 */

/* HPRE configuration */
        .equ	 RCC_CFGR_HPRE_DIV1,                 0x00000000	    /* SYSCLK not divided */
        .equ	 RCC_CFGR_HPRE_DIV2,                 0x00000080	    /* SYSCLK divided by 2 */
        .equ	 RCC_CFGR_HPRE_DIV4,                 0x00000090	    /* SYSCLK divided by 4 */
        .equ	 RCC_CFGR_HPRE_DIV8,                 0x000000A0	    /* SYSCLK divided by 8 */
        .equ	 RCC_CFGR_HPRE_DIV16,                0x000000B0	    /* SYSCLK divided by 16 */
        .equ	 RCC_CFGR_HPRE_DIV64,                0x000000C0	    /* SYSCLK divided by 64 */
        .equ	 RCC_CFGR_HPRE_DIV128,               0x000000D0	    /* SYSCLK divided by 128 */
        .equ	 RCC_CFGR_HPRE_DIV256,               0x000000E0	    /* SYSCLK divided by 256 */
        .equ	 RCC_CFGR_HPRE_DIV512,               0x000000F0	    /* SYSCLK divided by 512 */

        .equ	 RCC_CFGR_PPRE1,                     0x00000700	    /* PRE1[2:0] bits (APB1 prescaler) */
        .equ	 RCC_CFGR_PPRE1_0,                   0x00000100	    /* Bit 0 */
        .equ	 RCC_CFGR_PPRE1_1,                   0x00000200	    /* Bit 1 */
        .equ	 RCC_CFGR_PPRE1_2,                   0x00000400	    /* Bit 2 */

/* PPRE1 configuration */
        .equ	 RCC_CFGR_PPRE1_DIV1,                0x00000000	    /* HCLK not divided */
        .equ	 RCC_CFGR_PPRE1_DIV2,                0x00000400	    /* HCLK divided by 2 */
        .equ	 RCC_CFGR_PPRE1_DIV4,                0x00000500	    /* HCLK divided by 4 */
        .equ	 RCC_CFGR_PPRE1_DIV8,                0x00000600	    /* HCLK divided by 8 */
        .equ	 RCC_CFGR_PPRE1_DIV16,               0x00000700	    /* HCLK divided by 16 */

        .equ	 RCC_CFGR_PPRE2,                     0x00003800	    /* PRE2[2:0] bits (APB2 prescaler) */
        .equ	 RCC_CFGR_PPRE2_0,                   0x00000800	    /* Bit 0 */
        .equ	 RCC_CFGR_PPRE2_1,                   0x00001000	    /* Bit 1 */
        .equ	 RCC_CFGR_PPRE2_2,                   0x00002000	    /* Bit 2 */

/* PPRE2 configuration */
        .equ	 RCC_CFGR_PPRE2_DIV1,                0x00000000	    /* HCLK not divided */
        .equ	 RCC_CFGR_PPRE2_DIV2,                0x00002000	    /* HCLK divided by 2 */
        .equ	 RCC_CFGR_PPRE2_DIV4,                0x00002800	    /* HCLK divided by 4 */
        .equ	 RCC_CFGR_PPRE2_DIV8,                0x00003000	    /* HCLK divided by 8 */
        .equ	 RCC_CFGR_PPRE2_DIV16,               0x00003800	    /* HCLK divided by 16 */

/* PLL entry clock source*/
        .equ	 RCC_CFGR_PLLSRC,                    0x00010000	    /* PLL entry clock source */

        .equ	 RCC_CFGR_PLLSRC_HSI,                0x00000000	    /* HSI as PLL entry clock source */
        .equ	 RCC_CFGR_PLLSRC_HSE,                0x00010000	    /* HSE as PLL entry clock source */


        .equ	 RCC_CFGR_PLLMUL,                    0x003C0000	    /* PLLMUL[3:0] bits (PLL multiplication factor) */
        .equ	 RCC_CFGR_PLLMUL_0,                  0x00040000	    /* Bit 0 */
        .equ	 RCC_CFGR_PLLMUL_1,                  0x00080000	    /* Bit 1 */
        .equ	 RCC_CFGR_PLLMUL_2,                  0x00100000	    /* Bit 2 */
        .equ	 RCC_CFGR_PLLMUL_3,                  0x00200000	    /* Bit 3 */

/* PLLMUL configuration */
        .equ	 RCC_CFGR_PLLMUL3,                   0x00000000	    /* PLL input clock * 3 */
        .equ	 RCC_CFGR_PLLMUL4,                   0x00040000	    /* PLL input clock * 4 */
        .equ	 RCC_CFGR_PLLMUL6,                   0x00080000	    /* PLL input clock * 6 */
        .equ	 RCC_CFGR_PLLMUL8,                   0x000C0000	    /* PLL input clock * 8 */
        .equ	 RCC_CFGR_PLLMUL12,                  0x00100000	    /* PLL input clock * 12 */
        .equ	 RCC_CFGR_PLLMUL16,                  0x00140000	    /* PLL input clock * 16 */
        .equ	 RCC_CFGR_PLLMUL24,                  0x00180000	    /* PLL input clock * 24 */
        .equ	 RCC_CFGR_PLLMUL32,                  0x001C0000	    /* PLL input clock * 32 */
        .equ	 RCC_CFGR_PLLMUL48,                  0x00200000	    /* PLL input clock * 48 */

/* PLLDIV configuration */
        .equ	 RCC_CFGR_PLLDIV,                    0x00C00000	    /* PLLDIV[1:0] bits (PLL Output Division) */
        .equ	 RCC_CFGR_PLLDIV_0,                  0x00400000	    /* Bit0 */
        .equ	 RCC_CFGR_PLLDIV_1,                  0x00800000	    /* Bit1 */


/* PLLDIV configuration */
        .equ	 RCC_CFGR_PLLDIV1,                   0x00000000	    /* PLL clock output = CKVCO / 1 */
        .equ	 RCC_CFGR_PLLDIV2,                   0x00400000	    /* PLL clock output = CKVCO / 2 */
        .equ	 RCC_CFGR_PLLDIV3,                   0x00800000	    /* PLL clock output = CKVCO / 3 */
        .equ	 RCC_CFGR_PLLDIV4,                   0x00C00000	    /* PLL clock output = CKVCO / 4 */


        .equ	 RCC_CFGR_MCOSEL,                    0x07000000	    /* MCO[2:0] bits (Microcontroller Clock Output) */
        .equ	 RCC_CFGR_MCOSEL_0,                  0x01000000	    /* Bit 0 */
        .equ	 RCC_CFGR_MCOSEL_1,                  0x02000000	    /* Bit 1 */
        .equ	 RCC_CFGR_MCOSEL_2,                  0x04000000	    /* Bit 2 */

/* MCO configuration */
        .equ	 RCC_CFGR_MCO_NOCLOCK,               0x00000000	    /* No clock */
        .equ	 RCC_CFGR_MCO_SYSCLK,                0x01000000	    /* System clock selected */
        .equ	 RCC_CFGR_MCO_HSI,                   0x02000000	    /* Internal 16 MHz RC oscillator clock selected */
        .equ	 RCC_CFGR_MCO_MSI,                   0x03000000	    /* Internal Medium Speed RC oscillator clock selected */
        .equ	 RCC_CFGR_MCO_HSE,                   0x04000000	    /* External 1-25 MHz oscillator clock selected */
        .equ	 RCC_CFGR_MCO_PLL,                   0x05000000	    /* PLL clock divided */
        .equ	 RCC_CFGR_MCO_LSI,                   0x06000000	    /* LSI selected */
        .equ	 RCC_CFGR_MCO_LSE,                   0x07000000	    /* LSE selected */

        .equ	 RCC_CFGR_MCOPRE,                    0x70000000	    /* MCOPRE[2:0] bits (Microcontroller Clock Output Prescaler) */
        .equ	 RCC_CFGR_MCOPRE_0,                  0x10000000	    /* Bit 0 */
        .equ	 RCC_CFGR_MCOPRE_1,                  0x20000000	    /* Bit 1 */
        .equ	 RCC_CFGR_MCOPRE_2,                  0x40000000	    /* Bit 2 */

/* MCO Prescaler configuration */
        .equ	 RCC_CFGR_MCO_DIV1,                  0x00000000	    /* MCO Clock divided by 1 */
        .equ	 RCC_CFGR_MCO_DIV2,                  0x10000000	    /* MCO Clock divided by 2 */
        .equ	 RCC_CFGR_MCO_DIV4,                  0x20000000	    /* MCO Clock divided by 4 */
        .equ	 RCC_CFGR_MCO_DIV8,                  0x30000000	    /* MCO Clock divided by 8 */
        .equ	 RCC_CFGR_MCO_DIV16,                 0x40000000	    /* MCO Clock divided by 16 */

/*******************  Bit definition for RCC_CIR register  ********************/
        .equ	 RCC_CIR_LSIRDYF,                    0x00000001	    /* LSI Ready Interrupt flag */
        .equ	 RCC_CIR_LSERDYF,                    0x00000002	    /* LSE Ready Interrupt flag */
        .equ	 RCC_CIR_HSIRDYF,                    0x00000004	    /* HSI Ready Interrupt flag */
        .equ	 RCC_CIR_HSERDYF,                    0x00000008	    /* HSE Ready Interrupt flag */
        .equ	 RCC_CIR_PLLRDYF,                    0x00000010	    /* PLL Ready Interrupt flag */
        .equ	 RCC_CIR_MSIRDYF,                    0x00000020	    /* MSI Ready Interrupt flag */
        .equ	 RCC_CIR_CSSF,                       0x00000080	    /* Clock Security System Interrupt flag */

        .equ	 RCC_CIR_LSIRDYIE,                   0x00000100	    /* LSI Ready Interrupt Enable */
        .equ	 RCC_CIR_LSERDYIE,                   0x00000200	    /* LSE Ready Interrupt Enable */
        .equ	 RCC_CIR_HSIRDYIE,                   0x00000400	    /* HSI Ready Interrupt Enable */
        .equ	 RCC_CIR_HSERDYIE,                   0x00000800	    /* HSE Ready Interrupt Enable */
        .equ	 RCC_CIR_PLLRDYIE,                   0x00001000	    /* PLL Ready Interrupt Enable */
        .equ	 RCC_CIR_MSIRDYIE,                   0x00002000	    /* MSI Ready Interrupt Enable */

        .equ	 RCC_CIR_LSIRDYC,                    0x00010000	    /* LSI Ready Interrupt Clear */
        .equ	 RCC_CIR_LSERDYC,                    0x00020000	    /* LSE Ready Interrupt Clear */
        .equ	 RCC_CIR_HSIRDYC,                    0x00040000	    /* HSI Ready Interrupt Clear */
        .equ	 RCC_CIR_HSERDYC,                    0x00080000	    /* HSE Ready Interrupt Clear */
        .equ	 RCC_CIR_PLLRDYC,                    0x00100000	    /* PLL Ready Interrupt Clear */
        .equ	 RCC_CIR_MSIRDYC,                    0x00200000	    /* MSI Ready Interrupt Clear */
        .equ	 RCC_CIR_CSSC,                       0x00800000	    /* Clock Security System Interrupt Clear */


/*****************  Bit definition for RCC_AHBRSTR register  ******************/
        .equ	 RCC_AHBRSTR_GPIOARST,               0x00000001	    /* GPIO port A reset */
        .equ	 RCC_AHBRSTR_GPIOBRST,               0x00000002	    /* GPIO port B reset */
        .equ	 RCC_AHBRSTR_GPIOCRST,               0x00000004	    /* GPIO port C reset */
        .equ	 RCC_AHBRSTR_GPIODRST,               0x00000008	    /* GPIO port D reset */
        .equ	 RCC_AHBRSTR_GPIOERST,               0x00000010	    /* GPIO port E reset */
        .equ	 RCC_AHBRSTR_GPIOHRST,               0x00000020	    /* GPIO port H reset */
        .equ	 RCC_AHBRSTR_CRCRST,                 0x00001000	    /* CRC reset */
        .equ	 RCC_AHBRSTR_FLITFRST,               0x00008000	    /* FLITF reset */
        .equ	 RCC_AHBRSTR_DMA1RST,                0x01000000	    /* DMA1 reset */
 
/*****************  Bit definition for RCC_APB2RSTR register  *****************/
        .equ	 RCC_APB2RSTR_SYSCFGRST,             0x00000001	    /* System Configuration SYSCFG reset */
        .equ	 RCC_APB2RSTR_TIM9RST,               0x00000004	    /* TIM9 reset */
        .equ	 RCC_APB2RSTR_TIM10RST,              0x00000008	    /* TIM10 reset */
        .equ	 RCC_APB2RSTR_TIM11RST,              0x00000010	    /* TIM11 reset */
        .equ	 RCC_APB2RSTR_ADC1RST,               0x00000200	    /* ADC1 reset */
        .equ	 RCC_APB2RSTR_SPI1RST,               0x00001000	    /* SPI1 reset */
        .equ	 RCC_APB2RSTR_USART1RST,             0x00004000	    /* USART1 reset */

/*****************  Bit definition for RCC_APB1RSTR register  *****************/
        .equ	 RCC_APB1RSTR_TIM2RST,               0x00000001	    /* Timer 2 reset */
        .equ	 RCC_APB1RSTR_TIM3RST,               0x00000002	    /* Timer 3 reset */
        .equ	 RCC_APB1RSTR_TIM4RST,               0x00000004	    /* Timer 4 reset */
        .equ	 RCC_APB1RSTR_TIM6RST,               0x00000010	    /* Timer 6 reset */
        .equ	 RCC_APB1RSTR_TIM7RST,               0x00000020	    /* Timer 7 reset */
        .equ	 RCC_APB1RSTR_LCDRST,                0x00000200	    /* LCD reset */
        .equ	 RCC_APB1RSTR_WWDGRST,               0x00000800	    /* Window Watchdog reset */
        .equ	 RCC_APB1RSTR_SPI2RST,               0x00004000	    /* SPI 2 reset */
        .equ	 RCC_APB1RSTR_USART2RST,             0x00020000	    /* USART 2 reset */
        .equ	 RCC_APB1RSTR_USART3RST,             0x00040000	    /* RUSART 3 reset */
        .equ	 RCC_APB1RSTR_I2C1RST,               0x00200000	    /* I2C 1 reset */
        .equ	 RCC_APB1RSTR_I2C2RST,               0x00400000	    /* I2C 2 reset */
        .equ	 RCC_APB1RSTR_USBRST,                0x00800000	    /* USB reset */
        .equ	 RCC_APB1RSTR_PWRRST,                0x10000000	    /* Power interface reset */
        .equ	 RCC_APB1RSTR_DACRST,                0x20000000	    /* DAC interface reset */
        .equ	 RCC_APB1RSTR_COMPRST,               0x80000000	    /* Comparator interface reset */

/******************  Bit definition for RCC_AHBENR register  ******************/
        .equ	 RCC_AHBENR_GPIOAEN,                 0x00000001	    /* GPIO port A clock enable */
        .equ	 RCC_AHBENR_GPIOBEN,                 0x00000002	    /* GPIO port B clock enable */
        .equ	 RCC_AHBENR_GPIOCEN,                 0x00000004	    /* GPIO port C clock enable */
        .equ	 RCC_AHBENR_GPIODEN,                 0x00000008	    /* GPIO port D clock enable */
        .equ	 RCC_AHBENR_GPIOEEN,                 0x00000010	    /* GPIO port E clock enable */
        .equ	 RCC_AHBENR_GPIOHEN,                 0x00000020	    /* GPIO port H clock enable */
        .equ	 RCC_AHBENR_CRCEN,                   0x00001000	    /* CRC clock enable */
        .equ	 RCC_AHBENR_FLITFEN,                 0x00008000	    /* FLITF clock enable (has effect only when
                                                                                the Flash memory is in power down mode) */
        .equ	 RCC_AHBENR_DMA1EN,                  0x01000000	    /* DMA1 clock enable */


/******************  Bit definition for RCC_APB2ENR register  *****************/
        .equ	 RCC_APB2ENR_SYSCFGEN,               0x00000001	     /* System Configuration SYSCFG clock enable */
        .equ	 RCC_APB2ENR_TIM9EN,                 0x00000004	     /* TIM9 interface clock enable */
        .equ	 RCC_APB2ENR_TIM10EN,                0x00000008	     /* TIM10 interface clock enable */
        .equ	 RCC_APB2ENR_TIM11EN,                0x00000010	     /* TIM11 Timer clock enable */
        .equ	 RCC_APB2ENR_ADC1EN,                 0x00000200	     /* ADC1 clock enable */
        .equ	 RCC_APB2ENR_SPI1EN,                 0x00001000	     /* SPI1 clock enable */
        .equ	 RCC_APB2ENR_USART1EN,               0x00004000	     /* USART1 clock enable */


/*****************  Bit definition for RCC_APB1ENR register  ******************/
        .equ	 RCC_APB1ENR_TIM2EN,                 0x00000001	    /* Timer 2 clock enabled*/
        .equ	 RCC_APB1ENR_TIM3EN,                 0x00000002	    /* Timer 3 clock enable */
        .equ	 RCC_APB1ENR_TIM4EN,                 0x00000004	    /* Timer 4 clock enable */
        .equ	 RCC_APB1ENR_TIM6EN,                 0x00000010	    /* Timer 6 clock enable */
        .equ	 RCC_APB1ENR_TIM7EN,                 0x00000020	    /* Timer 7 clock enable */
        .equ	 RCC_APB1ENR_LCDEN,                  0x00000200	    /* LCD clock enable */
        .equ	 RCC_APB1ENR_WWDGEN,                 0x00000800	    /* Window Watchdog clock enable */
        .equ	 RCC_APB1ENR_SPI2EN,                 0x00004000	    /* SPI 2 clock enable */
        .equ	 RCC_APB1ENR_USART2EN,               0x00020000	    /* USART 2 clock enable */
        .equ	 RCC_APB1ENR_USART3EN,               0x00040000	    /* USART 3 clock enable */
        .equ	 RCC_APB1ENR_I2C1EN,                 0x00200000	    /* I2C 1 clock enable */
        .equ	 RCC_APB1ENR_I2C2EN,                 0x00400000	    /* I2C 2 clock enable */
        .equ	 RCC_APB1ENR_USBEN,                  0x00800000	    /* USB clock enable */
        .equ	 RCC_APB1ENR_PWREN,                  0x10000000	    /* Power interface clock enable */
        .equ	 RCC_APB1ENR_DACEN,                  0x20000000	    /* DAC interface clock enable */
        .equ	 RCC_APB1ENR_COMPEN,                 0x80000000	    /* Comparator interface clock enable */

/******************  Bit definition for RCC_AHBLPENR register  ****************/
        .equ	 RCC_AHBLPENR_GPIOALPEN,             0x00000001	    /* GPIO port A clock enabled in sleep mode */
        .equ	 RCC_AHBLPENR_GPIOBLPEN,             0x00000002	    /* GPIO port B clock enabled in sleep mode */
        .equ	 RCC_AHBLPENR_GPIOCLPEN,             0x00000004	    /* GPIO port C clock enabled in sleep mode */
        .equ	 RCC_AHBLPENR_GPIODLPEN,             0x00000008	    /* GPIO port D clock enabled in sleep mode */
        .equ	 RCC_AHBLPENR_GPIOELPEN,             0x00000010	    /* GPIO port E clock enabled in sleep mode */
        .equ	 RCC_AHBLPENR_GPIOHLPEN,             0x00000020	    /* GPIO port H clock enabled in sleep mode */
        .equ	 RCC_AHBLPENR_CRCLPEN,               0x00001000	    /* CRC clock enabled in sleep mode */
        .equ	 RCC_AHBLPENR_FLITFLPEN,             0x00008000	    /* Flash Interface clock enabled in sleep mode
                                                                                       (has effect only when the Flash memory is
                                                                                       in power down mode) */
        .equ	 RCC_AHBLPENR_SRAMLPEN,              0x00010000	    /* SRAM clock enabled in sleep mode */
        .equ	 RCC_AHBLPENR_DMA1LPEN,              0x01000000	    /* DMA1 clock enabled in sleep mode */

/******************  Bit definition for RCC_APB2LPENR register  ***************/
        .equ	 RCC_APB2LPENR_SYSCFGLPEN,           0x00000001	     /* System Configuration SYSCFG clock enabled in sleep mode */
        .equ	 RCC_APB2LPENR_TIM9LPEN,             0x00000004	     /* TIM9 interface clock enabled in sleep mode */
        .equ	 RCC_APB2LPENR_TIM10LPEN,            0x00000008	     /* TIM10 interface clock enabled in sleep mode */
        .equ	 RCC_APB2LPENR_TIM11LPEN,            0x00000010	     /* TIM11 Timer clock enabled in sleep mode */
        .equ	 RCC_APB2LPENR_ADC1LPEN,             0x00000200	     /* ADC1 clock enabled in sleep mode */
        .equ	 RCC_APB2LPENR_SPI1LPEN,             0x00001000	     /* SPI1 clock enabled in sleep mode */
        .equ	 RCC_APB2LPENR_USART1LPEN,           0x00004000	     /* USART1 clock enabled in sleep mode */

/*****************  Bit definition for RCC_APB1LPENR register  ****************/
        .equ	 RCC_APB1LPENR_TIM2LPEN,             0x00000001	    /* Timer 2 clock enabled in sleep mode */
        .equ	 RCC_APB1LPENR_TIM3LPEN,             0x00000002	    /* Timer 3 clock enabled in sleep mode */
        .equ	 RCC_APB1LPENR_TIM4LPEN,             0x00000004	    /* Timer 4 clock enabled in sleep mode */
        .equ	 RCC_APB1LPENR_TIM6LPEN,             0x00000010	    /* Timer 6 clock enabled in sleep mode */
        .equ	 RCC_APB1LPENR_TIM7LPEN,             0x00000020	    /* Timer 7 clock enabled in sleep mode */
        .equ	 RCC_APB1LPENR_LCDLPEN,              0x00000200	    /* LCD clock enabled in sleep mode */
        .equ	 RCC_APB1LPENR_WWDGLPEN,             0x00000800	    /* Window Watchdog clock enabled in sleep mode */
        .equ	 RCC_APB1LPENR_SPI2LPEN,             0x00004000	    /* SPI 2 clock enabled in sleep mode */
        .equ	 RCC_APB1LPENR_USART2LPEN,           0x00020000	    /* USART 2 clock enabled in sleep mode */
        .equ	 RCC_APB1LPENR_USART3LPEN,           0x00040000	    /* USART 3 clock enabled in sleep mode */
        .equ	 RCC_APB1LPENR_I2C1LPEN,             0x00200000	    /* I2C 1 clock enabled in sleep mode */
        .equ	 RCC_APB1LPENR_I2C2LPEN,             0x00400000	    /* I2C 2 clock enabled in sleep mode */
        .equ	 RCC_APB1LPENR_USBLPEN,              0x00800000	    /* USB clock enabled in sleep mode */
        .equ	 RCC_APB1LPENR_PWRLPEN,              0x10000000	    /* Power interface clock enabled in sleep mode */
        .equ	 RCC_APB1LPENR_DACLPEN,              0x20000000	    /* DAC interface clock enabled in sleep mode */
        .equ	 RCC_APB1LPENR_COMPLPEN,             0x80000000	    /* Comparator interface clock enabled in sleep mode*/

/*******************  Bit definition for RCC_CSR register  ********************/
        .equ	 RCC_CSR_LSION,                     0x00000001	    /* Internal Low Speed oscillator enable */
        .equ	 RCC_CSR_LSIRDY,                    0x00000002	    /* Internal Low Speed oscillator Ready */

        .equ	 RCC_CSR_LSEON,                     0x00000100	    /* External Low Speed oscillator enable */
        .equ	 RCC_CSR_LSERDY,                    0x00000200	    /* External Low Speed oscillator Ready */
        .equ	 RCC_CSR_LSEBYP,                    0x00000400	    /* External Low Speed oscillator Bypass */

        .equ	 RCC_CSR_RTCSEL,                    0x00030000	    /* RTCSEL[1:0] bits (RTC clock source selection) */
        .equ	 RCC_CSR_RTCSEL_0,                  0x00010000	    /* Bit 0 */
        .equ	 RCC_CSR_RTCSEL_1,                  0x00020000	    /* Bit 1 */

/* RTC congiguration */
        .equ	 RCC_CSR_RTCSEL_NOCLOCK,            0x00000000	    /* No clock */
        .equ	 RCC_CSR_RTCSEL_LSE,                0x00010000	    /* LSE oscillator clock used as RTC clock */
        .equ	 RCC_CSR_RTCSEL_LSI,                0x00020000	    /* LSI oscillator clock used as RTC clock */
        .equ	 RCC_CSR_RTCSEL_HSE,                0x00030000	    /* HSE oscillator clock divided by 2, 4, 8 or 16 by RTCPRE used as RTC clock */

        .equ	 RCC_CSR_RTCEN,                     0x00400000	    /* RTC clock enable */
        .equ	 RCC_CSR_RTCRST,                    0x00800000	    /* RTC reset  */
 
        .equ	 RCC_CSR_RMVF,                      0x01000000	    /* Remove reset flag */
        .equ	 RCC_CSR_OBLRSTF,                   0x02000000	    /* Option Bytes Loader reset flag */
        .equ	 RCC_CSR_PINRSTF,                   0x04000000	    /* PIN reset flag */
        .equ	 RCC_CSR_PORRSTF,                   0x08000000	    /* POR/PDR reset flag */
        .equ	 RCC_CSR_SFTRSTF,                   0x10000000	    /* Software Reset flag */
        .equ	 RCC_CSR_IWDGRSTF,                  0x20000000	    /* Independent Watchdog reset flag */
        .equ	 RCC_CSR_WWDGRSTF,                  0x40000000	    /* Window watchdog reset flag */
        .equ	 RCC_CSR_LPWRRSTF,                  0x80000000	    /* Low-Power reset flag */


/******************************************************************************/
/*                                                                            */
/*                           Real-Time Clock (RTC)                            */
/*                                                                            */
/******************************************************************************/
/********************  Bits definition for RTC_TR register  *******************/
        .equ	RTC_TR_PM,                           0x00400000
        .equ	RTC_TR_HT,                           0x00300000
        .equ	RTC_TR_HT_0,                         0x00100000
        .equ	RTC_TR_HT_1,                         0x00200000
        .equ	RTC_TR_HU,                           0x000F0000
        .equ	RTC_TR_HU_0,                         0x00010000
        .equ	RTC_TR_HU_1,                         0x00020000
        .equ	RTC_TR_HU_2,                         0x00040000
        .equ	RTC_TR_HU_3,                         0x00080000
        .equ	RTC_TR_MNT,                          0x00007000
        .equ	RTC_TR_MNT_0,                        0x00001000
        .equ	RTC_TR_MNT_1,                        0x00002000
        .equ	RTC_TR_MNT_2,                        0x00004000
        .equ	RTC_TR_MNU,                          0x00000F00
        .equ	RTC_TR_MNU_0,                        0x00000100
        .equ	RTC_TR_MNU_1,                        0x00000200
        .equ	RTC_TR_MNU_2,                        0x00000400
        .equ	RTC_TR_MNU_3,                        0x00000800
        .equ	RTC_TR_ST,                           0x00000070
        .equ	RTC_TR_ST_0,                         0x00000010
        .equ	RTC_TR_ST_1,                         0x00000020
        .equ	RTC_TR_ST_2,                         0x00000040
        .equ	RTC_TR_SU,                           0x0000000F
        .equ	RTC_TR_SU_0,                         0x00000001
        .equ	RTC_TR_SU_1,                         0x00000002
        .equ	RTC_TR_SU_2,                         0x00000004
        .equ	RTC_TR_SU_3,                         0x00000008

/********************  Bits definition for RTC_DR register  *******************/
        .equ	RTC_DR_YT,                           0x00F00000
        .equ	RTC_DR_YT_0,                         0x00100000
        .equ	RTC_DR_YT_1,                         0x00200000
        .equ	RTC_DR_YT_2,                         0x00400000
        .equ	RTC_DR_YT_3,                         0x00800000
        .equ	RTC_DR_YU,                           0x000F0000
        .equ	RTC_DR_YU_0,                         0x00010000
        .equ	RTC_DR_YU_1,                         0x00020000
        .equ	RTC_DR_YU_2,                         0x00040000
        .equ	RTC_DR_YU_3,                         0x00080000
        .equ	RTC_DR_WDU,                          0x0000E000
        .equ	RTC_DR_WDU_0,                        0x00002000
        .equ	RTC_DR_WDU_1,                        0x00004000
        .equ	RTC_DR_WDU_2,                        0x00008000
        .equ	RTC_DR_MT,                           0x00001000
        .equ	RTC_DR_MU,                           0x00000F00
        .equ	RTC_DR_MU_0,                         0x00000100
        .equ	RTC_DR_MU_1,                         0x00000200
        .equ	RTC_DR_MU_2,                         0x00000400
        .equ	RTC_DR_MU_3,                         0x00000800
        .equ	RTC_DR_DT,                           0x00000030
        .equ	RTC_DR_DT_0,                         0x00000010
        .equ	RTC_DR_DT_1,                         0x00000020
        .equ	RTC_DR_DU,                           0x0000000F
        .equ	RTC_DR_DU_0,                         0x00000001
        .equ	RTC_DR_DU_1,                         0x00000002
        .equ	RTC_DR_DU_2,                         0x00000004
        .equ	RTC_DR_DU_3,                         0x00000008

/********************  Bits definition for RTC_CR register  *******************/
        .equ	RTC_CR_COE,                          0x00800000
        .equ	RTC_CR_OSEL,                         0x00600000
        .equ	RTC_CR_OSEL_0,                       0x00200000
        .equ	RTC_CR_OSEL_1,                       0x00400000
        .equ	RTC_CR_POL,                          0x00100000
        .equ	RTC_CR_BCK,                          0x00040000
        .equ	RTC_CR_SUB1H,                        0x00020000
        .equ	RTC_CR_ADD1H,                        0x00010000
        .equ	RTC_CR_TSIE,                         0x00008000
        .equ	RTC_CR_WUTIE,                        0x00004000
        .equ	RTC_CR_ALRBIE,                       0x00002000
        .equ	RTC_CR_ALRAIE,                       0x00001000
        .equ	RTC_CR_TSE,                          0x00000800
        .equ	RTC_CR_WUTE,                         0x00000400
        .equ	RTC_CR_ALRBE,                        0x00000200
        .equ	RTC_CR_ALRAE,                        0x00000100
        .equ	RTC_CR_DCE,                          0x00000080
        .equ	RTC_CR_FMT,                          0x00000040
        .equ	RTC_CR_REFCKON,                      0x00000010
        .equ	RTC_CR_TSEDGE,                       0x00000008
        .equ	RTC_CR_WUCKSEL,                      0x00000007
        .equ	RTC_CR_WUCKSEL_0,                    0x00000001
        .equ	RTC_CR_WUCKSEL_1,                    0x00000002
        .equ	RTC_CR_WUCKSEL_2,                    0x00000004

/********************  Bits definition for RTC_ISR register  ******************/
        .equ	RTC_ISR_TAMP1F,                      0x00002000
        .equ	RTC_ISR_TSOVF,                       0x00001000
        .equ	RTC_ISR_TSF,                         0x00000800
        .equ	RTC_ISR_WUTF,                        0x00000400
        .equ	RTC_ISR_ALRBF,                       0x00000200
        .equ	RTC_ISR_ALRAF,                       0x00000100
        .equ	RTC_ISR_INIT,                        0x00000080
        .equ	RTC_ISR_INITF,                       0x00000040
        .equ	RTC_ISR_RSF,                         0x00000020
        .equ	RTC_ISR_INITS,                       0x00000010
        .equ	RTC_ISR_WUTWF,                       0x00000004
        .equ	RTC_ISR_ALRBWF,                      0x00000002
        .equ	RTC_ISR_ALRAWF,                      0x00000001

/********************  Bits definition for RTC_PRER register  *****************/
        .equ	RTC_PRER_PREDIV_A,                   0x007F0000
        .equ	RTC_PRER_PREDIV_S,                   0x00001FFF

/********************  Bits definition for RTC_WUTR register  *****************/
        .equ	RTC_WUTR_WUT,                        0x0000FFFF

/********************  Bits definition for RTC_CALIBR register  ***************/
        .equ	RTC_CALIBR_DCS,                      0x00000080
        .equ	RTC_CALIBR_DC,                       0x0000001F

/********************  Bits definition for RTC_ALRMAR register  ***************/
        .equ	RTC_ALRMAR_MSK4,                     0x80000000
        .equ	RTC_ALRMAR_WDSEL,                    0x40000000
        .equ	RTC_ALRMAR_DT,                       0x30000000
        .equ	RTC_ALRMAR_DT_0,                     0x10000000
        .equ	RTC_ALRMAR_DT_1,                     0x20000000
        .equ	RTC_ALRMAR_DU,                       0x0F000000
        .equ	RTC_ALRMAR_DU_0,                     0x01000000
        .equ	RTC_ALRMAR_DU_1,                     0x02000000
        .equ	RTC_ALRMAR_DU_2,                     0x04000000
        .equ	RTC_ALRMAR_DU_3,                     0x08000000
        .equ	RTC_ALRMAR_MSK3,                     0x00800000
        .equ	RTC_ALRMAR_PM,                       0x00400000
        .equ	RTC_ALRMAR_HT,                       0x00300000
        .equ	RTC_ALRMAR_HT_0,                     0x00100000
        .equ	RTC_ALRMAR_HT_1,                     0x00200000
        .equ	RTC_ALRMAR_HU,                       0x000F0000
        .equ	RTC_ALRMAR_HU_0,                     0x00010000
        .equ	RTC_ALRMAR_HU_1,                     0x00020000
        .equ	RTC_ALRMAR_HU_2,                     0x00040000
        .equ	RTC_ALRMAR_HU_3,                     0x00080000
        .equ	RTC_ALRMAR_MSK2,                     0x00008000
        .equ	RTC_ALRMAR_MNT,                      0x00007000
        .equ	RTC_ALRMAR_MNT_0,                    0x00001000
        .equ	RTC_ALRMAR_MNT_1,                    0x00002000
        .equ	RTC_ALRMAR_MNT_2,                    0x00004000
        .equ	RTC_ALRMAR_MNU,                      0x00000F00
        .equ	RTC_ALRMAR_MNU_0,                    0x00000100
        .equ	RTC_ALRMAR_MNU_1,                    0x00000200
        .equ	RTC_ALRMAR_MNU_2,                    0x00000400
        .equ	RTC_ALRMAR_MNU_3,                    0x00000800
        .equ	RTC_ALRMAR_MSK1,                     0x00000080
        .equ	RTC_ALRMAR_ST,                       0x00000070
        .equ	RTC_ALRMAR_ST_0,                     0x00000010
        .equ	RTC_ALRMAR_ST_1,                     0x00000020
        .equ	RTC_ALRMAR_ST_2,                     0x00000040
        .equ	RTC_ALRMAR_SU,                       0x0000000F
        .equ	RTC_ALRMAR_SU_0,                     0x00000001
        .equ	RTC_ALRMAR_SU_1,                     0x00000002
        .equ	RTC_ALRMAR_SU_2,                     0x00000004
        .equ	RTC_ALRMAR_SU_3,                     0x00000008

/********************  Bits definition for RTC_ALRMBR register  ***************/
        .equ	RTC_ALRMBR_MSK4,                     0x80000000
        .equ	RTC_ALRMBR_WDSEL,                    0x40000000
        .equ	RTC_ALRMBR_DT,                       0x30000000
        .equ	RTC_ALRMBR_DT_0,                     0x10000000
        .equ	RTC_ALRMBR_DT_1,                     0x20000000
        .equ	RTC_ALRMBR_DU,                       0x0F000000
        .equ	RTC_ALRMBR_DU_0,                     0x01000000
        .equ	RTC_ALRMBR_DU_1,                     0x02000000
        .equ	RTC_ALRMBR_DU_2,                     0x04000000
        .equ	RTC_ALRMBR_DU_3,                     0x08000000
        .equ	RTC_ALRMBR_MSK3,                     0x00800000
        .equ	RTC_ALRMBR_PM,                       0x00400000
        .equ	RTC_ALRMBR_HT,                       0x00300000
        .equ	RTC_ALRMBR_HT_0,                     0x00100000
        .equ	RTC_ALRMBR_HT_1,                     0x00200000
        .equ	RTC_ALRMBR_HU,                       0x000F0000
        .equ	RTC_ALRMBR_HU_0,                     0x00010000
        .equ	RTC_ALRMBR_HU_1,                     0x00020000
        .equ	RTC_ALRMBR_HU_2,                     0x00040000
        .equ	RTC_ALRMBR_HU_3,                     0x00080000
        .equ	RTC_ALRMBR_MSK2,                     0x00008000
        .equ	RTC_ALRMBR_MNT,                      0x00007000
        .equ	RTC_ALRMBR_MNT_0,                    0x00001000
        .equ	RTC_ALRMBR_MNT_1,                    0x00002000
        .equ	RTC_ALRMBR_MNT_2,                    0x00004000
        .equ	RTC_ALRMBR_MNU,                      0x00000F00
        .equ	RTC_ALRMBR_MNU_0,                    0x00000100
        .equ	RTC_ALRMBR_MNU_1,                    0x00000200
        .equ	RTC_ALRMBR_MNU_2,                    0x00000400
        .equ	RTC_ALRMBR_MNU_3,                    0x00000800
        .equ	RTC_ALRMBR_MSK1,                     0x00000080
        .equ	RTC_ALRMBR_ST,                       0x00000070
        .equ	RTC_ALRMBR_ST_0,                     0x00000010
        .equ	RTC_ALRMBR_ST_1,                     0x00000020
        .equ	RTC_ALRMBR_ST_2,                     0x00000040
        .equ	RTC_ALRMBR_SU,                       0x0000000F
        .equ	RTC_ALRMBR_SU_0,                     0x00000001
        .equ	RTC_ALRMBR_SU_1,                     0x00000002
        .equ	RTC_ALRMBR_SU_2,                     0x00000004
        .equ	RTC_ALRMBR_SU_3,                     0x00000008

/********************  Bits definition for RTC_WPR register  ******************/
        .equ	RTC_WPR_KEY,                         0x000000FF

/********************  Bits definition for RTC_TSTR register  *****************/
        .equ	RTC_TSTR_PM,                         0x00400000
        .equ	RTC_TSTR_HT,                         0x00300000
        .equ	RTC_TSTR_HT_0,                       0x00100000
        .equ	RTC_TSTR_HT_1,                       0x00200000
        .equ	RTC_TSTR_HU,                         0x000F0000
        .equ	RTC_TSTR_HU_0,                       0x00010000
        .equ	RTC_TSTR_HU_1,                       0x00020000
        .equ	RTC_TSTR_HU_2,                       0x00040000
        .equ	RTC_TSTR_HU_3,                       0x00080000
        .equ	RTC_TSTR_MNT,                        0x00007000
        .equ	RTC_TSTR_MNT_0,                      0x00001000
        .equ	RTC_TSTR_MNT_1,                      0x00002000
        .equ	RTC_TSTR_MNT_2,                      0x00004000
        .equ	RTC_TSTR_MNU,                        0x00000F00
        .equ	RTC_TSTR_MNU_0,                      0x00000100
        .equ	RTC_TSTR_MNU_1,                      0x00000200
        .equ	RTC_TSTR_MNU_2,                      0x00000400
        .equ	RTC_TSTR_MNU_3,                      0x00000800
        .equ	RTC_TSTR_ST,                         0x00000070
        .equ	RTC_TSTR_ST_0,                       0x00000010
        .equ	RTC_TSTR_ST_1,                       0x00000020
        .equ	RTC_TSTR_ST_2,                       0x00000040
        .equ	RTC_TSTR_SU,                         0x0000000F
        .equ	RTC_TSTR_SU_0,                       0x00000001
        .equ	RTC_TSTR_SU_1,                       0x00000002
        .equ	RTC_TSTR_SU_2,                       0x00000004
        .equ	RTC_TSTR_SU_3,                       0x00000008

/********************  Bits definition for RTC_TSDR register  *****************/
        .equ	RTC_TSDR_WDU,                        0x0000E000
        .equ	RTC_TSDR_WDU_0,                      0x00002000
        .equ	RTC_TSDR_WDU_1,                      0x00004000
        .equ	RTC_TSDR_WDU_2,                      0x00008000
        .equ	RTC_TSDR_MT,                         0x00001000
        .equ	RTC_TSDR_MU,                         0x00000F00
        .equ	RTC_TSDR_MU_0,                       0x00000100
        .equ	RTC_TSDR_MU_1,                       0x00000200
        .equ	RTC_TSDR_MU_2,                       0x00000400
        .equ	RTC_TSDR_MU_3,                       0x00000800
        .equ	RTC_TSDR_DT,                         0x00000030
        .equ	RTC_TSDR_DT_0,                       0x00000010
        .equ	RTC_TSDR_DT_1,                       0x00000020
        .equ	RTC_TSDR_DU,                         0x0000000F
        .equ	RTC_TSDR_DU_0,                       0x00000001
        .equ	RTC_TSDR_DU_1,                       0x00000002
        .equ	RTC_TSDR_DU_2,                       0x00000004
        .equ	RTC_TSDR_DU_3,                       0x00000008

/********************  Bits definition for RTC_TAFCR register  ****************/
        .equ	RTC_TAFCR_ALARMOUTTYPE,              0x00040000
        .equ	RTC_TAFCR_TAMPIE,                    0x00000004
        .equ	RTC_TAFCR_TAMP1TRG,                  0x00000002
        .equ	RTC_TAFCR_TAMP1E,                    0x00000001

/********************  Bits definition for RTC_BKP0R register  ****************/
        .equ	RTC_BKP0R,                           0xFFFFFFFF

/********************  Bits definition for RTC_BKP1R register  ****************/
        .equ	RTC_BKP1R,                           0xFFFFFFFF

/********************  Bits definition for RTC_BKP2R register  ****************/
        .equ	RTC_BKP2R,                           0xFFFFFFFF

/********************  Bits definition for RTC_BKP3R register  ****************/
        .equ	RTC_BKP3R,                           0xFFFFFFFF

/********************  Bits definition for RTC_BKP4R register  ****************/
        .equ	RTC_BKP4R,                           0xFFFFFFFF

/********************  Bits definition for RTC_BKP5R register  ****************/
        .equ	RTC_BKP5R,                           0xFFFFFFFF

/********************  Bits definition for RTC_BKP6R register  ****************/
        .equ	RTC_BKP6R,                           0xFFFFFFFF

/********************  Bits definition for RTC_BKP7R register  ****************/
        .equ	RTC_BKP7R,                           0xFFFFFFFF

/********************  Bits definition for RTC_BKP8R register  ****************/
        .equ	RTC_BKP8R,                           0xFFFFFFFF

/********************  Bits definition for RTC_BKP9R register  ****************/
        .equ	RTC_BKP9R,                           0xFFFFFFFF

/********************  Bits definition for RTC_BKP10R register  ***************/
        .equ	RTC_BKP10R,                          0xFFFFFFFF

/********************  Bits definition for RTC_BKP11R register  ***************/
        .equ	RTC_BKP11R,                          0xFFFFFFFF

/********************  Bits definition for RTC_BKP12R register  ***************/
        .equ	RTC_BKP12R,                          0xFFFFFFFF

/********************  Bits definition for RTC_BKP13R register  ***************/
        .equ	RTC_BKP13R,                          0xFFFFFFFF

/********************  Bits definition for RTC_BKP14R register  ***************/
        .equ	RTC_BKP14R,                          0xFFFFFFFF

/********************  Bits definition for RTC_BKP15R register  ***************/
        .equ	RTC_BKP15R,                          0xFFFFFFFF

/********************  Bits definition for RTC_BKP16R register  ***************/
        .equ	RTC_BKP16R,                          0xFFFFFFFF

/********************  Bits definition for RTC_BKP17R register  ***************/
        .equ	RTC_BKP17R,                          0xFFFFFFFF

/********************  Bits definition for RTC_BKP18R register  ***************/
        .equ	RTC_BKP18R,                          0xFFFFFFFF

/********************  Bits definition for RTC_BKP19R register  ***************/
        .equ	RTC_BKP19R,                          0xFFFFFFFF

/******************************************************************************/
/*                                                                            */
/*                     Serial Peripheral Interface (SPI)                      */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for SPI_CR1 register  ********************/
        .equ	 SPI_CR1_CPHA,                       0x0001	        /* Clock Phase */
        .equ	 SPI_CR1_CPOL,                       0x0002	        /* Clock Polarity */
        .equ	 SPI_CR1_MSTR,                       0x0004	        /* Master Selection */

        .equ	 SPI_CR1_BR,                         0x0038	        /* BR[2:0] bits (Baud Rate Control) */
        .equ	 SPI_CR1_BR_0,                       0x0008	        /* Bit 0 */
        .equ	 SPI_CR1_BR_1,                       0x0010	        /* Bit 1 */
        .equ	 SPI_CR1_BR_2,                       0x0020	        /* Bit 2 */

        .equ	 SPI_CR1_SPE,                        0x0040	        /* SPI Enable */
        .equ	 SPI_CR1_LSBFIRST,                   0x0080	        /* Frame Format */
        .equ	 SPI_CR1_SSI,                        0x0100	        /* Internal slave select */
        .equ	 SPI_CR1_SSM,                        0x0200	        /* Software slave management */
        .equ	 SPI_CR1_RXONLY,                     0x0400	        /* Receive only */
        .equ	 SPI_CR1_DFF,                        0x0800	        /* Data Frame Format */
        .equ	 SPI_CR1_CRCNEXT,                    0x1000	        /* Transmit CRC next */
        .equ	 SPI_CR1_CRCEN,                      0x2000	        /* Hardware CRC calculation enable */
        .equ	 SPI_CR1_BIDIOE,                     0x4000	        /* Output enable in bidirectional mode */
        .equ	 SPI_CR1_BIDIMODE,                   0x8000	        /* Bidirectional data mode enable */

/*******************  Bit definition for SPI_CR2 register  ********************/
        .equ	 SPI_CR2_RXDMAEN,                    0x01	           /* Rx Buffer DMA Enable */
        .equ	 SPI_CR2_TXDMAEN,                    0x02	           /* Tx Buffer DMA Enable */
        .equ	 SPI_CR2_SSOE,                       0x04	           /* SS Output Enable */
        .equ	 SPI_CR2_ERRIE,                      0x20	           /* Error Interrupt Enable */
        .equ	 SPI_CR2_RXNEIE,                     0x40	           /* RX buffer Not Empty Interrupt Enable */
        .equ	 SPI_CR2_TXEIE,                      0x80	           /* Tx buffer Empty Interrupt Enable */

/********************  Bit definition for SPI_SR register  ********************/
        .equ	 SPI_SR_RXNE,                        0x01	           /* Receive buffer Not Empty */
        .equ	 SPI_SR_TXE,                         0x02	           /* Transmit buffer Empty */
        .equ	 SPI_SR_CRCERR,                      0x10	           /* CRC Error flag */
        .equ	 SPI_SR_MODF,                        0x20	           /* Mode fault */
        .equ	 SPI_SR_OVR,                         0x40	           /* Overrun flag */
        .equ	 SPI_SR_BSY,                         0x80	           /* Busy flag */

/********************  Bit definition for SPI_DR register  ********************/
        .equ	 SPI_DR_DR,                          0xFFFF	        /* Data Register */

/*******************  Bit definition for SPI_CRCPR register  ******************/
        .equ	 SPI_CRCPR_CRCPOLY,                  0xFFFF	        /* CRC polynomial register */

/******************  Bit definition for SPI_RXCRCR register  ******************/
        .equ	 SPI_RXCRCR_RXCRC,                   0xFFFF	        /* Rx CRC Register */

/******************  Bit definition for SPI_TXCRCR register  ******************/
        .equ	 SPI_TXCRCR_TXCRC,                   0xFFFF	        /* Tx CRC Register */

/******************************************************************************/
/*                                                                            */
/*                       System Configuration (SYSCFG)                        */
/*                                                                            */
/******************************************************************************/
/*****************  Bit definition for SYSCFG_MEMRMP register  ****************/
        .equ	SYSCFG_MEMRMP_MEM_MODE,         0x00000003 /* SYSCFG_Memory Remap Config */
        .equ	SYSCFG_MEMRMP_MEM_MODE_0,       0x00000001 /* Bit 0 */
        .equ	SYSCFG_MEMRMP_MEM_MODE_1,       0x00000002 /* Bit 1 */

/*****************  Bit definition for SYSCFG_PMC register  *******************/
        .equ	SYSCFG_PMC_USB_PU,              0x00000001 /* SYSCFG PMC */

/*****************  Bit definition for SYSCFG_EXTICR1 register  ***************/
        .equ	SYSCFG_EXTICR1_EXTI0,           0x000F /* EXTI 0 configuration */
        .equ	SYSCFG_EXTICR1_EXTI1,           0x00F0 /* EXTI 1 configuration */
        .equ	SYSCFG_EXTICR1_EXTI2,           0x0F00 /* EXTI 2 configuration */
        .equ	SYSCFG_EXTICR1_EXTI3,           0xF000 /* EXTI 3 configuration */

/** 
  * @brief  EXTI0 configuration  
  */ 
        .equ	SYSCFG_EXTICR1_EXTI0_PA,        0x0000 /* PA[0] pin */
        .equ	SYSCFG_EXTICR1_EXTI0_PB,        0x0001 /* PB[0] pin */
        .equ	SYSCFG_EXTICR1_EXTI0_PC,        0x0002 /* PC[0] pin */
        .equ	SYSCFG_EXTICR1_EXTI0_PD,        0x0003 /* PD[0] pin */
        .equ	SYSCFG_EXTICR1_EXTI0_PE,        0x0004 /* PE[0] pin */
        .equ	SYSCFG_EXTICR1_EXTI0_PH,        0x0005 /* PH[0] pin */

/** 
  * @brief  EXTI1 configuration  
  */ 
        .equ	SYSCFG_EXTICR1_EXTI1_PA,        0x0000 /* PA[1] pin */
        .equ	SYSCFG_EXTICR1_EXTI1_PB,        0x0010 /* PB[1] pin */
        .equ	SYSCFG_EXTICR1_EXTI1_PC,        0x0020 /* PC[1] pin */
        .equ	SYSCFG_EXTICR1_EXTI1_PD,        0x0030 /* PD[1] pin */
        .equ	SYSCFG_EXTICR1_EXTI1_PE,        0x0040 /* PE[1] pin */
        .equ	SYSCFG_EXTICR1_EXTI1_PH,        0x0050 /* PH[1] pin */

/** 
  * @brief  EXTI2 configuration  
  */ 
        .equ	SYSCFG_EXTICR1_EXTI2_PA,        0x0000 /* PA[2] pin */
        .equ	SYSCFG_EXTICR1_EXTI2_PB,        0x0100 /* PB[2] pin */
        .equ	SYSCFG_EXTICR1_EXTI2_PC,        0x0200 /* PC[2] pin */
        .equ	SYSCFG_EXTICR1_EXTI2_PD,        0x0300 /* PD[2] pin */
        .equ	SYSCFG_EXTICR1_EXTI2_PE,        0x0400 /* PE[2] pin */
        .equ	SYSCFG_EXTICR1_EXTI2_PH,        0x0500 /* PH[2] pin */

/** 
  * @brief  EXTI3 configuration  
  */ 
        .equ	SYSCFG_EXTICR1_EXTI3_PA,        0x0000 /* PA[3] pin */
        .equ	SYSCFG_EXTICR1_EXTI3_PB,        0x1000 /* PB[3] pin */
        .equ	SYSCFG_EXTICR1_EXTI3_PC,        0x2000 /* PC[3] pin */
        .equ	SYSCFG_EXTICR1_EXTI3_PD,        0x3000 /* PD[3] pin */
        .equ	SYSCFG_EXTICR1_EXTI3_PE,        0x4000 /* PE[3] pin */

/*****************  Bit definition for SYSCFG_EXTICR2 register  *****************/
        .equ	SYSCFG_EXTICR2_EXTI4,           0x000F /* EXTI 4 configuration */
        .equ	SYSCFG_EXTICR2_EXTI5,           0x00F0 /* EXTI 5 configuration */
        .equ	SYSCFG_EXTICR2_EXTI6,           0x0F00 /* EXTI 6 configuration */
        .equ	SYSCFG_EXTICR2_EXTI7,           0xF000 /* EXTI 7 configuration */

/** 
  * @brief  EXTI4 configuration  
  */ 
        .equ	SYSCFG_EXTICR2_EXTI4_PA,        0x0000 /* PA[4] pin */
        .equ	SYSCFG_EXTICR2_EXTI4_PB,        0x0001 /* PB[4] pin */
        .equ	SYSCFG_EXTICR2_EXTI4_PC,        0x0002 /* PC[4] pin */
        .equ	SYSCFG_EXTICR2_EXTI4_PD,        0x0003 /* PD[4] pin */
        .equ	SYSCFG_EXTICR2_EXTI4_PE,        0x0004 /* PE[4] pin */

/** 
  * @brief  EXTI5 configuration  
  */ 
        .equ	SYSCFG_EXTICR2_EXTI5_PA,        0x0000 /* PA[5] pin */
        .equ	SYSCFG_EXTICR2_EXTI5_PB,        0x0010 /* PB[5] pin */
        .equ	SYSCFG_EXTICR2_EXTI5_PC,        0x0020 /* PC[5] pin */
        .equ	SYSCFG_EXTICR2_EXTI5_PD,        0x0030 /* PD[5] pin */
        .equ	SYSCFG_EXTICR2_EXTI5_PE,        0x0040 /* PE[5] pin */

/** 
  * @brief  EXTI6 configuration  
  */ 
        .equ	SYSCFG_EXTICR2_EXTI6_PA,        0x0000 /* PA[6] pin */
        .equ	SYSCFG_EXTICR2_EXTI6_PB,        0x0100 /* PB[6] pin */
        .equ	SYSCFG_EXTICR2_EXTI6_PC,        0x0200 /* PC[6] pin */
        .equ	SYSCFG_EXTICR2_EXTI6_PD,        0x0300 /* PD[6] pin */
        .equ	SYSCFG_EXTICR2_EXTI6_PE,        0x0400 /* PE[6] pin */

/** 
  * @brief  EXTI7 configuration  
  */ 
        .equ	SYSCFG_EXTICR2_EXTI7_PA,        0x0000 /* PA[7] pin */
        .equ	SYSCFG_EXTICR2_EXTI7_PB,        0x1000 /* PB[7] pin */
        .equ	SYSCFG_EXTICR2_EXTI7_PC,        0x2000 /* PC[7] pin */
        .equ	SYSCFG_EXTICR2_EXTI7_PD,        0x3000 /* PD[7] pin */
        .equ	SYSCFG_EXTICR2_EXTI7_PE,        0x4000 /* PE[7] pin */

/*****************  Bit definition for SYSCFG_EXTICR3 register  *****************/
        .equ	SYSCFG_EXTICR3_EXTI8,           0x000F /* EXTI 8 configuration */
        .equ	SYSCFG_EXTICR3_EXTI9,           0x00F0 /* EXTI 9 configuration */
        .equ	SYSCFG_EXTICR3_EXTI10,          0x0F00 /* EXTI 10 configuration */
        .equ	SYSCFG_EXTICR3_EXTI11,          0xF000 /* EXTI 11 configuration */
                                                                          
/** 
  * @brief  EXTI8 configuration  
  */ 
        .equ	SYSCFG_EXTICR3_EXTI8_PA,        0x0000 /* PA[8] pin */
        .equ	SYSCFG_EXTICR3_EXTI8_PB,        0x0001 /* PB[8] pin */
        .equ	SYSCFG_EXTICR3_EXTI8_PC,        0x0002 /* PC[8] pin */
        .equ	SYSCFG_EXTICR3_EXTI8_PD,        0x0003 /* PD[8] pin */
        .equ	SYSCFG_EXTICR3_EXTI8_PE,        0x0004 /* PE[8] pin */

/** 
  * @brief  EXTI9 configuration  
  */ 
        .equ	SYSCFG_EXTICR3_EXTI9_PA,        0x0000 /* PA[9] pin */
        .equ	SYSCFG_EXTICR3_EXTI9_PB,        0x0010 /* PB[9] pin */
        .equ	SYSCFG_EXTICR3_EXTI9_PC,        0x0020 /* PC[9] pin */
        .equ	SYSCFG_EXTICR3_EXTI9_PD,        0x0030 /* PD[9] pin */
        .equ	SYSCFG_EXTICR3_EXTI9_PE,        0x0040 /* PE[9] pin */

/** 
  * @brief  EXTI10 configuration  
  */ 
        .equ	SYSCFG_EXTICR3_EXTI10_PA,       0x0000 /* PA[10] pin */
        .equ	SYSCFG_EXTICR3_EXTI10_PB,       0x0100 /* PB[10] pin */
        .equ	SYSCFG_EXTICR3_EXTI10_PC,       0x0200 /* PC[10] pin */
        .equ	SYSCFG_EXTICR3_EXTI10_PD,       0x0300 /* PD[10] pin */
        .equ	SYSCFG_EXTICR3_EXTI10_PE,       0x0400 /* PE[10] pin */

/** 
  * @brief  EXTI11 configuration  
  */ 
        .equ	SYSCFG_EXTICR3_EXTI11_PA,       0x0000 /* PA[11] pin */
        .equ	SYSCFG_EXTICR3_EXTI11_PB,       0x1000 /* PB[11] pin */
        .equ	SYSCFG_EXTICR3_EXTI11_PC,       0x2000 /* PC[11] pin */
        .equ	SYSCFG_EXTICR3_EXTI11_PD,       0x3000 /* PD[11] pin */
        .equ	SYSCFG_EXTICR3_EXTI11_PE,       0x4000 /* PE[11] pin */

/*****************  Bit definition for SYSCFG_EXTICR4 register  *****************/
        .equ	SYSCFG_EXTICR4_EXTI12,          0x000F /* EXTI 12 configuration */
        .equ	SYSCFG_EXTICR4_EXTI13,          0x00F0 /* EXTI 13 configuration */
        .equ	SYSCFG_EXTICR4_EXTI14,          0x0F00 /* EXTI 14 configuration */
        .equ	SYSCFG_EXTICR4_EXTI15,          0xF000 /* EXTI 15 configuration */

/** 
  * @brief  EXTI12 configuration  
  */ 
        .equ	SYSCFG_EXTICR4_EXTI12_PA,       0x0000 /* PA[12] pin */
        .equ	SYSCFG_EXTICR4_EXTI12_PB,       0x0001 /* PB[12] pin */
        .equ	SYSCFG_EXTICR4_EXTI12_PC,       0x0002 /* PC[12] pin */
        .equ	SYSCFG_EXTICR4_EXTI12_PD,       0x0003 /* PD[12] pin */
        .equ	SYSCFG_EXTICR4_EXTI12_PE,       0x0004 /* PE[12] pin */

/** 
  * @brief  EXTI13 configuration  
  */ 
        .equ	SYSCFG_EXTICR4_EXTI13_PA,       0x0000 /* PA[13] pin */
        .equ	SYSCFG_EXTICR4_EXTI13_PB,       0x0010 /* PB[13] pin */
        .equ	SYSCFG_EXTICR4_EXTI13_PC,       0x0020 /* PC[13] pin */
        .equ	SYSCFG_EXTICR4_EXTI13_PD,       0x0030 /* PD[13] pin */
        .equ	SYSCFG_EXTICR4_EXTI13_PE,       0x0040 /* PE[13] pin */

/** 
  * @brief  EXTI14 configuration  
  */ 
        .equ	SYSCFG_EXTICR4_EXTI14_PA,       0x0000 /* PA[14] pin */
        .equ	SYSCFG_EXTICR4_EXTI14_PB,       0x0100 /* PB[14] pin */
        .equ	SYSCFG_EXTICR4_EXTI14_PC,       0x0200 /* PC[14] pin */
        .equ	SYSCFG_EXTICR4_EXTI14_PD,       0x0300 /* PD[14] pin */
        .equ	SYSCFG_EXTICR4_EXTI14_PE,       0x0400 /* PE[14] pin */

/** 
  * @brief  EXTI15 configuration  
  */ 
        .equ	SYSCFG_EXTICR4_EXTI15_PA,       0x0000 /* PA[15] pin */
        .equ	SYSCFG_EXTICR4_EXTI15_PB,       0x1000 /* PB[15] pin */
        .equ	SYSCFG_EXTICR4_EXTI15_PC,       0x2000 /* PC[15] pin */
        .equ	SYSCFG_EXTICR4_EXTI15_PD,       0x3000 /* PD[15] pin */
        .equ	SYSCFG_EXTICR4_EXTI15_PE,       0x4000 /* PE[15] pin */
 
/******************************************************************************/
/*                                                                            */
/*                       Routing Interface (RI)                               */
/*                                                                            */
/******************************************************************************/

/********************  Bit definition for RI_ICR register  ********************/
        .equ	 RI_ICR_IC1Z,                   0x0000000F /* IC1Z[3:0] bits (Input Capture 1 select bits) */
        .equ	 RI_ICR_IC1Z_0,                 0x00000001 /* Bit 0 */
        .equ	 RI_ICR_IC1Z_1,                 0x00000002 /* Bit 1 */
        .equ	 RI_ICR_IC1Z_2,                 0x00000004 /* Bit 2 */
        .equ	 RI_ICR_IC1Z_3,                 0x00000008 /* Bit 3 */

        .equ	 RI_ICR_IC2Z,                   0x000000F0 /* IC2Z[3:0] bits (Input Capture 2 select bits) */
        .equ	 RI_ICR_IC2Z_0,                 0x00000010 /* Bit 0 */
        .equ	 RI_ICR_IC2Z_1,                 0x00000020 /* Bit 1 */
        .equ	 RI_ICR_IC2Z_2,                 0x00000040 /* Bit 2 */
        .equ	 RI_ICR_IC2Z_3,                 0x00000080 /* Bit 3 */

        .equ	 RI_ICR_IC3Z,                   0x00000F00 /* IC3Z[3:0] bits (Input Capture 3 select bits) */
        .equ	 RI_ICR_IC3Z_0,                 0x00000100 /* Bit 0 */
        .equ	 RI_ICR_IC3Z_1,                 0x00000200 /* Bit 1 */
        .equ	 RI_ICR_IC3Z_2,                 0x00000400 /* Bit 2 */
        .equ	 RI_ICR_IC3Z_3,                 0x00000800 /* Bit 3 */

        .equ	 RI_ICR_IC4Z,                   0x0000F000 /* IC4Z[3:0] bits (Input Capture 4 select bits) */
        .equ	 RI_ICR_IC4Z_0,                 0x00001000 /* Bit 0 */
        .equ	 RI_ICR_IC4Z_1,                 0x00002000 /* Bit 1 */
        .equ	 RI_ICR_IC4Z_2,                 0x00004000 /* Bit 2 */
        .equ	 RI_ICR_IC4Z_3,                 0x00008000 /* Bit 3 */

        .equ	 RI_ICR_TIM,                    0x00030000 /* TIM[3:0] bits (Timers select bits) */
        .equ	 RI_ICR_TIM_0,                  0x00010000 /* Bit 0 */
        .equ	 RI_ICR_TIM_1,                  0x00020000 /* Bit 1 */

        .equ	 RI_ICR_IC1,                    0x00040000 /* Input capture 1 */
        .equ	 RI_ICR_IC2,                    0x00080000 /* Input capture 2 */
        .equ	 RI_ICR_IC3,                    0x00100000 /* Input capture 3 */
        .equ	 RI_ICR_IC4,                    0x00200000 /* Input capture 4 */

/********************  Bit definition for RI_ASCR1 register  ********************/
        .equ	 RI_ASCR1_CH,                   0x03FCFFFF /* AS_CH[25:18] & AS_CH[15:0] bits ( Analog switches selection bits) */
        .equ	 RI_ASCR1_CH_0,                 0x00000001 /* Bit 0 */
        .equ	 RI_ASCR1_CH_1,                 0x00000002 /* Bit 1 */
        .equ	 RI_ASCR1_CH_2,                 0x00000004 /* Bit 2 */
        .equ	 RI_ASCR1_CH_3,                 0x00000008 /* Bit 3 */
        .equ	 RI_ASCR1_CH_4,                 0x00000010 /* Bit 4 */
        .equ	 RI_ASCR1_CH_5,                 0x00000020 /* Bit 5 */
        .equ	 RI_ASCR1_CH_6,                 0x00000040 /* Bit 6 */
        .equ	 RI_ASCR1_CH_7,                 0x00000080 /* Bit 7 */
        .equ	 RI_ASCR1_CH_8,                 0x00000100 /* Bit 8 */
        .equ	 RI_ASCR1_CH_9,                 0x00000200 /* Bit 9 */
        .equ	 RI_ASCR1_CH_10,                0x00000400 /* Bit 10 */
        .equ	 RI_ASCR1_CH_11,                0x00000800 /* Bit 11 */
        .equ	 RI_ASCR1_CH_12,                0x00001000 /* Bit 12 */
        .equ	 RI_ASCR1_CH_13,                0x00002000 /* Bit 13 */
        .equ	 RI_ASCR1_CH_14,                0x00004000 /* Bit 14 */
        .equ	 RI_ASCR1_CH_15,                0x00008000 /* Bit 15 */
        .equ	 RI_ASCR1_CH_18,                0x00040000 /* Bit 18 */
        .equ	 RI_ASCR1_CH_19,                0x00080000 /* Bit 19 */
        .equ	 RI_ASCR1_CH_20,                0x00100000 /* Bit 20 */
        .equ	 RI_ASCR1_CH_21,                0x00200000 /* Bit 21 */
        .equ	 RI_ASCR1_CH_22,                0x00400000 /* Bit 22 */
        .equ	 RI_ASCR1_CH_23,                0x00800000 /* Bit 23 */
        .equ	 RI_ASCR1_CH_24,                0x01000000 /* Bit 24 */
        .equ	 RI_ASCR1_CH_25,                0x02000000 /* Bit 25 */

        .equ	 RI_ASCR1_VCOMP,                0x04000000 /* ADC analog switch selection for internal node to COMP1 */
        .equ	 RI_ASCR1_SCM,                  0x80000000 /* I/O Switch control mode */

/********************  Bit definition for RI_ASCR2 register  ********************/
        .equ	 RI_ASCR2_GR10_1,               0x00000001 /* GR10-1 selection bit */
        .equ	 RI_ASCR2_GR10_2,               0x00000002 /* GR10-2 selection bit */
        .equ	 RI_ASCR2_GR10_3,               0x00000004 /* GR10-3 selection bit */
        .equ	 RI_ASCR2_GR10_4,               0x00000008 /* GR10-4 selection bit */
        .equ	 RI_ASCR2_GR6_1,                0x00000010 /* GR6-1 selection bit */
        .equ	 RI_ASCR2_GR6_2,                0x00000020 /* GR6-2 selection bit */
        .equ	 RI_ASCR2_GR5_1,                0x00000040 /* GR5-1 selection bit */
        .equ	 RI_ASCR2_GR5_2,                0x00000080 /* GR5-2 selection bit */
        .equ	 RI_ASCR2_GR5_3,                0x00000100 /* GR5-3 selection bit */
        .equ	 RI_ASCR2_GR4_1,                0x00000200 /* GR4-1 selection bit */
        .equ	 RI_ASCR2_GR4_2,                0x00000400 /* GR4-2 selection bit */
        .equ	 RI_ASCR2_GR4_3,                0x00000800 /* GR4-3 selection bit */


/********************  Bit definition for RI_HYSCR1 register  ********************/
        .equ	 RI_HYSCR1_PA,                  0x0000FFFF /* PA[15:0] Port A Hysteresis selection */
        .equ	 RI_HYSCR1_PA_0,                0x00000001 /* Bit 0 */
        .equ	 RI_HYSCR1_PA_1,                0x00000002 /* Bit 1 */
        .equ	 RI_HYSCR1_PA_2,                0x00000004 /* Bit 2 */
        .equ	 RI_HYSCR1_PA_3,                0x00000008 /* Bit 3 */
        .equ	 RI_HYSCR1_PA_4,                0x00000010 /* Bit 4 */
        .equ	 RI_HYSCR1_PA_5,                0x00000020 /* Bit 5 */
        .equ	 RI_HYSCR1_PA_6,                0x00000040 /* Bit 6 */
        .equ	 RI_HYSCR1_PA_7,                0x00000080 /* Bit 7 */
        .equ	 RI_HYSCR1_PA_8,                0x00000100 /* Bit 8 */
        .equ	 RI_HYSCR1_PA_9,                0x00000200 /* Bit 9 */
        .equ	 RI_HYSCR1_PA_10,               0x00000400 /* Bit 10 */
        .equ	 RI_HYSCR1_PA_11,               0x00000800 /* Bit 11 */
        .equ	 RI_HYSCR1_PA_12,               0x00001000 /* Bit 12 */
        .equ	 RI_HYSCR1_PA_13,               0x00002000 /* Bit 13 */
        .equ	 RI_HYSCR1_PA_14,               0x00004000 /* Bit 14 */
        .equ	 RI_HYSCR1_PA_15,               0x00008000 /* Bit 15 */

        .equ	 RI_HYSCR1_PB,                  0xFFFF0000 /* PB[15:0] Port B Hysteresis selection */
        .equ	 RI_HYSCR1_PB_0,                0x00010000 /* Bit 0 */
        .equ	 RI_HYSCR1_PB_1,                0x00020000 /* Bit 1 */
        .equ	 RI_HYSCR1_PB_2,                0x00040000 /* Bit 2 */
        .equ	 RI_HYSCR1_PB_3,                0x00080000 /* Bit 3 */
        .equ	 RI_HYSCR1_PB_4,                0x00100000 /* Bit 4 */
        .equ	 RI_HYSCR1_PB_5,                0x00200000 /* Bit 5 */
        .equ	 RI_HYSCR1_PB_6,                0x00400000 /* Bit 6 */
        .equ	 RI_HYSCR1_PB_7,                0x00800000 /* Bit 7 */
        .equ	 RI_HYSCR1_PB_8,                0x01000000 /* Bit 8 */
        .equ	 RI_HYSCR1_PB_9,                0x02000000 /* Bit 9 */
        .equ	 RI_HYSCR1_PB_10,               0x04000000 /* Bit 10 */
        .equ	 RI_HYSCR1_PB_11,               0x08000000 /* Bit 11 */
        .equ	 RI_HYSCR1_PB_12,               0x10000000 /* Bit 12 */
        .equ	 RI_HYSCR1_PB_13,               0x20000000 /* Bit 13 */
        .equ	 RI_HYSCR1_PB_14,               0x40000000 /* Bit 14 */
        .equ	 RI_HYSCR1_PB_15,               0x80000000 /* Bit 15 */

/********************  Bit definition for RI_HYSCR2 register  ********************/
        .equ	 RI_HYSCR2_PC,                  0x0000FFFF /* PC[15:0] Port C Hysteresis selection */
        .equ	 RI_HYSCR2_PC_0,                0x00000001 /* Bit 0 */
        .equ	 RI_HYSCR2_PC_1,                0x00000002 /* Bit 1 */
        .equ	 RI_HYSCR2_PC_2,                0x00000004 /* Bit 2 */
        .equ	 RI_HYSCR2_PC_3,                0x00000008 /* Bit 3 */
        .equ	 RI_HYSCR2_PC_4,                0x00000010 /* Bit 4 */
        .equ	 RI_HYSCR2_PC_5,                0x00000020 /* Bit 5 */
        .equ	 RI_HYSCR2_PC_6,                0x00000040 /* Bit 6 */
        .equ	 RI_HYSCR2_PC_7,                0x00000080 /* Bit 7 */
        .equ	 RI_HYSCR2_PC_8,                0x00000100 /* Bit 8 */
        .equ	 RI_HYSCR2_PC_9,                0x00000200 /* Bit 9 */
        .equ	 RI_HYSCR2_PC_10,               0x00000400 /* Bit 10 */
        .equ	 RI_HYSCR2_PC_11,               0x00000800 /* Bit 11 */
        .equ	 RI_HYSCR2_PC_12,               0x00001000 /* Bit 12 */
        .equ	 RI_HYSCR2_PC_13,               0x00002000 /* Bit 13 */
        .equ	 RI_HYSCR2_PC_14,               0x00004000 /* Bit 14 */
        .equ	 RI_HYSCR2_PC_15,               0x00008000 /* Bit 15 */

        .equ	 RI_HYSCR2_PD,                  0xFFFF0000 /* PD[15:0] Port D Hysteresis selection */
        .equ	 RI_HYSCR2_PD_0,                0x00010000 /* Bit 0 */
        .equ	 RI_HYSCR2_PD_1,                0x00020000 /* Bit 1 */
        .equ	 RI_HYSCR2_PD_2,                0x00040000 /* Bit 2 */
        .equ	 RI_HYSCR2_PD_3,                0x00080000 /* Bit 3 */
        .equ	 RI_HYSCR2_PD_4,                0x00100000 /* Bit 4 */
        .equ	 RI_HYSCR2_PD_5,                0x00200000 /* Bit 5 */
        .equ	 RI_HYSCR2_PD_6,                0x00400000 /* Bit 6 */
        .equ	 RI_HYSCR2_PD_7,                0x00800000 /* Bit 7 */
        .equ	 RI_HYSCR2_PD_8,                0x01000000 /* Bit 8 */
        .equ	 RI_HYSCR2_PD_9,                0x02000000 /* Bit 9 */
        .equ	 RI_HYSCR2_PD_10,               0x04000000 /* Bit 10 */
        .equ	 RI_HYSCR2_PD_11,               0x08000000 /* Bit 11 */
        .equ	 RI_HYSCR2_PD_12,               0x10000000 /* Bit 12 */
        .equ	 RI_HYSCR2_PD_13,               0x20000000 /* Bit 13 */
        .equ	 RI_HYSCR2_PD_14,               0x40000000 /* Bit 14 */
        .equ	 RI_HYSCR2_PD_15,               0x80000000 /* Bit 15 */

/********************  Bit definition for RI_HYSCR3 register  ********************/
        .equ	 RI_HYSCR2_PE,                  0x0000FFFF /* PE[15:0] Port E Hysteresis selection */
        .equ	 RI_HYSCR2_PE_0,                0x00000001 /* Bit 0 */
        .equ	 RI_HYSCR2_PE_1,                0x00000002 /* Bit 1 */
        .equ	 RI_HYSCR2_PE_2,                0x00000004 /* Bit 2 */
        .equ	 RI_HYSCR2_PE_3,                0x00000008 /* Bit 3 */
        .equ	 RI_HYSCR2_PE_4,                0x00000010 /* Bit 4 */
        .equ	 RI_HYSCR2_PE_5,                0x00000020 /* Bit 5 */
        .equ	 RI_HYSCR2_PE_6,                0x00000040 /* Bit 6 */
        .equ	 RI_HYSCR2_PE_7,                0x00000080 /* Bit 7 */
        .equ	 RI_HYSCR2_PE_8,                0x00000100 /* Bit 8 */
        .equ	 RI_HYSCR2_PE_9,                0x00000200 /* Bit 9 */
        .equ	 RI_HYSCR2_PE_10,               0x00000400 /* Bit 10 */
        .equ	 RI_HYSCR2_PE_11,               0x00000800 /* Bit 11 */
        .equ	 RI_HYSCR2_PE_12,               0x00001000 /* Bit 12 */
        .equ	 RI_HYSCR2_PE_13,               0x00002000 /* Bit 13 */
        .equ	 RI_HYSCR2_PE_14,               0x00004000 /* Bit 14 */
        .equ	 RI_HYSCR2_PE_15,               0x00008000 /* Bit 15 */

/******************************************************************************/
/*                                                                            */
/*                               Timers (TIM)                                 */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for TIM_CR1 register  ********************/
        .equ	 TIM_CR1_CEN,                        0x0001	        /*Counter enable */
        .equ	 TIM_CR1_UDIS,                       0x0002	        /*Update disable */
        .equ	 TIM_CR1_URS,                        0x0004	        /*Update request source */
        .equ	 TIM_CR1_OPM,                        0x0008	        /*One pulse mode */
        .equ	 TIM_CR1_DIR,                        0x0010	        /*Direction */

        .equ	 TIM_CR1_CMS,                        0x0060	        /*CMS[1:0] bits (Center-aligned mode selection) */
        .equ	 TIM_CR1_CMS_0,                      0x0020	        /*Bit 0 */
        .equ	 TIM_CR1_CMS_1,                      0x0040	        /*Bit 1 */

        .equ	 TIM_CR1_ARPE,                       0x0080	        /*Auto-reload preload enable */

        .equ	 TIM_CR1_CKD,                        0x0300	        /*CKD[1:0] bits (clock division) */
        .equ	 TIM_CR1_CKD_0,                      0x0100	        /*Bit 0 */
        .equ	 TIM_CR1_CKD_1,                      0x0200	        /*Bit 1 */

/*******************  Bit definition for TIM_CR2 register  ********************/
        .equ	 TIM_CR2_CCPC,                       0x0001	        /*Capture/Compare Preloaded Control */
        .equ	 TIM_CR2_CCUS,                       0x0004	        /*Capture/Compare Control Update Selection */
        .equ	 TIM_CR2_CCDS,                       0x0008	        /*Capture/Compare DMA Selection */

        .equ	 TIM_CR2_MMS,                        0x0070	        /*MMS[2:0] bits (Master Mode Selection) */
        .equ	 TIM_CR2_MMS_0,                      0x0010	        /*Bit 0 */
        .equ	 TIM_CR2_MMS_1,                      0x0020	        /*Bit 1 */
        .equ	 TIM_CR2_MMS_2,                      0x0040	        /*Bit 2 */

        .equ	 TIM_CR2_TI1S,                       0x0080	        /*TI1 Selection */
        .equ	 TIM_CR2_OIS1,                       0x0100	        /*Output Idle state 1 (OC1 output) */
        .equ	 TIM_CR2_OIS1N,                      0x0200	        /*Output Idle state 1 (OC1N output) */
        .equ	 TIM_CR2_OIS2,                       0x0400	        /*Output Idle state 2 (OC2 output) */
        .equ	 TIM_CR2_OIS2N,                      0x0800	        /*Output Idle state 2 (OC2N output) */
        .equ	 TIM_CR2_OIS3,                       0x1000	        /*Output Idle state 3 (OC3 output) */
        .equ	 TIM_CR2_OIS3N,                      0x2000	        /*Output Idle state 3 (OC3N output) */
        .equ	 TIM_CR2_OIS4,                       0x4000	        /*Output Idle state 4 (OC4 output) */

/*******************  Bit definition for TIM_SMCR register  *******************/
        .equ	 TIM_SMCR_SMS,                       0x0007	        /*SMS[2:0] bits (Slave mode selection) */
        .equ	 TIM_SMCR_SMS_0,                     0x0001	        /*Bit 0 */
        .equ	 TIM_SMCR_SMS_1,                     0x0002	        /*Bit 1 */
        .equ	 TIM_SMCR_SMS_2,                     0x0004	        /*Bit 2 */

        .equ	 TIM_SMCR_OCCS,                      0x0008	        /*OCCS bits (OCref Clear Selection) */

        .equ	 TIM_SMCR_TS,                        0x0070	        /*TS[2:0] bits (Trigger selection) */
        .equ	 TIM_SMCR_TS_0,                      0x0010	        /*Bit 0 */
        .equ	 TIM_SMCR_TS_1,                      0x0020	        /*Bit 1 */
        .equ	 TIM_SMCR_TS_2,                      0x0040	        /*Bit 2 */

        .equ	 TIM_SMCR_MSM,                       0x0080	        /*Master/slave mode */

        .equ	 TIM_SMCR_ETF,                       0x0F00	        /*ETF[3:0] bits (External trigger filter) */
        .equ	 TIM_SMCR_ETF_0,                     0x0100	        /*Bit 0 */
        .equ	 TIM_SMCR_ETF_1,                     0x0200	        /*Bit 1 */
        .equ	 TIM_SMCR_ETF_2,                     0x0400	        /*Bit 2 */
        .equ	 TIM_SMCR_ETF_3,                     0x0800	        /*Bit 3 */

        .equ	 TIM_SMCR_ETPS,                      0x3000	        /*ETPS[1:0] bits (External trigger prescaler) */
        .equ	 TIM_SMCR_ETPS_0,                    0x1000	        /*Bit 0 */
        .equ	 TIM_SMCR_ETPS_1,                    0x2000	        /*Bit 1 */

        .equ	 TIM_SMCR_ECE,                       0x4000	        /*External clock enable */
        .equ	 TIM_SMCR_ETP,                       0x8000	        /*External trigger polarity */

/*******************  Bit definition for TIM_DIER register  *******************/
        .equ	 TIM_DIER_UIE,                       0x0001	        /*Update interrupt enable */
        .equ	 TIM_DIER_CC1IE,                     0x0002	        /*Capture/Compare 1 interrupt enable */
        .equ	 TIM_DIER_CC2IE,                     0x0004	        /*Capture/Compare 2 interrupt enable */
        .equ	 TIM_DIER_CC3IE,                     0x0008	        /*Capture/Compare 3 interrupt enable */
        .equ	 TIM_DIER_CC4IE,                     0x0010	        /*Capture/Compare 4 interrupt enable */
        .equ	 TIM_DIER_COMIE,                     0x0020	        /*COM interrupt enable */
        .equ	 TIM_DIER_TIE,                       0x0040	        /*Trigger interrupt enable */
        .equ	 TIM_DIER_BIE,                       0x0080	        /*Break interrupt enable */
        .equ	 TIM_DIER_UDE,                       0x0100	        /*Update DMA request enable */
        .equ	 TIM_DIER_CC1DE,                     0x0200	        /*Capture/Compare 1 DMA request enable */
        .equ	 TIM_DIER_CC2DE,                     0x0400	        /*Capture/Compare 2 DMA request enable */
        .equ	 TIM_DIER_CC3DE,                     0x0800	        /*Capture/Compare 3 DMA request enable */
        .equ	 TIM_DIER_CC4DE,                     0x1000	        /*Capture/Compare 4 DMA request enable */
        .equ	 TIM_DIER_COMDE,                     0x2000	        /*COM DMA request enable */
        .equ	 TIM_DIER_TDE,                       0x4000	        /*Trigger DMA request enable */

/********************  Bit definition for TIM_SR register  ********************/
        .equ	 TIM_SR_UIF,                         0x0001	        /*Update interrupt Flag */
        .equ	 TIM_SR_CC1IF,                       0x0002	        /*Capture/Compare 1 interrupt Flag */
        .equ	 TIM_SR_CC2IF,                       0x0004	        /*Capture/Compare 2 interrupt Flag */
        .equ	 TIM_SR_CC3IF,                       0x0008	        /*Capture/Compare 3 interrupt Flag */
        .equ	 TIM_SR_CC4IF,                       0x0010	        /*Capture/Compare 4 interrupt Flag */
        .equ	 TIM_SR_COMIF,                       0x0020	        /*COM interrupt Flag */
        .equ	 TIM_SR_TIF,                         0x0040	        /*Trigger interrupt Flag */
        .equ	 TIM_SR_BIF,                         0x0080	        /*Break interrupt Flag */
        .equ	 TIM_SR_CC1OF,                       0x0200	        /*Capture/Compare 1 Overcapture Flag */
        .equ	 TIM_SR_CC2OF,                       0x0400	        /*Capture/Compare 2 Overcapture Flag */
        .equ	 TIM_SR_CC3OF,                       0x0800	        /*Capture/Compare 3 Overcapture Flag */
        .equ	 TIM_SR_CC4OF,                       0x1000	        /*Capture/Compare 4 Overcapture Flag */

/*******************  Bit definition for TIM_EGR register  ********************/
        .equ	 TIM_EGR_UG,                         0x01	        /*Update Generation */
        .equ	 TIM_EGR_CC1G,                       0x02	        /*Capture/Compare 1 Generation */
        .equ	 TIM_EGR_CC2G,                       0x04	        /*Capture/Compare 2 Generation */
        .equ	 TIM_EGR_CC3G,                       0x08	        /*Capture/Compare 3 Generation */
        .equ	 TIM_EGR_CC4G,                       0x10	        /*Capture/Compare 4 Generation */
        .equ	 TIM_EGR_COMG,                       0x20	        /*Capture/Compare Control Update Generation */
        .equ	 TIM_EGR_TG,                         0x40	        /*Trigger Generation */
        .equ	 TIM_EGR_BG,                         0x80	        /*Break Generation */

/******************  Bit definition for TIM_CCMR1 register  *******************/
        .equ	 TIM_CCMR1_CC1S,                     0x0003	        /*CC1S[1:0] bits (Capture/Compare 1 Selection) */
        .equ	 TIM_CCMR1_CC1S_0,                   0x0001	        /*Bit 0 */
        .equ	 TIM_CCMR1_CC1S_1,                   0x0002	        /*Bit 1 */

        .equ	 TIM_CCMR1_OC1FE,                    0x0004	        /*Output Compare 1 Fast enable */
        .equ	 TIM_CCMR1_OC1PE,                    0x0008	        /*Output Compare 1 Preload enable */

        .equ	 TIM_CCMR1_OC1M,                     0x0070	        /*OC1M[2:0] bits (Output Compare 1 Mode) */
        .equ	 TIM_CCMR1_OC1M_0,                   0x0010	        /*Bit 0 */
        .equ	 TIM_CCMR1_OC1M_1,                   0x0020	        /*Bit 1 */
        .equ	 TIM_CCMR1_OC1M_2,                   0x0040	        /*Bit 2 */

        .equ	 TIM_CCMR1_OC1CE,                    0x0080	        /*Output Compare 1Clear Enable */

        .equ	 TIM_CCMR1_CC2S,                     0x0300	        /*CC2S[1:0] bits (Capture/Compare 2 Selection) */
        .equ	 TIM_CCMR1_CC2S_0,                   0x0100	        /*Bit 0 */
        .equ	 TIM_CCMR1_CC2S_1,                   0x0200	        /*Bit 1 */

        .equ	 TIM_CCMR1_OC2FE,                    0x0400	        /*Output Compare 2 Fast enable */
        .equ	 TIM_CCMR1_OC2PE,                    0x0800	        /*Output Compare 2 Preload enable */

        .equ	 TIM_CCMR1_OC2M,                     0x7000	        /*OC2M[2:0] bits (Output Compare 2 Mode) */
        .equ	 TIM_CCMR1_OC2M_0,                   0x1000	        /*Bit 0 */
        .equ	 TIM_CCMR1_OC2M_1,                   0x2000	        /*Bit 1 */
        .equ	 TIM_CCMR1_OC2M_2,                   0x4000	        /*Bit 2 */

        .equ	 TIM_CCMR1_OC2CE,                    0x8000	        /*Output Compare 2 Clear Enable */

/*----------------------------------------------------------------------------*/

        .equ	 TIM_CCMR1_IC1PSC,                   0x000C	        /*IC1PSC[1:0] bits (Input Capture 1 Prescaler) */
        .equ	 TIM_CCMR1_IC1PSC_0,                 0x0004	        /*Bit 0 */
        .equ	 TIM_CCMR1_IC1PSC_1,                 0x0008	        /*Bit 1 */

        .equ	 TIM_CCMR1_IC1F,                     0x00F0	        /*IC1F[3:0] bits (Input Capture 1 Filter) */
        .equ	 TIM_CCMR1_IC1F_0,                   0x0010	        /*Bit 0 */
        .equ	 TIM_CCMR1_IC1F_1,                   0x0020	        /*Bit 1 */
        .equ	 TIM_CCMR1_IC1F_2,                   0x0040	        /*Bit 2 */
        .equ	 TIM_CCMR1_IC1F_3,                   0x0080	        /*Bit 3 */

        .equ	 TIM_CCMR1_IC2PSC,                   0x0C00	        /*IC2PSC[1:0] bits (Input Capture 2 Prescaler) */
        .equ	 TIM_CCMR1_IC2PSC_0,                 0x0400	        /*Bit 0 */
        .equ	 TIM_CCMR1_IC2PSC_1,                 0x0800	        /*Bit 1 */

        .equ	 TIM_CCMR1_IC2F,                     0xF000	        /*IC2F[3:0] bits (Input Capture 2 Filter) */
        .equ	 TIM_CCMR1_IC2F_0,                   0x1000	        /*Bit 0 */
        .equ	 TIM_CCMR1_IC2F_1,                   0x2000	        /*Bit 1 */
        .equ	 TIM_CCMR1_IC2F_2,                   0x4000	        /*Bit 2 */
        .equ	 TIM_CCMR1_IC2F_3,                   0x8000	        /*Bit 3 */

/******************  Bit definition for TIM_CCMR2 register  *******************/
        .equ	 TIM_CCMR2_CC3S,                     0x0003	        /*CC3S[1:0] bits (Capture/Compare 3 Selection) */
        .equ	 TIM_CCMR2_CC3S_0,                   0x0001	        /*Bit 0 */
        .equ	 TIM_CCMR2_CC3S_1,                   0x0002	        /*Bit 1 */

        .equ	 TIM_CCMR2_OC3FE,                    0x0004	        /*Output Compare 3 Fast enable */
        .equ	 TIM_CCMR2_OC3PE,                    0x0008	        /*Output Compare 3 Preload enable */

        .equ	 TIM_CCMR2_OC3M,                     0x0070	        /*OC3M[2:0] bits (Output Compare 3 Mode) */
        .equ	 TIM_CCMR2_OC3M_0,                   0x0010	        /*Bit 0 */
        .equ	 TIM_CCMR2_OC3M_1,                   0x0020	        /*Bit 1 */
        .equ	 TIM_CCMR2_OC3M_2,                   0x0040	        /*Bit 2 */

        .equ	 TIM_CCMR2_OC3CE,                    0x0080	        /*Output Compare 3 Clear Enable */

        .equ	 TIM_CCMR2_CC4S,                     0x0300	        /*CC4S[1:0] bits (Capture/Compare 4 Selection) */
        .equ	 TIM_CCMR2_CC4S_0,                   0x0100	        /*Bit 0 */
        .equ	 TIM_CCMR2_CC4S_1,                   0x0200	        /*Bit 1 */

        .equ	 TIM_CCMR2_OC4FE,                    0x0400	        /*Output Compare 4 Fast enable */
        .equ	 TIM_CCMR2_OC4PE,                    0x0800	        /*Output Compare 4 Preload enable */

        .equ	 TIM_CCMR2_OC4M,                     0x7000	        /*OC4M[2:0] bits (Output Compare 4 Mode) */
        .equ	 TIM_CCMR2_OC4M_0,                   0x1000	        /*Bit 0 */
        .equ	 TIM_CCMR2_OC4M_1,                   0x2000	        /*Bit 1 */
        .equ	 TIM_CCMR2_OC4M_2,                   0x4000	        /*Bit 2 */

        .equ	 TIM_CCMR2_OC4CE,                    0x8000	        /*Output Compare 4 Clear Enable */

/*----------------------------------------------------------------------------*/

        .equ	 TIM_CCMR2_IC3PSC,                   0x000C	        /*IC3PSC[1:0] bits (Input Capture 3 Prescaler) */
        .equ	 TIM_CCMR2_IC3PSC_0,                 0x0004	        /*Bit 0 */
        .equ	 TIM_CCMR2_IC3PSC_1,                 0x0008	        /*Bit 1 */

        .equ	 TIM_CCMR2_IC3F,                     0x00F0	        /*IC3F[3:0] bits (Input Capture 3 Filter) */
        .equ	 TIM_CCMR2_IC3F_0,                   0x0010	        /*Bit 0 */
        .equ	 TIM_CCMR2_IC3F_1,                   0x0020	        /*Bit 1 */
        .equ	 TIM_CCMR2_IC3F_2,                   0x0040	        /*Bit 2 */
        .equ	 TIM_CCMR2_IC3F_3,                   0x0080	        /*Bit 3 */

        .equ	 TIM_CCMR2_IC4PSC,                   0x0C00	        /*IC4PSC[1:0] bits (Input Capture 4 Prescaler) */
        .equ	 TIM_CCMR2_IC4PSC_0,                 0x0400	        /*Bit 0 */
        .equ	 TIM_CCMR2_IC4PSC_1,                 0x0800	        /*Bit 1 */

        .equ	 TIM_CCMR2_IC4F,                     0xF000	        /*IC4F[3:0] bits (Input Capture 4 Filter) */
        .equ	 TIM_CCMR2_IC4F_0,                   0x1000	        /*Bit 0 */
        .equ	 TIM_CCMR2_IC4F_1,                   0x2000	        /*Bit 1 */
        .equ	 TIM_CCMR2_IC4F_2,                   0x4000	        /*Bit 2 */
        .equ	 TIM_CCMR2_IC4F_3,                   0x8000	        /*Bit 3 */

/*******************  Bit definition for TIM_CCER register  *******************/
        .equ	 TIM_CCER_CC1E,                      0x0001	        /*Capture/Compare 1 output enable */
        .equ	 TIM_CCER_CC1P,                      0x0002	        /*Capture/Compare 1 output Polarity */
        .equ	 TIM_CCER_CC1NE,                     0x0004	        /*Capture/Compare 1 Complementary output enable */
        .equ	 TIM_CCER_CC1NP,                     0x0008	        /*Capture/Compare 1 Complementary output Polarity */
        .equ	 TIM_CCER_CC2E,                      0x0010	        /*Capture/Compare 2 output enable */
        .equ	 TIM_CCER_CC2P,                      0x0020	        /*Capture/Compare 2 output Polarity */
        .equ	 TIM_CCER_CC2NE,                     0x0040	        /*Capture/Compare 2 Complementary output enable */
        .equ	 TIM_CCER_CC2NP,                     0x0080	        /*Capture/Compare 2 Complementary output Polarity */
        .equ	 TIM_CCER_CC3E,                      0x0100	        /*Capture/Compare 3 output enable */
        .equ	 TIM_CCER_CC3P,                      0x0200	        /*Capture/Compare 3 output Polarity */
        .equ	 TIM_CCER_CC3NE,                     0x0400	        /*Capture/Compare 3 Complementary output enable */
        .equ	 TIM_CCER_CC3NP,                     0x0800	        /*Capture/Compare 3 Complementary output Polarity */
        .equ	 TIM_CCER_CC4E,                      0x1000	        /*Capture/Compare 4 output enable */
        .equ	 TIM_CCER_CC4P,                      0x2000	        /*Capture/Compare 4 output Polarity */
        .equ	 TIM_CCER_CC4NP,                     0x8000	        /*Capture/Compare 4 Complementary output Polarity */

/*******************  Bit definition for TIM_CNT register  ********************/
        .equ	 TIM_CNT_CNT,                        0xFFFF	        /*Counter Value */

/*******************  Bit definition for TIM_PSC register  ********************/
        .equ	 TIM_PSC_PSC,                        0xFFFF	        /*Prescaler Value */

/*******************  Bit definition for TIM_ARR register  ********************/
        .equ	 TIM_ARR_ARR,                        0xFFFF	        /*actual auto-reload Value */

/*******************  Bit definition for TIM_RCR register  ********************/
        .equ	 TIM_RCR_REP,                        0xFF	           /*Repetition Counter Value */

/*******************  Bit definition for TIM_CCR1 register  *******************/
        .equ	 TIM_CCR1_CCR1,                      0xFFFF	        /*Capture/Compare 1 Value */

/*******************  Bit definition for TIM_CCR2 register  *******************/
        .equ	 TIM_CCR2_CCR2,                      0xFFFF	        /*Capture/Compare 2 Value */

/*******************  Bit definition for TIM_CCR3 register  *******************/
        .equ	 TIM_CCR3_CCR3,                      0xFFFF	        /*Capture/Compare 3 Value */

/*******************  Bit definition for TIM_CCR4 register  *******************/
        .equ	 TIM_CCR4_CCR4,                      0xFFFF	        /*Capture/Compare 4 Value */

/*******************  Bit definition for TIM_DCR register  ********************/
        .equ	 TIM_DCR_DBA,                        0x001F	        /*DBA[4:0] bits (DMA Base Address) */
        .equ	 TIM_DCR_DBA_0,                      0x0001	        /*Bit 0 */
        .equ	 TIM_DCR_DBA_1,                      0x0002	        /*Bit 1 */
        .equ	 TIM_DCR_DBA_2,                      0x0004	        /*Bit 2 */
        .equ	 TIM_DCR_DBA_3,                      0x0008	        /*Bit 3 */
        .equ	 TIM_DCR_DBA_4,                      0x0010	        /*Bit 4 */

        .equ	 TIM_DCR_DBL,                        0x1F00	        /*DBL[4:0] bits (DMA Burst Length) */
        .equ	 TIM_DCR_DBL_0,                      0x0100	        /*Bit 0 */
        .equ	 TIM_DCR_DBL_1,                      0x0200	        /*Bit 1 */
        .equ	 TIM_DCR_DBL_2,                      0x0400	        /*Bit 2 */
        .equ	 TIM_DCR_DBL_3,                      0x0800	        /*Bit 3 */
        .equ	 TIM_DCR_DBL_4,                      0x1000	        /*Bit 4 */

/*******************  Bit definition for TIM_DMAR register  *******************/
        .equ	 TIM_DMAR_DMAB,                      0xFFFF	        /*DMA register for burst accesses */

/*******************  Bit definition for TIM_OR register  *********************/
        .equ	 TIM_OR_TI1RMP,                      0x0003	        /*Option register for TI1 Remapping */
        .equ	 TIM_OR_TI1RMP_0,                    0x0001	        /*Bit 0 */
        .equ	 TIM_OR_TI1RMP_1,                    0x0002	        /*Bit 1 */

/******************************************************************************/
/*                                                                            */
/*      Universal Synchronous Asynchronous Receiver Transmitter (USART)       */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for USART_SR register  *******************/
        .equ	 USART_SR_PE,                        0x0001	        /* Parity Error */
        .equ	 USART_SR_FE,                        0x0002	        /* Framing Error */
        .equ	 USART_SR_NE,                        0x0004	        /* Noise Error Flag */
        .equ	 USART_SR_ORE,                       0x0008	        /* OverRun Error */
        .equ	 USART_SR_IDLE,                      0x0010	        /* IDLE line detected */
        .equ	 USART_SR_RXNE,                      0x0020	        /* Read Data Register Not Empty */
        .equ	 USART_SR_TC,                        0x0040	        /* Transmission Complete */
        .equ	 USART_SR_TXE,                       0x0080	        /* Transmit Data Register Empty */
        .equ	 USART_SR_LBD,                       0x0100	        /* LIN Break Detection Flag */
        .equ	 USART_SR_CTS,                       0x0200	        /* CTS Flag */

/*******************  Bit definition for USART_DR register  *******************/
        .equ	 USART_DR_DR,                        0x01FF	        /* Data value */

/******************  Bit definition for USART_BRR register  *******************/
        .equ	 USART_BRR_DIV_FRACTION,             0x000F	        /* Fraction of USARTDIV */
        .equ	 USART_BRR_DIV_MANTISSA,             0xFFF0	        /* Mantissa of USARTDIV */

/******************  Bit definition for USART_CR1 register  *******************/
        .equ	 USART_CR1_SBK,                      0x0001	        /* Send Break */
        .equ	 USART_CR1_RWU,                      0x0002	        /* Receiver wakeup */
        .equ	 USART_CR1_RE,                       0x0004	        /* Receiver Enable */
        .equ	 USART_CR1_TE,                       0x0008	        /* Transmitter Enable */
        .equ	 USART_CR1_IDLEIE,                   0x0010	        /* IDLE Interrupt Enable */
        .equ	 USART_CR1_RXNEIE,                   0x0020	        /* RXNE Interrupt Enable */
        .equ	 USART_CR1_TCIE,                     0x0040	        /* Transmission Complete Interrupt Enable */
        .equ	 USART_CR1_TXEIE,                    0x0080	        /* PE Interrupt Enable */
        .equ	 USART_CR1_PEIE,                     0x0100	        /* PE Interrupt Enable */
        .equ	 USART_CR1_PS,                       0x0200	        /* Parity Selection */
        .equ	 USART_CR1_PCE,                      0x0400	        /* Parity Control Enable */
        .equ	 USART_CR1_WAKE,                     0x0800	        /* Wakeup method */
        .equ	 USART_CR1_M,                        0x1000	        /* Word length */
        .equ	 USART_CR1_UE,                       0x2000	        /* USART Enable */
        .equ	 USART_CR1_OVER8,                    0x8000	        /* Oversampling by 8-bit mode */

/******************  Bit definition for USART_CR2 register  *******************/
        .equ	 USART_CR2_ADD,                      0x000F	        /* Address of the USART node */
        .equ	 USART_CR2_LBDL,                     0x0020	        /* LIN Break Detection Length */
        .equ	 USART_CR2_LBDIE,                    0x0040	        /* LIN Break Detection Interrupt Enable */
        .equ	 USART_CR2_LBCL,                     0x0100	        /* Last Bit Clock pulse */
        .equ	 USART_CR2_CPHA,                     0x0200	        /* Clock Phase */
        .equ	 USART_CR2_CPOL,                     0x0400	        /* Clock Polarity */
        .equ	 USART_CR2_CLKEN,                    0x0800	        /* Clock Enable */

        .equ	 USART_CR2_STOP,                     0x3000	        /* STOP[1:0] bits (STOP bits) */
        .equ	 USART_CR2_STOP_0,                   0x1000	        /* Bit 0 */
        .equ	 USART_CR2_STOP_1,                   0x2000	        /* Bit 1 */

        .equ	 USART_CR2_LINEN,                    0x4000	        /* LIN mode enable */

/******************  Bit definition for USART_CR3 register  *******************/
        .equ	 USART_CR3_EIE,                      0x0001	        /* Error Interrupt Enable */
        .equ	 USART_CR3_IREN,                     0x0002	        /* IrDA mode Enable */
        .equ	 USART_CR3_IRLP,                     0x0004	        /* IrDA Low-Power */
        .equ	 USART_CR3_HDSEL,                    0x0008	        /* Half-Duplex Selection */
        .equ	 USART_CR3_NACK,                     0x0010	        /* Smartcard NACK enable */
        .equ	 USART_CR3_SCEN,                     0x0020	        /* Smartcard mode enable */
        .equ	 USART_CR3_DMAR,                     0x0040	        /* DMA Enable Receiver */
        .equ	 USART_CR3_DMAT,                     0x0080	        /* DMA Enable Transmitter */
        .equ	 USART_CR3_RTSE,                     0x0100	        /* RTS Enable */
        .equ	 USART_CR3_CTSE,                     0x0200	        /* CTS Enable */
        .equ	 USART_CR3_CTSIE,                    0x0400	        /* CTS Interrupt Enable */
        .equ	 USART_CR3_ONEBIT,                   0x0800	        /* One sample bit method enable */

/******************  Bit definition for USART_GTPR register  ******************/
        .equ	 USART_GTPR_PSC,                     0x00FF	        /* PSC[7:0] bits (Prescaler value) */
        .equ	 USART_GTPR_PSC_0,                   0x0001	        /* Bit 0 */
        .equ	 USART_GTPR_PSC_1,                   0x0002	        /* Bit 1 */
        .equ	 USART_GTPR_PSC_2,                   0x0004	        /* Bit 2 */
        .equ	 USART_GTPR_PSC_3,                   0x0008	        /* Bit 3 */
        .equ	 USART_GTPR_PSC_4,                   0x0010	        /* Bit 4 */
        .equ	 USART_GTPR_PSC_5,                   0x0020	        /* Bit 5 */
        .equ	 USART_GTPR_PSC_6,                   0x0040	        /* Bit 6 */
        .equ	 USART_GTPR_PSC_7,                   0x0080	        /* Bit 7 */

        .equ	 USART_GTPR_GT,                      0xFF00	        /* Guard time value */

/******************************************************************************/
/*                                                                            */
/*                     Universal Serial Bus (USB)                             */
/*                                                                            */
/******************************************************************************/

/*Endpoint-specific registers */
/*******************  Bit definition for USB_EP0R register  *******************/
        .equ	 USB_EP0R_EA,                        0x000F	        /*Endpoint Address */

        .equ	 USB_EP0R_STAT_TX,                   0x0030	        /*STAT_TX[1:0] bits (Status bits, for transmission transfers) */
        .equ	 USB_EP0R_STAT_TX_0,                 0x0010	        /*Bit 0 */
        .equ	 USB_EP0R_STAT_TX_1,                 0x0020	        /*Bit 1 */

        .equ	 USB_EP0R_DTOG_TX,                   0x0040	        /*Data Toggle, for transmission transfers */
        .equ	 USB_EP0R_CTR_TX,                    0x0080	        /*Correct Transfer for transmission */
        .equ	 USB_EP0R_EP_KIND,                   0x0100	        /*Endpoint Kind */

        .equ	 USB_EP0R_EP_TYPE,                   0x0600	        /*EP_TYPE[1:0] bits (Endpoint type) */
        .equ	 USB_EP0R_EP_TYPE_0,                 0x0200	        /*Bit 0 */
        .equ	 USB_EP0R_EP_TYPE_1,                 0x0400	        /*Bit 1 */

        .equ	 USB_EP0R_SETUP,                     0x0800	        /*Setup transaction completed */

        .equ	 USB_EP0R_STAT_RX,                   0x3000	        /*STAT_RX[1:0] bits (Status bits, for reception transfers) */
        .equ	 USB_EP0R_STAT_RX_0,                 0x1000	        /*Bit 0 */
        .equ	 USB_EP0R_STAT_RX_1,                 0x2000	        /*Bit 1 */

        .equ	 USB_EP0R_DTOG_RX,                   0x4000	        /*Data Toggle, for reception transfers */
        .equ	 USB_EP0R_CTR_RX,                    0x8000	        /*Correct Transfer for reception */

/*******************  Bit definition for USB_EP1R register  *******************/
        .equ	 USB_EP1R_EA,                        0x000F	        /*Endpoint Address */

        .equ	 USB_EP1R_STAT_TX,                   0x0030	        /*STAT_TX[1:0] bits (Status bits, for transmission transfers) */
        .equ	 USB_EP1R_STAT_TX_0,                 0x0010	        /*Bit 0 */
        .equ	 USB_EP1R_STAT_TX_1,                 0x0020	        /*Bit 1 */

        .equ	 USB_EP1R_DTOG_TX,                   0x0040	        /*Data Toggle, for transmission transfers */
        .equ	 USB_EP1R_CTR_TX,                    0x0080	        /*Correct Transfer for transmission */
        .equ	 USB_EP1R_EP_KIND,                   0x0100	        /*Endpoint Kind */

        .equ	 USB_EP1R_EP_TYPE,                   0x0600	        /*EP_TYPE[1:0] bits (Endpoint type) */
        .equ	 USB_EP1R_EP_TYPE_0,                 0x0200	        /*Bit 0 */
        .equ	 USB_EP1R_EP_TYPE_1,                 0x0400	        /*Bit 1 */

        .equ	 USB_EP1R_SETUP,                     0x0800	        /*Setup transaction completed */

        .equ	 USB_EP1R_STAT_RX,                   0x3000	        /*STAT_RX[1:0] bits (Status bits, for reception transfers) */
        .equ	 USB_EP1R_STAT_RX_0,                 0x1000	        /*Bit 0 */
        .equ	 USB_EP1R_STAT_RX_1,                 0x2000	        /*Bit 1 */

        .equ	 USB_EP1R_DTOG_RX,                   0x4000	        /*Data Toggle, for reception transfers */
        .equ	 USB_EP1R_CTR_RX,                    0x8000	        /*Correct Transfer for reception */

/*******************  Bit definition for USB_EP2R register  *******************/
        .equ	 USB_EP2R_EA,                        0x000F	        /*Endpoint Address */

        .equ	 USB_EP2R_STAT_TX,                   0x0030	        /*STAT_TX[1:0] bits (Status bits, for transmission transfers) */
        .equ	 USB_EP2R_STAT_TX_0,                 0x0010	        /*Bit 0 */
        .equ	 USB_EP2R_STAT_TX_1,                 0x0020	        /*Bit 1 */

        .equ	 USB_EP2R_DTOG_TX,                   0x0040	        /*Data Toggle, for transmission transfers */
        .equ	 USB_EP2R_CTR_TX,                    0x0080	        /*Correct Transfer for transmission */
        .equ	 USB_EP2R_EP_KIND,                   0x0100	        /*Endpoint Kind */

        .equ	 USB_EP2R_EP_TYPE,                   0x0600	        /*EP_TYPE[1:0] bits (Endpoint type) */
        .equ	 USB_EP2R_EP_TYPE_0,                 0x0200	        /*Bit 0 */
        .equ	 USB_EP2R_EP_TYPE_1,                 0x0400	        /*Bit 1 */

        .equ	 USB_EP2R_SETUP,                     0x0800	        /*Setup transaction completed */

        .equ	 USB_EP2R_STAT_RX,                   0x3000	        /*STAT_RX[1:0] bits (Status bits, for reception transfers) */
        .equ	 USB_EP2R_STAT_RX_0,                 0x1000	        /*Bit 0 */
        .equ	 USB_EP2R_STAT_RX_1,                 0x2000	        /*Bit 1 */

        .equ	 USB_EP2R_DTOG_RX,                   0x4000	        /*Data Toggle, for reception transfers */
        .equ	 USB_EP2R_CTR_RX,                    0x8000	        /*Correct Transfer for reception */

/*******************  Bit definition for USB_EP3R register  *******************/
        .equ	 USB_EP3R_EA,                        0x000F	        /*Endpoint Address */

        .equ	 USB_EP3R_STAT_TX,                   0x0030	        /*STAT_TX[1:0] bits (Status bits, for transmission transfers) */
        .equ	 USB_EP3R_STAT_TX_0,                 0x0010	        /*Bit 0 */
        .equ	 USB_EP3R_STAT_TX_1,                 0x0020	        /*Bit 1 */

        .equ	 USB_EP3R_DTOG_TX,                   0x0040	        /*Data Toggle, for transmission transfers */
        .equ	 USB_EP3R_CTR_TX,                    0x0080	        /*Correct Transfer for transmission */
        .equ	 USB_EP3R_EP_KIND,                   0x0100	        /*Endpoint Kind */

        .equ	 USB_EP3R_EP_TYPE,                   0x0600	        /*EP_TYPE[1:0] bits (Endpoint type) */
        .equ	 USB_EP3R_EP_TYPE_0,                 0x0200	        /*Bit 0 */
        .equ	 USB_EP3R_EP_TYPE_1,                 0x0400	        /*Bit 1 */

        .equ	 USB_EP3R_SETUP,                     0x0800	        /*Setup transaction completed */

        .equ	 USB_EP3R_STAT_RX,                   0x3000	        /*STAT_RX[1:0] bits (Status bits, for reception transfers) */
        .equ	 USB_EP3R_STAT_RX_0,                 0x1000	        /*Bit 0 */
        .equ	 USB_EP3R_STAT_RX_1,                 0x2000	        /*Bit 1 */

        .equ	 USB_EP3R_DTOG_RX,                   0x4000	        /*Data Toggle, for reception transfers */
        .equ	 USB_EP3R_CTR_RX,                    0x8000	        /*Correct Transfer for reception */

/*******************  Bit definition for USB_EP4R register  *******************/
        .equ	 USB_EP4R_EA,                        0x000F	        /*Endpoint Address */

        .equ	 USB_EP4R_STAT_TX,                   0x0030	        /*STAT_TX[1:0] bits (Status bits, for transmission transfers) */
        .equ	 USB_EP4R_STAT_TX_0,                 0x0010	        /*Bit 0 */
        .equ	 USB_EP4R_STAT_TX_1,                 0x0020	        /*Bit 1 */

        .equ	 USB_EP4R_DTOG_TX,                   0x0040	        /*Data Toggle, for transmission transfers */
        .equ	 USB_EP4R_CTR_TX,                    0x0080	        /*Correct Transfer for transmission */
        .equ	 USB_EP4R_EP_KIND,                   0x0100	        /*Endpoint Kind */

        .equ	 USB_EP4R_EP_TYPE,                   0x0600	        /*EP_TYPE[1:0] bits (Endpoint type) */
        .equ	 USB_EP4R_EP_TYPE_0,                 0x0200	        /*Bit 0 */
        .equ	 USB_EP4R_EP_TYPE_1,                 0x0400	        /*Bit 1 */

        .equ	 USB_EP4R_SETUP,                     0x0800	        /*Setup transaction completed */

        .equ	 USB_EP4R_STAT_RX,                   0x3000	        /*STAT_RX[1:0] bits (Status bits, for reception transfers) */
        .equ	 USB_EP4R_STAT_RX_0,                 0x1000	        /*Bit 0 */
        .equ	 USB_EP4R_STAT_RX_1,                 0x2000	        /*Bit 1 */

        .equ	 USB_EP4R_DTOG_RX,                   0x4000	        /*Data Toggle, for reception transfers */
        .equ	 USB_EP4R_CTR_RX,                    0x8000	        /*Correct Transfer for reception */

/*******************  Bit definition for USB_EP5R register  *******************/
        .equ	 USB_EP5R_EA,                        0x000F	        /*Endpoint Address */

        .equ	 USB_EP5R_STAT_TX,                   0x0030	        /*STAT_TX[1:0] bits (Status bits, for transmission transfers) */
        .equ	 USB_EP5R_STAT_TX_0,                 0x0010	        /*Bit 0 */
        .equ	 USB_EP5R_STAT_TX_1,                 0x0020	        /*Bit 1 */

        .equ	 USB_EP5R_DTOG_TX,                   0x0040	        /*Data Toggle, for transmission transfers */
        .equ	 USB_EP5R_CTR_TX,                    0x0080	        /*Correct Transfer for transmission */
        .equ	 USB_EP5R_EP_KIND,                   0x0100	        /*Endpoint Kind */

        .equ	 USB_EP5R_EP_TYPE,                   0x0600	        /*EP_TYPE[1:0] bits (Endpoint type) */
        .equ	 USB_EP5R_EP_TYPE_0,                 0x0200	        /*Bit 0 */
        .equ	 USB_EP5R_EP_TYPE_1,                 0x0400	        /*Bit 1 */

        .equ	 USB_EP5R_SETUP,                     0x0800	        /*Setup transaction completed */

        .equ	 USB_EP5R_STAT_RX,                   0x3000	        /*STAT_RX[1:0] bits (Status bits, for reception transfers) */
        .equ	 USB_EP5R_STAT_RX_0,                 0x1000	        /*Bit 0 */
        .equ	 USB_EP5R_STAT_RX_1,                 0x2000	        /*Bit 1 */

        .equ	 USB_EP5R_DTOG_RX,                   0x4000	        /*Data Toggle, for reception transfers */
        .equ	 USB_EP5R_CTR_RX,                    0x8000	        /*Correct Transfer for reception */

/*******************  Bit definition for USB_EP6R register  *******************/
        .equ	 USB_EP6R_EA,                        0x000F	        /*Endpoint Address */

        .equ	 USB_EP6R_STAT_TX,                   0x0030	        /*STAT_TX[1:0] bits (Status bits, for transmission transfers) */
        .equ	 USB_EP6R_STAT_TX_0,                 0x0010	        /*Bit 0 */
        .equ	 USB_EP6R_STAT_TX_1,                 0x0020	        /*Bit 1 */

        .equ	 USB_EP6R_DTOG_TX,                   0x0040	        /*Data Toggle, for transmission transfers */
        .equ	 USB_EP6R_CTR_TX,                    0x0080	        /*Correct Transfer for transmission */
        .equ	 USB_EP6R_EP_KIND,                   0x0100	        /*Endpoint Kind */

        .equ	 USB_EP6R_EP_TYPE,                   0x0600	        /*EP_TYPE[1:0] bits (Endpoint type) */
        .equ	 USB_EP6R_EP_TYPE_0,                 0x0200	        /*Bit 0 */
        .equ	 USB_EP6R_EP_TYPE_1,                 0x0400	        /*Bit 1 */

        .equ	 USB_EP6R_SETUP,                     0x0800	        /*Setup transaction completed */

        .equ	 USB_EP6R_STAT_RX,                   0x3000	        /*STAT_RX[1:0] bits (Status bits, for reception transfers) */
        .equ	 USB_EP6R_STAT_RX_0,                 0x1000	        /*Bit 0 */
        .equ	 USB_EP6R_STAT_RX_1,                 0x2000	        /*Bit 1 */

        .equ	 USB_EP6R_DTOG_RX,                   0x4000	        /*Data Toggle, for reception transfers */
        .equ	 USB_EP6R_CTR_RX,                    0x8000	        /*Correct Transfer for reception */

/*******************  Bit definition for USB_EP7R register  *******************/
        .equ	 USB_EP7R_EA,                        0x000F	        /*Endpoint Address */

        .equ	 USB_EP7R_STAT_TX,                   0x0030	        /*STAT_TX[1:0] bits (Status bits, for transmission transfers) */
        .equ	 USB_EP7R_STAT_TX_0,                 0x0010	        /*Bit 0 */
        .equ	 USB_EP7R_STAT_TX_1,                 0x0020	        /*Bit 1 */

        .equ	 USB_EP7R_DTOG_TX,                   0x0040	        /*Data Toggle, for transmission transfers */
        .equ	 USB_EP7R_CTR_TX,                    0x0080	        /*Correct Transfer for transmission */
        .equ	 USB_EP7R_EP_KIND,                   0x0100	        /*Endpoint Kind */

        .equ	 USB_EP7R_EP_TYPE,                   0x0600	        /*EP_TYPE[1:0] bits (Endpoint type) */
        .equ	 USB_EP7R_EP_TYPE_0,                 0x0200	        /*Bit 0 */
        .equ	 USB_EP7R_EP_TYPE_1,                 0x0400	        /*Bit 1 */

        .equ	 USB_EP7R_SETUP,                     0x0800	        /*Setup transaction completed */

        .equ	 USB_EP7R_STAT_RX,                   0x3000	        /*STAT_RX[1:0] bits (Status bits, for reception transfers) */
        .equ	 USB_EP7R_STAT_RX_0,                 0x1000	        /*Bit 0 */
        .equ	 USB_EP7R_STAT_RX_1,                 0x2000	        /*Bit 1 */

        .equ	 USB_EP7R_DTOG_RX,                   0x4000	        /*Data Toggle, for reception transfers */
        .equ	 USB_EP7R_CTR_RX,                    0x8000	        /*Correct Transfer for reception */

/*Common registers */
/*******************  Bit definition for USB_CNTR register  *******************/
        .equ	 USB_CNTR_FRES,                      0x0001	        /*Force USB Reset */
        .equ	 USB_CNTR_PDWN,                      0x0002	        /*Power down */
        .equ	 USB_CNTR_LP_MODE,                   0x0004	        /*Low-power mode */
        .equ	 USB_CNTR_FSUSP,                     0x0008	        /*Force suspend */
        .equ	 USB_CNTR_RESUME,                    0x0010	        /*Resume request */
        .equ	 USB_CNTR_ESOFM,                     0x0100	        /*Expected Start Of Frame Interrupt Mask */
        .equ	 USB_CNTR_SOFM,                      0x0200	        /*Start Of Frame Interrupt Mask */
        .equ	 USB_CNTR_RESETM,                    0x0400	        /*RESET Interrupt Mask */
        .equ	 USB_CNTR_SUSPM,                     0x0800	        /*Suspend mode Interrupt Mask */
        .equ	 USB_CNTR_WKUPM,                     0x1000	        /*Wakeup Interrupt Mask */
        .equ	 USB_CNTR_ERRM,                      0x2000	        /*Error Interrupt Mask */
        .equ	 USB_CNTR_PMAOVRM,                   0x4000	        /*Packet Memory Area Over / Underrun Interrupt Mask */
        .equ	 USB_CNTR_CTRM,                      0x8000	        /*Correct Transfer Interrupt Mask */

/*******************  Bit definition for USB_ISTR register  *******************/
        .equ	 USB_ISTR_EP_ID,                     0x000F	        /*Endpoint Identifier */
        .equ	 USB_ISTR_DIR,                       0x0010	        /*Direction of transaction */
        .equ	 USB_ISTR_ESOF,                      0x0100	        /*Expected Start Of Frame */
        .equ	 USB_ISTR_SOF,                       0x0200	        /*Start Of Frame */
        .equ	 USB_ISTR_RESET,                     0x0400	        /*USB RESET request */
        .equ	 USB_ISTR_SUSP,                      0x0800	        /*Suspend mode request */
        .equ	 USB_ISTR_WKUP,                      0x1000	        /*Wake up */
        .equ	 USB_ISTR_ERR,                       0x2000	        /*Error */
        .equ	 USB_ISTR_PMAOVR,                    0x4000	        /*Packet Memory Area Over / Underrun */
        .equ	 USB_ISTR_CTR,                       0x8000	        /*Correct Transfer */

/*******************  Bit definition for USB_FNR register  ********************/
        .equ	 USB_FNR_FN,                         0x07FF	        /*Frame Number */
        .equ	 USB_FNR_LSOF,                       0x1800	        /*Lost SOF */
        .equ	 USB_FNR_LCK,                        0x2000	        /*Locked */
        .equ	 USB_FNR_RXDM,                       0x4000	        /*Receive Data - Line Status */
        .equ	 USB_FNR_RXDP,                       0x8000	        /*Receive Data + Line Status */

/******************  Bit definition for USB_DADDR register  *******************/
        .equ	 USB_DADDR_ADD,                      0x7F	           /*ADD[6:0] bits (Device Address) */
        .equ	 USB_DADDR_ADD0,                     0x01	           /*Bit 0 */
        .equ	 USB_DADDR_ADD1,                     0x02	           /*Bit 1 */
        .equ	 USB_DADDR_ADD2,                     0x04	           /*Bit 2 */
        .equ	 USB_DADDR_ADD3,                     0x08	           /*Bit 3 */
        .equ	 USB_DADDR_ADD4,                     0x10	           /*Bit 4 */
        .equ	 USB_DADDR_ADD5,                     0x20	           /*Bit 5 */
        .equ	 USB_DADDR_ADD6,                     0x40	           /*Bit 6 */

        .equ	 USB_DADDR_EF,                       0x80	           /*Enable Function */

/******************  Bit definition for USB_BTABLE register  ******************/    
        .equ	 USB_BTABLE_BTABLE,                  0xFFF8	        /*Buffer Table */

/* Buffer descriptor table */
/*****************  Bit definition for USB_ADDR0_TX register  *****************/
        .equ	 USB_ADDR0_TX_ADDR0_TX,              0xFFFE	        /* Transmission Buffer Address 0 */

/*****************  Bit definition for USB_ADDR1_TX register  *****************/
        .equ	 USB_ADDR1_TX_ADDR1_TX,              0xFFFE	        /* Transmission Buffer Address 1 */

/*****************  Bit definition for USB_ADDR2_TX register  *****************/
        .equ	 USB_ADDR2_TX_ADDR2_TX,              0xFFFE	        /* Transmission Buffer Address 2 */

/*****************  Bit definition for USB_ADDR3_TX register  *****************/
        .equ	 USB_ADDR3_TX_ADDR3_TX,              0xFFFE	        /* Transmission Buffer Address 3 */

/*****************  Bit definition for USB_ADDR4_TX register  *****************/
        .equ	 USB_ADDR4_TX_ADDR4_TX,              0xFFFE	        /* Transmission Buffer Address 4 */

/*****************  Bit definition for USB_ADDR5_TX register  *****************/
        .equ	 USB_ADDR5_TX_ADDR5_TX,              0xFFFE	        /* Transmission Buffer Address 5 */

/*****************  Bit definition for USB_ADDR6_TX register  *****************/
        .equ	 USB_ADDR6_TX_ADDR6_TX,              0xFFFE	        /* Transmission Buffer Address 6 */

/*****************  Bit definition for USB_ADDR7_TX register  *****************/
        .equ	 USB_ADDR7_TX_ADDR7_TX,              0xFFFE	        /* Transmission Buffer Address 7 */

/*----------------------------------------------------------------------------*/

/*****************  Bit definition for USB_COUNT0_TX register  ****************/
        .equ	 USB_COUNT0_TX_COUNT0_TX,            0x03FF	        /* Transmission Byte Count 0 */

/*****************  Bit definition for USB_COUNT1_TX register  ****************/
        .equ	 USB_COUNT1_TX_COUNT1_TX,            0x03FF	        /* Transmission Byte Count 1 */

/*****************  Bit definition for USB_COUNT2_TX register  ****************/
        .equ	 USB_COUNT2_TX_COUNT2_TX,            0x03FF	        /* Transmission Byte Count 2 */

/*****************  Bit definition for USB_COUNT3_TX register  ****************/
        .equ	 USB_COUNT3_TX_COUNT3_TX,            0x03FF	        /* Transmission Byte Count 3 */

/*****************  Bit definition for USB_COUNT4_TX register  ****************/
        .equ	 USB_COUNT4_TX_COUNT4_TX,            0x03FF	        /* Transmission Byte Count 4 */

/*****************  Bit definition for USB_COUNT5_TX register  ****************/
        .equ	 USB_COUNT5_TX_COUNT5_TX,            0x03FF	        /* Transmission Byte Count 5 */

/*****************  Bit definition for USB_COUNT6_TX register  ****************/
        .equ	 USB_COUNT6_TX_COUNT6_TX,            0x03FF	        /* Transmission Byte Count 6 */

/*****************  Bit definition for USB_COUNT7_TX register  ****************/
        .equ	 USB_COUNT7_TX_COUNT7_TX,            0x03FF	        /* Transmission Byte Count 7 */

/*----------------------------------------------------------------------------*/

/****************  Bit definition for USB_COUNT0_TX_0 register  ***************/
        .equ	 USB_COUNT0_TX_0_COUNT0_TX_0,        0x000003FF	    /* Transmission Byte Count 0 (low) */

/****************  Bit definition for USB_COUNT0_TX_1 register  ***************/
        .equ	 USB_COUNT0_TX_1_COUNT0_TX_1,        0x03FF0000	    /* Transmission Byte Count 0 (high) */

/****************  Bit definition for USB_COUNT1_TX_0 register  ***************/
        .equ	 USB_COUNT1_TX_0_COUNT1_TX_0,         0x000003FF	    /* Transmission Byte Count 1 (low) */

/****************  Bit definition for USB_COUNT1_TX_1 register  ***************/
        .equ	 USB_COUNT1_TX_1_COUNT1_TX_1,         0x03FF0000	    /* Transmission Byte Count 1 (high) */

/****************  Bit definition for USB_COUNT2_TX_0 register  ***************/
        .equ	 USB_COUNT2_TX_0_COUNT2_TX_0,        0x000003FF	    /* Transmission Byte Count 2 (low) */

/****************  Bit definition for USB_COUNT2_TX_1 register  ***************/
        .equ	 USB_COUNT2_TX_1_COUNT2_TX_1,        0x03FF0000	    /* Transmission Byte Count 2 (high) */

/****************  Bit definition for USB_COUNT3_TX_0 register  ***************/
        .equ	 USB_COUNT3_TX_0_COUNT3_TX_0,        0x000003FF	    /* Transmission Byte Count 3 (low) */

/****************  Bit definition for USB_COUNT3_TX_1 register  ***************/
        .equ	 USB_COUNT3_TX_1_COUNT3_TX_1,        0x03FF0000	    /* Transmission Byte Count 3 (high) */

/****************  Bit definition for USB_COUNT4_TX_0 register  ***************/
        .equ	 USB_COUNT4_TX_0_COUNT4_TX_0,        0x000003FF	    /* Transmission Byte Count 4 (low) */

/****************  Bit definition for USB_COUNT4_TX_1 register  ***************/
        .equ	 USB_COUNT4_TX_1_COUNT4_TX_1,        0x03FF0000	    /* Transmission Byte Count 4 (high) */

/****************  Bit definition for USB_COUNT5_TX_0 register  ***************/
        .equ	 USB_COUNT5_TX_0_COUNT5_TX_0,        0x000003FF	    /* Transmission Byte Count 5 (low) */

/****************  Bit definition for USB_COUNT5_TX_1 register  ***************/
        .equ	 USB_COUNT5_TX_1_COUNT5_TX_1,        0x03FF0000	    /* Transmission Byte Count 5 (high) */

/****************  Bit definition for USB_COUNT6_TX_0 register  ***************/
        .equ	 USB_COUNT6_TX_0_COUNT6_TX_0,        0x000003FF	    /* Transmission Byte Count 6 (low) */

/****************  Bit definition for USB_COUNT6_TX_1 register  ***************/
        .equ	 USB_COUNT6_TX_1_COUNT6_TX_1,        0x03FF0000	    /* Transmission Byte Count 6 (high) */

/****************  Bit definition for USB_COUNT7_TX_0 register  ***************/
        .equ	 USB_COUNT7_TX_0_COUNT7_TX_0,        0x000003FF	    /* Transmission Byte Count 7 (low) */

/****************  Bit definition for USB_COUNT7_TX_1 register  ***************/
        .equ	 USB_COUNT7_TX_1_COUNT7_TX_1,        0x03FF0000	    /* Transmission Byte Count 7 (high) */

/*----------------------------------------------------------------------------*/

/*****************  Bit definition for USB_ADDR0_RX register  *****************/
        .equ	 USB_ADDR0_RX_ADDR0_RX,              0xFFFE	        /* Reception Buffer Address 0 */

/*****************  Bit definition for USB_ADDR1_RX register  *****************/
        .equ	 USB_ADDR1_RX_ADDR1_RX,              0xFFFE	        /* Reception Buffer Address 1 */

/*****************  Bit definition for USB_ADDR2_RX register  *****************/
        .equ	 USB_ADDR2_RX_ADDR2_RX,              0xFFFE	        /* Reception Buffer Address 2 */

/*****************  Bit definition for USB_ADDR3_RX register  *****************/
        .equ	 USB_ADDR3_RX_ADDR3_RX,              0xFFFE	        /* Reception Buffer Address 3 */

/*****************  Bit definition for USB_ADDR4_RX register  *****************/
        .equ	 USB_ADDR4_RX_ADDR4_RX,              0xFFFE	        /* Reception Buffer Address 4 */

/*****************  Bit definition for USB_ADDR5_RX register  *****************/
        .equ	 USB_ADDR5_RX_ADDR5_RX,              0xFFFE	        /* Reception Buffer Address 5 */

/*****************  Bit definition for USB_ADDR6_RX register  *****************/
        .equ	 USB_ADDR6_RX_ADDR6_RX,              0xFFFE	        /* Reception Buffer Address 6 */

/*****************  Bit definition for USB_ADDR7_RX register  *****************/
        .equ	 USB_ADDR7_RX_ADDR7_RX,              0xFFFE	        /* Reception Buffer Address 7 */

/*----------------------------------------------------------------------------*/

/*****************  Bit definition for USB_COUNT0_RX register  ****************/
        .equ	 USB_COUNT0_RX_COUNT0_RX,            0x03FF	        /* Reception Byte Count */

        .equ	 USB_COUNT0_RX_NUM_BLOCK,            0x7C00	        /* NUM_BLOCK[4:0] bits (Number of blocks) */
        .equ	 USB_COUNT0_RX_NUM_BLOCK_0,          0x0400	        /* Bit 0 */
        .equ	 USB_COUNT0_RX_NUM_BLOCK_1,          0x0800	        /* Bit 1 */
        .equ	 USB_COUNT0_RX_NUM_BLOCK_2,          0x1000	        /* Bit 2 */
        .equ	 USB_COUNT0_RX_NUM_BLOCK_3,          0x2000	        /* Bit 3 */
        .equ	 USB_COUNT0_RX_NUM_BLOCK_4,          0x4000	        /* Bit 4 */

        .equ	 USB_COUNT0_RX_BLSIZE,               0x8000	        /* BLock SIZE */

/*****************  Bit definition for USB_COUNT1_RX register  ****************/
        .equ	 USB_COUNT1_RX_COUNT1_RX,            0x03FF	        /* Reception Byte Count */

        .equ	 USB_COUNT1_RX_NUM_BLOCK,            0x7C00	        /* NUM_BLOCK[4:0] bits (Number of blocks) */
        .equ	 USB_COUNT1_RX_NUM_BLOCK_0,          0x0400	        /* Bit 0 */
        .equ	 USB_COUNT1_RX_NUM_BLOCK_1,          0x0800	        /* Bit 1 */
        .equ	 USB_COUNT1_RX_NUM_BLOCK_2,          0x1000	        /* Bit 2 */
        .equ	 USB_COUNT1_RX_NUM_BLOCK_3,          0x2000	        /* Bit 3 */
        .equ	 USB_COUNT1_RX_NUM_BLOCK_4,          0x4000	        /* Bit 4 */

        .equ	 USB_COUNT1_RX_BLSIZE,               0x8000	        /* BLock SIZE */

/*****************  Bit definition for USB_COUNT2_RX register  ****************/
        .equ	 USB_COUNT2_RX_COUNT2_RX,            0x03FF	        /* Reception Byte Count */

        .equ	 USB_COUNT2_RX_NUM_BLOCK,            0x7C00	        /* NUM_BLOCK[4:0] bits (Number of blocks) */
        .equ	 USB_COUNT2_RX_NUM_BLOCK_0,          0x0400	        /* Bit 0 */
        .equ	 USB_COUNT2_RX_NUM_BLOCK_1,          0x0800	        /* Bit 1 */
        .equ	 USB_COUNT2_RX_NUM_BLOCK_2,          0x1000	        /* Bit 2 */
        .equ	 USB_COUNT2_RX_NUM_BLOCK_3,          0x2000	        /* Bit 3 */
        .equ	 USB_COUNT2_RX_NUM_BLOCK_4,          0x4000	        /* Bit 4 */

        .equ	 USB_COUNT2_RX_BLSIZE,               0x8000	        /* BLock SIZE */

/*****************  Bit definition for USB_COUNT3_RX register  ****************/
        .equ	 USB_COUNT3_RX_COUNT3_RX,            0x03FF	        /* Reception Byte Count */

        .equ	 USB_COUNT3_RX_NUM_BLOCK,            0x7C00	        /* NUM_BLOCK[4:0] bits (Number of blocks) */
        .equ	 USB_COUNT3_RX_NUM_BLOCK_0,          0x0400	        /* Bit 0 */
        .equ	 USB_COUNT3_RX_NUM_BLOCK_1,          0x0800	        /* Bit 1 */
        .equ	 USB_COUNT3_RX_NUM_BLOCK_2,          0x1000	        /* Bit 2 */
        .equ	 USB_COUNT3_RX_NUM_BLOCK_3,          0x2000	        /* Bit 3 */
        .equ	 USB_COUNT3_RX_NUM_BLOCK_4,          0x4000	        /* Bit 4 */

        .equ	 USB_COUNT3_RX_BLSIZE,               0x8000	        /* BLock SIZE */

/*****************  Bit definition for USB_COUNT4_RX register  ****************/
        .equ	 USB_COUNT4_RX_COUNT4_RX,            0x03FF	        /* Reception Byte Count */

        .equ	 USB_COUNT4_RX_NUM_BLOCK,            0x7C00	        /* NUM_BLOCK[4:0] bits (Number of blocks) */
        .equ	 USB_COUNT4_RX_NUM_BLOCK_0,          0x0400	        /* Bit 0 */
        .equ	 USB_COUNT4_RX_NUM_BLOCK_1,          0x0800	        /* Bit 1 */
        .equ	 USB_COUNT4_RX_NUM_BLOCK_2,          0x1000	        /* Bit 2 */
        .equ	 USB_COUNT4_RX_NUM_BLOCK_3,          0x2000	        /* Bit 3 */
        .equ	 USB_COUNT4_RX_NUM_BLOCK_4,          0x4000	        /* Bit 4 */

        .equ	 USB_COUNT4_RX_BLSIZE,               0x8000	        /* BLock SIZE */

/*****************  Bit definition for USB_COUNT5_RX register  ****************/
        .equ	 USB_COUNT5_RX_COUNT5_RX,            0x03FF	        /* Reception Byte Count */

        .equ	 USB_COUNT5_RX_NUM_BLOCK,            0x7C00	        /* NUM_BLOCK[4:0] bits (Number of blocks) */
        .equ	 USB_COUNT5_RX_NUM_BLOCK_0,          0x0400	        /* Bit 0 */
        .equ	 USB_COUNT5_RX_NUM_BLOCK_1,          0x0800	        /* Bit 1 */
        .equ	 USB_COUNT5_RX_NUM_BLOCK_2,          0x1000	        /* Bit 2 */
        .equ	 USB_COUNT5_RX_NUM_BLOCK_3,          0x2000	        /* Bit 3 */
        .equ	 USB_COUNT5_RX_NUM_BLOCK_4,          0x4000	        /* Bit 4 */

        .equ	 USB_COUNT5_RX_BLSIZE,               0x8000	        /* BLock SIZE */

/*****************  Bit definition for USB_COUNT6_RX register  ****************/
        .equ	 USB_COUNT6_RX_COUNT6_RX,            0x03FF	        /* Reception Byte Count */

        .equ	 USB_COUNT6_RX_NUM_BLOCK,            0x7C00	        /* NUM_BLOCK[4:0] bits (Number of blocks) */
        .equ	 USB_COUNT6_RX_NUM_BLOCK_0,          0x0400	        /* Bit 0 */
        .equ	 USB_COUNT6_RX_NUM_BLOCK_1,          0x0800	        /* Bit 1 */
        .equ	 USB_COUNT6_RX_NUM_BLOCK_2,          0x1000	        /* Bit 2 */
        .equ	 USB_COUNT6_RX_NUM_BLOCK_3,          0x2000	        /* Bit 3 */
        .equ	 USB_COUNT6_RX_NUM_BLOCK_4,          0x4000	        /* Bit 4 */

        .equ	 USB_COUNT6_RX_BLSIZE,               0x8000	        /* BLock SIZE */

/*****************  Bit definition for USB_COUNT7_RX register  ****************/
        .equ	 USB_COUNT7_RX_COUNT7_RX,            0x03FF	        /* Reception Byte Count */

        .equ	 USB_COUNT7_RX_NUM_BLOCK,            0x7C00	        /* NUM_BLOCK[4:0] bits (Number of blocks) */
        .equ	 USB_COUNT7_RX_NUM_BLOCK_0,          0x0400	        /* Bit 0 */
        .equ	 USB_COUNT7_RX_NUM_BLOCK_1,          0x0800	        /* Bit 1 */
        .equ	 USB_COUNT7_RX_NUM_BLOCK_2,          0x1000	        /* Bit 2 */
        .equ	 USB_COUNT7_RX_NUM_BLOCK_3,          0x2000	        /* Bit 3 */
        .equ	 USB_COUNT7_RX_NUM_BLOCK_4,          0x4000	        /* Bit 4 */

        .equ	 USB_COUNT7_RX_BLSIZE,               0x8000	        /* BLock SIZE */

/*----------------------------------------------------------------------------*/

/****************  Bit definition for USB_COUNT0_RX_0 register  ***************/
        .equ	 USB_COUNT0_RX_0_COUNT0_RX_0,        0x000003FF	    /* Reception Byte Count (low) */

        .equ	 USB_COUNT0_RX_0_NUM_BLOCK_0,        0x00007C00	    /* NUM_BLOCK_0[4:0] bits (Number of blocks) (low) */
        .equ	 USB_COUNT0_RX_0_NUM_BLOCK_0_0,      0x00000400	    /* Bit 0 */
        .equ	 USB_COUNT0_RX_0_NUM_BLOCK_0_1,      0x00000800	    /* Bit 1 */
        .equ	 USB_COUNT0_RX_0_NUM_BLOCK_0_2,      0x00001000	    /* Bit 2 */
        .equ	 USB_COUNT0_RX_0_NUM_BLOCK_0_3,      0x00002000	    /* Bit 3 */
        .equ	 USB_COUNT0_RX_0_NUM_BLOCK_0_4,      0x00004000	    /* Bit 4 */

        .equ	 USB_COUNT0_RX_0_BLSIZE_0,           0x00008000	    /* BLock SIZE (low) */

/****************  Bit definition for USB_COUNT0_RX_1 register  ***************/
        .equ	 USB_COUNT0_RX_1_COUNT0_RX_1,        0x03FF0000	    /* Reception Byte Count (high) */

        .equ	 USB_COUNT0_RX_1_NUM_BLOCK_1,        0x7C000000	    /* NUM_BLOCK_1[4:0] bits (Number of blocks) (high) */
        .equ	 USB_COUNT0_RX_1_NUM_BLOCK_1_0,      0x04000000	    /* Bit 1 */
        .equ	 USB_COUNT0_RX_1_NUM_BLOCK_1_1,      0x08000000	    /* Bit 1 */
        .equ	 USB_COUNT0_RX_1_NUM_BLOCK_1_2,      0x10000000	    /* Bit 2 */
        .equ	 USB_COUNT0_RX_1_NUM_BLOCK_1_3,      0x20000000	    /* Bit 3 */
        .equ	 USB_COUNT0_RX_1_NUM_BLOCK_1_4,      0x40000000	    /* Bit 4 */

        .equ	 USB_COUNT0_RX_1_BLSIZE_1,           0x80000000	    /* BLock SIZE (high) */

/****************  Bit definition for USB_COUNT1_RX_0 register  ***************/
        .equ	 USB_COUNT1_RX_0_COUNT1_RX_0,        0x000003FF	    /* Reception Byte Count (low) */

        .equ	 USB_COUNT1_RX_0_NUM_BLOCK_0,        0x00007C00	    /* NUM_BLOCK_0[4:0] bits (Number of blocks) (low) */
        .equ	 USB_COUNT1_RX_0_NUM_BLOCK_0_0,      0x00000400	    /* Bit 0 */
        .equ	 USB_COUNT1_RX_0_NUM_BLOCK_0_1,      0x00000800	    /* Bit 1 */
        .equ	 USB_COUNT1_RX_0_NUM_BLOCK_0_2,      0x00001000	    /* Bit 2 */
        .equ	 USB_COUNT1_RX_0_NUM_BLOCK_0_3,      0x00002000	    /* Bit 3 */
        .equ	 USB_COUNT1_RX_0_NUM_BLOCK_0_4,      0x00004000	    /* Bit 4 */

        .equ	 USB_COUNT1_RX_0_BLSIZE_0,           0x00008000	    /* BLock SIZE (low) */

/****************  Bit definition for USB_COUNT1_RX_1 register  ***************/
        .equ	 USB_COUNT1_RX_1_COUNT1_RX_1,        0x03FF0000	    /* Reception Byte Count (high) */

        .equ	 USB_COUNT1_RX_1_NUM_BLOCK_1,        0x7C000000	    /* NUM_BLOCK_1[4:0] bits (Number of blocks) (high) */
        .equ	 USB_COUNT1_RX_1_NUM_BLOCK_1_0,      0x04000000	    /* Bit 0 */
        .equ	 USB_COUNT1_RX_1_NUM_BLOCK_1_1,      0x08000000	    /* Bit 1 */
        .equ	 USB_COUNT1_RX_1_NUM_BLOCK_1_2,      0x10000000	    /* Bit 2 */
        .equ	 USB_COUNT1_RX_1_NUM_BLOCK_1_3,      0x20000000	    /* Bit 3 */
        .equ	 USB_COUNT1_RX_1_NUM_BLOCK_1_4,      0x40000000	    /* Bit 4 */

        .equ	 USB_COUNT1_RX_1_BLSIZE_1,           0x80000000	    /* BLock SIZE (high) */

/****************  Bit definition for USB_COUNT2_RX_0 register  ***************/
        .equ	 USB_COUNT2_RX_0_COUNT2_RX_0,        0x000003FF	    /* Reception Byte Count (low) */

        .equ	 USB_COUNT2_RX_0_NUM_BLOCK_0,        0x00007C00	    /* NUM_BLOCK_0[4:0] bits (Number of blocks) (low) */
        .equ	 USB_COUNT2_RX_0_NUM_BLOCK_0_0,      0x00000400	    /* Bit 0 */
        .equ	 USB_COUNT2_RX_0_NUM_BLOCK_0_1,      0x00000800	    /* Bit 1 */
        .equ	 USB_COUNT2_RX_0_NUM_BLOCK_0_2,      0x00001000	    /* Bit 2 */
        .equ	 USB_COUNT2_RX_0_NUM_BLOCK_0_3,      0x00002000	    /* Bit 3 */
        .equ	 USB_COUNT2_RX_0_NUM_BLOCK_0_4,      0x00004000	    /* Bit 4 */

        .equ	 USB_COUNT2_RX_0_BLSIZE_0,           0x00008000	    /* BLock SIZE (low) */

/****************  Bit definition for USB_COUNT2_RX_1 register  ***************/
        .equ	 USB_COUNT2_RX_1_COUNT2_RX_1,        0x03FF0000	    /* Reception Byte Count (high) */

        .equ	 USB_COUNT2_RX_1_NUM_BLOCK_1,        0x7C000000	    /* NUM_BLOCK_1[4:0] bits (Number of blocks) (high) */
        .equ	 USB_COUNT2_RX_1_NUM_BLOCK_1_0,      0x04000000	    /* Bit 0 */
        .equ	 USB_COUNT2_RX_1_NUM_BLOCK_1_1,      0x08000000	    /* Bit 1 */
        .equ	 USB_COUNT2_RX_1_NUM_BLOCK_1_2,      0x10000000	    /* Bit 2 */
        .equ	 USB_COUNT2_RX_1_NUM_BLOCK_1_3,      0x20000000	    /* Bit 3 */
        .equ	 USB_COUNT2_RX_1_NUM_BLOCK_1_4,      0x40000000	    /* Bit 4 */

        .equ	 USB_COUNT2_RX_1_BLSIZE_1,           0x80000000	    /* BLock SIZE (high) */

/****************  Bit definition for USB_COUNT3_RX_0 register  ***************/
        .equ	 USB_COUNT3_RX_0_COUNT3_RX_0,        0x000003FF	    /* Reception Byte Count (low) */

        .equ	 USB_COUNT3_RX_0_NUM_BLOCK_0,        0x00007C00	    /* NUM_BLOCK_0[4:0] bits (Number of blocks) (low) */
        .equ	 USB_COUNT3_RX_0_NUM_BLOCK_0_0,      0x00000400	    /* Bit 0 */
        .equ	 USB_COUNT3_RX_0_NUM_BLOCK_0_1,      0x00000800	    /* Bit 1 */
        .equ	 USB_COUNT3_RX_0_NUM_BLOCK_0_2,      0x00001000	    /* Bit 2 */
        .equ	 USB_COUNT3_RX_0_NUM_BLOCK_0_3,      0x00002000	    /* Bit 3 */
        .equ	 USB_COUNT3_RX_0_NUM_BLOCK_0_4,      0x00004000	    /* Bit 4 */

        .equ	 USB_COUNT3_RX_0_BLSIZE_0,           0x00008000	    /* BLock SIZE (low) */

/****************  Bit definition for USB_COUNT3_RX_1 register  ***************/
        .equ	 USB_COUNT3_RX_1_COUNT3_RX_1,        0x03FF0000	    /* Reception Byte Count (high) */

        .equ	 USB_COUNT3_RX_1_NUM_BLOCK_1,        0x7C000000	    /* NUM_BLOCK_1[4:0] bits (Number of blocks) (high) */
        .equ	 USB_COUNT3_RX_1_NUM_BLOCK_1_0,      0x04000000	    /* Bit 0 */
        .equ	 USB_COUNT3_RX_1_NUM_BLOCK_1_1,      0x08000000	    /* Bit 1 */
        .equ	 USB_COUNT3_RX_1_NUM_BLOCK_1_2,      0x10000000	    /* Bit 2 */
        .equ	 USB_COUNT3_RX_1_NUM_BLOCK_1_3,      0x20000000	    /* Bit 3 */
        .equ	 USB_COUNT3_RX_1_NUM_BLOCK_1_4,      0x40000000	    /* Bit 4 */

        .equ	 USB_COUNT3_RX_1_BLSIZE_1,           0x80000000	    /* BLock SIZE (high) */

/****************  Bit definition for USB_COUNT4_RX_0 register  ***************/
        .equ	 USB_COUNT4_RX_0_COUNT4_RX_0,        0x000003FF	    /* Reception Byte Count (low) */

        .equ	 USB_COUNT4_RX_0_NUM_BLOCK_0,        0x00007C00	    /* NUM_BLOCK_0[4:0] bits (Number of blocks) (low) */
        .equ	 USB_COUNT4_RX_0_NUM_BLOCK_0_0,      0x00000400	    /* Bit 0 */
        .equ	 USB_COUNT4_RX_0_NUM_BLOCK_0_1,      0x00000800	    /* Bit 1 */
        .equ	 USB_COUNT4_RX_0_NUM_BLOCK_0_2,      0x00001000	    /* Bit 2 */
        .equ	 USB_COUNT4_RX_0_NUM_BLOCK_0_3,      0x00002000	    /* Bit 3 */
        .equ	 USB_COUNT4_RX_0_NUM_BLOCK_0_4,      0x00004000	    /* Bit 4 */

        .equ	 USB_COUNT4_RX_0_BLSIZE_0,           0x00008000	    /* BLock SIZE (low) */

/****************  Bit definition for USB_COUNT4_RX_1 register  ***************/
        .equ	 USB_COUNT4_RX_1_COUNT4_RX_1,        0x03FF0000	    /* Reception Byte Count (high) */

        .equ	 USB_COUNT4_RX_1_NUM_BLOCK_1,        0x7C000000	    /* NUM_BLOCK_1[4:0] bits (Number of blocks) (high) */
        .equ	 USB_COUNT4_RX_1_NUM_BLOCK_1_0,      0x04000000	    /* Bit 0 */
        .equ	 USB_COUNT4_RX_1_NUM_BLOCK_1_1,      0x08000000	    /* Bit 1 */
        .equ	 USB_COUNT4_RX_1_NUM_BLOCK_1_2,      0x10000000	    /* Bit 2 */
        .equ	 USB_COUNT4_RX_1_NUM_BLOCK_1_3,      0x20000000	    /* Bit 3 */
        .equ	 USB_COUNT4_RX_1_NUM_BLOCK_1_4,      0x40000000	    /* Bit 4 */

        .equ	 USB_COUNT4_RX_1_BLSIZE_1,           0x80000000	    /* BLock SIZE (high) */

/****************  Bit definition for USB_COUNT5_RX_0 register  ***************/
        .equ	 USB_COUNT5_RX_0_COUNT5_RX_0,        0x000003FF	    /* Reception Byte Count (low) */

        .equ	 USB_COUNT5_RX_0_NUM_BLOCK_0,        0x00007C00	    /* NUM_BLOCK_0[4:0] bits (Number of blocks) (low) */
        .equ	 USB_COUNT5_RX_0_NUM_BLOCK_0_0,      0x00000400	    /* Bit 0 */
        .equ	 USB_COUNT5_RX_0_NUM_BLOCK_0_1,      0x00000800	    /* Bit 1 */
        .equ	 USB_COUNT5_RX_0_NUM_BLOCK_0_2,      0x00001000	    /* Bit 2 */
        .equ	 USB_COUNT5_RX_0_NUM_BLOCK_0_3,      0x00002000	    /* Bit 3 */
        .equ	 USB_COUNT5_RX_0_NUM_BLOCK_0_4,      0x00004000	    /* Bit 4 */

        .equ	 USB_COUNT5_RX_0_BLSIZE_0,           0x00008000	    /* BLock SIZE (low) */

/****************  Bit definition for USB_COUNT5_RX_1 register  ***************/
        .equ	 USB_COUNT5_RX_1_COUNT5_RX_1,        0x03FF0000	    /* Reception Byte Count (high) */

        .equ	 USB_COUNT5_RX_1_NUM_BLOCK_1,        0x7C000000	    /* NUM_BLOCK_1[4:0] bits (Number of blocks) (high) */
        .equ	 USB_COUNT5_RX_1_NUM_BLOCK_1_0,      0x04000000	    /* Bit 0 */
        .equ	 USB_COUNT5_RX_1_NUM_BLOCK_1_1,      0x08000000	    /* Bit 1 */
        .equ	 USB_COUNT5_RX_1_NUM_BLOCK_1_2,      0x10000000	    /* Bit 2 */
        .equ	 USB_COUNT5_RX_1_NUM_BLOCK_1_3,      0x20000000	    /* Bit 3 */
        .equ	 USB_COUNT5_RX_1_NUM_BLOCK_1_4,      0x40000000	    /* Bit 4 */

        .equ	 USB_COUNT5_RX_1_BLSIZE_1,           0x80000000	    /* BLock SIZE (high) */

/***************  Bit definition for USB_COUNT6_RX_0  register  ***************/
        .equ	 USB_COUNT6_RX_0_COUNT6_RX_0,        0x000003FF	    /* Reception Byte Count (low) */

        .equ	 USB_COUNT6_RX_0_NUM_BLOCK_0,        0x00007C00	    /* NUM_BLOCK_0[4:0] bits (Number of blocks) (low) */
        .equ	 USB_COUNT6_RX_0_NUM_BLOCK_0_0,      0x00000400	    /* Bit 0 */
        .equ	 USB_COUNT6_RX_0_NUM_BLOCK_0_1,      0x00000800	    /* Bit 1 */
        .equ	 USB_COUNT6_RX_0_NUM_BLOCK_0_2,      0x00001000	    /* Bit 2 */
        .equ	 USB_COUNT6_RX_0_NUM_BLOCK_0_3,      0x00002000	    /* Bit 3 */
        .equ	 USB_COUNT6_RX_0_NUM_BLOCK_0_4,      0x00004000	    /* Bit 4 */

        .equ	 USB_COUNT6_RX_0_BLSIZE_0,           0x00008000	    /* BLock SIZE (low) */

/****************  Bit definition for USB_COUNT6_RX_1 register  ***************/
        .equ	 USB_COUNT6_RX_1_COUNT6_RX_1,        0x03FF0000	    /* Reception Byte Count (high) */

        .equ	 USB_COUNT6_RX_1_NUM_BLOCK_1,        0x7C000000	    /* NUM_BLOCK_1[4:0] bits (Number of blocks) (high) */
        .equ	 USB_COUNT6_RX_1_NUM_BLOCK_1_0,      0x04000000	    /* Bit 0 */
        .equ	 USB_COUNT6_RX_1_NUM_BLOCK_1_1,      0x08000000	    /* Bit 1 */
        .equ	 USB_COUNT6_RX_1_NUM_BLOCK_1_2,      0x10000000	    /* Bit 2 */
        .equ	 USB_COUNT6_RX_1_NUM_BLOCK_1_3,      0x20000000	    /* Bit 3 */
        .equ	 USB_COUNT6_RX_1_NUM_BLOCK_1_4,      0x40000000	    /* Bit 4 */

        .equ	 USB_COUNT6_RX_1_BLSIZE_1,           0x80000000	    /* BLock SIZE (high) */

/***************  Bit definition for USB_COUNT7_RX_0 register  ****************/
        .equ	 USB_COUNT7_RX_0_COUNT7_RX_0,        0x000003FF	    /* Reception Byte Count (low) */

        .equ	 USB_COUNT7_RX_0_NUM_BLOCK_0,        0x00007C00	    /* NUM_BLOCK_0[4:0] bits (Number of blocks) (low) */
        .equ	 USB_COUNT7_RX_0_NUM_BLOCK_0_0,      0x00000400	    /* Bit 0 */
        .equ	 USB_COUNT7_RX_0_NUM_BLOCK_0_1,      0x00000800	    /* Bit 1 */
        .equ	 USB_COUNT7_RX_0_NUM_BLOCK_0_2,      0x00001000	    /* Bit 2 */
        .equ	 USB_COUNT7_RX_0_NUM_BLOCK_0_3,      0x00002000	    /* Bit 3 */
        .equ	 USB_COUNT7_RX_0_NUM_BLOCK_0_4,      0x00004000	    /* Bit 4 */

        .equ	 USB_COUNT7_RX_0_BLSIZE_0,           0x00008000	    /* BLock SIZE (low) */

/***************  Bit definition for USB_COUNT7_RX_1 register  ****************/
        .equ	 USB_COUNT7_RX_1_COUNT7_RX_1,        0x03FF0000	    /* Reception Byte Count (high) */

        .equ	 USB_COUNT7_RX_1_NUM_BLOCK_1,        0x7C000000	    /* NUM_BLOCK_1[4:0] bits (Number of blocks) (high) */
        .equ	 USB_COUNT7_RX_1_NUM_BLOCK_1_0,      0x04000000	    /* Bit 0 */
        .equ	 USB_COUNT7_RX_1_NUM_BLOCK_1_1,      0x08000000	    /* Bit 1 */
        .equ	 USB_COUNT7_RX_1_NUM_BLOCK_1_2,      0x10000000	    /* Bit 2 */
        .equ	 USB_COUNT7_RX_1_NUM_BLOCK_1_3,      0x20000000	    /* Bit 3 */
        .equ	 USB_COUNT7_RX_1_NUM_BLOCK_1_4,      0x40000000	    /* Bit 4 */

        .equ	 USB_COUNT7_RX_1_BLSIZE_1,           0x80000000	    /* BLock SIZE (high) */

/******************************************************************************/
/*                                                                            */
/*                         Window WATCHDOG (WWDG)                             */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for WWDG_CR register  ********************/
        .equ	 WWDG_CR_T,                          0x7F	           /* T[6:0] bits (7-Bit counter (MSB to LSB)) */
        .equ	 WWDG_CR_T0,                         0x01	           /* Bit 0 */
        .equ	 WWDG_CR_T1,                         0x02	           /* Bit 1 */
        .equ	 WWDG_CR_T2,                         0x04	           /* Bit 2 */
        .equ	 WWDG_CR_T3,                         0x08	           /* Bit 3 */
        .equ	 WWDG_CR_T4,                         0x10	           /* Bit 4 */
        .equ	 WWDG_CR_T5,                         0x20	           /* Bit 5 */
        .equ	 WWDG_CR_T6,                         0x40	           /* Bit 6 */

        .equ	 WWDG_CR_WDGA,                       0x80	           /* Activation bit */

/*******************  Bit definition for WWDG_CFR register  *******************/
        .equ	 WWDG_CFR_W,                         0x007F	        /* W[6:0] bits (7-bit window value) */
        .equ	 WWDG_CFR_W0,                        0x0001	        /* Bit 0 */
        .equ	 WWDG_CFR_W1,                        0x0002	        /* Bit 1 */
        .equ	 WWDG_CFR_W2,                        0x0004	        /* Bit 2 */
        .equ	 WWDG_CFR_W3,                        0x0008	        /* Bit 3 */
        .equ	 WWDG_CFR_W4,                        0x0010	        /* Bit 4 */
        .equ	 WWDG_CFR_W5,                        0x0020	        /* Bit 5 */
        .equ	 WWDG_CFR_W6,                        0x0040	        /* Bit 6 */

        .equ	 WWDG_CFR_WDGTB,                     0x0180	        /* WDGTB[1:0] bits (Timer Base) */
        .equ	 WWDG_CFR_WDGTB0,                    0x0080	        /* Bit 0 */
        .equ	 WWDG_CFR_WDGTB1,                    0x0100	        /* Bit 1 */

        .equ	 WWDG_CFR_EWI,                       0x0200	        /* Early Wakeup Interrupt */

/*******************  Bit definition for WWDG_SR register  ********************/
        .equ	 WWDG_SR_EWIF,                       0x01	        /* Early Wakeup Interrupt Flag */

/******************************************************************************/
/*                                                                            */
/*                        SystemTick (SysTick)                                */
/*                                                                            */
/******************************************************************************/

/*****************  Bit definition for SysTick_CTRL register  *****************/
        .equ	 SysTick_CTRL_ENABLE,                0x00000001	    /* Counter enable */
        .equ	 SysTick_CTRL_TICKINT,               0x00000002	    /* Counting down to 0 pends the SysTick handler */
        .equ	 SysTick_CTRL_CLKSOURCE,             0x00000004	    /* Clock source */
        .equ	 SysTick_CTRL_COUNTFLAG,             0x00010000	    /* Count Flag */

/*****************  Bit definition for SysTick_LOAD register  *****************/
        .equ	 SysTick_LOAD_RELOAD,                0x00FFFFFF	    /* Value to load into the SysTick Current Value Register when the counter reaches 0 */

/*****************  Bit definition for SysTick_VAL register  ******************/
        .equ	 SysTick_VAL_CURRENT,                0x00FFFFFF	    /* Current value at the time the register is accessed */

/*****************  Bit definition for SysTick_CALIB register  ****************/
        .equ	 SysTick_CALIB_TENMS,                0x00FFFFFF	    /* Reload value to use for 10ms timing */
        .equ	 SysTick_CALIB_SKEW,                 0x40000000	    /* Calibration value is not exactly 10 ms */
        .equ	 SysTick_CALIB_NOREF,                0x80000000	    /* The reference clock is not provided */

/******************************************************************************/
/*                                                                            */
/*               Nested Vectored Interrupt Controller (NVIC)                  */
/*                                                                            */
/******************************************************************************/

/******************  Bit definition for NVIC_ISER register  *******************/
        .equ	 NVIC_ISER_SETENA,                   0xFFFFFFFF	    /* Interrupt set enable bits */
        .equ	 NVIC_ISER_SETENA_0,                 0x00000001	    /* bit 0 */
        .equ	 NVIC_ISER_SETENA_1,                 0x00000002	    /* bit 1 */
        .equ	 NVIC_ISER_SETENA_2,                 0x00000004	    /* bit 2 */
        .equ	 NVIC_ISER_SETENA_3,                 0x00000008	    /* bit 3 */
        .equ	 NVIC_ISER_SETENA_4,                 0x00000010	    /* bit 4 */
        .equ	 NVIC_ISER_SETENA_5,                 0x00000020	    /* bit 5 */
        .equ	 NVIC_ISER_SETENA_6,                 0x00000040	    /* bit 6 */
        .equ	 NVIC_ISER_SETENA_7,                 0x00000080	    /* bit 7 */
        .equ	 NVIC_ISER_SETENA_8,                 0x00000100	    /* bit 8 */
        .equ	 NVIC_ISER_SETENA_9,                 0x00000200	    /* bit 9 */
        .equ	 NVIC_ISER_SETENA_10,                0x00000400	    /* bit 10 */
        .equ	 NVIC_ISER_SETENA_11,                0x00000800	    /* bit 11 */
        .equ	 NVIC_ISER_SETENA_12,                0x00001000	    /* bit 12 */
        .equ	 NVIC_ISER_SETENA_13,                0x00002000	    /* bit 13 */
        .equ	 NVIC_ISER_SETENA_14,                0x00004000	    /* bit 14 */
        .equ	 NVIC_ISER_SETENA_15,                0x00008000	    /* bit 15 */
        .equ	 NVIC_ISER_SETENA_16,                0x00010000	    /* bit 16 */
        .equ	 NVIC_ISER_SETENA_17,                0x00020000	    /* bit 17 */
        .equ	 NVIC_ISER_SETENA_18,                0x00040000	    /* bit 18 */
        .equ	 NVIC_ISER_SETENA_19,                0x00080000	    /* bit 19 */
        .equ	 NVIC_ISER_SETENA_20,                0x00100000	    /* bit 20 */
        .equ	 NVIC_ISER_SETENA_21,                0x00200000	    /* bit 21 */
        .equ	 NVIC_ISER_SETENA_22,                0x00400000	    /* bit 22 */
        .equ	 NVIC_ISER_SETENA_23,                0x00800000	    /* bit 23 */
        .equ	 NVIC_ISER_SETENA_24,                0x01000000	    /* bit 24 */
        .equ	 NVIC_ISER_SETENA_25,                0x02000000	    /* bit 25 */
        .equ	 NVIC_ISER_SETENA_26,                0x04000000	    /* bit 26 */
        .equ	 NVIC_ISER_SETENA_27,                0x08000000	    /* bit 27 */
        .equ	 NVIC_ISER_SETENA_28,                0x10000000	    /* bit 28 */
        .equ	 NVIC_ISER_SETENA_29,                0x20000000	    /* bit 29 */
        .equ	 NVIC_ISER_SETENA_30,                0x40000000	    /* bit 30 */
        .equ	 NVIC_ISER_SETENA_31,                0x80000000	    /* bit 31 */

/******************  Bit definition for NVIC_ICER register  *******************/
        .equ	 NVIC_ICER_CLRENA,                  0xFFFFFFFF	    /* Interrupt clear-enable bits */
        .equ	 NVIC_ICER_CLRENA_0,                 0x00000001	    /* bit 0 */
        .equ	 NVIC_ICER_CLRENA_1,                 0x00000002	    /* bit 1 */
        .equ	 NVIC_ICER_CLRENA_2,                 0x00000004	    /* bit 2 */
        .equ	 NVIC_ICER_CLRENA_3,                 0x00000008	    /* bit 3 */
        .equ	 NVIC_ICER_CLRENA_4,                 0x00000010	    /* bit 4 */
        .equ	 NVIC_ICER_CLRENA_5,                 0x00000020	    /* bit 5 */
        .equ	 NVIC_ICER_CLRENA_6,                 0x00000040	    /* bit 6 */
        .equ	 NVIC_ICER_CLRENA_7,                 0x00000080	    /* bit 7 */
        .equ	 NVIC_ICER_CLRENA_8,                 0x00000100	    /* bit 8 */
        .equ	 NVIC_ICER_CLRENA_9,                 0x00000200	    /* bit 9 */
        .equ	 NVIC_ICER_CLRENA_10,                0x00000400	    /* bit 10 */
        .equ	 NVIC_ICER_CLRENA_11,                0x00000800	    /* bit 11 */
        .equ	 NVIC_ICER_CLRENA_12,                0x00001000	    /* bit 12 */
        .equ	 NVIC_ICER_CLRENA_13,                0x00002000	    /* bit 13 */
        .equ	 NVIC_ICER_CLRENA_14,                0x00004000	    /* bit 14 */
        .equ	 NVIC_ICER_CLRENA_15,                0x00008000	    /* bit 15 */
        .equ	 NVIC_ICER_CLRENA_16,                0x00010000	    /* bit 16 */
        .equ	 NVIC_ICER_CLRENA_17,                0x00020000	    /* bit 17 */
        .equ	 NVIC_ICER_CLRENA_18,                0x00040000	    /* bit 18 */
        .equ	 NVIC_ICER_CLRENA_19,                0x00080000	    /* bit 19 */
        .equ	 NVIC_ICER_CLRENA_20,                0x00100000	    /* bit 20 */
        .equ	 NVIC_ICER_CLRENA_21,                0x00200000	    /* bit 21 */
        .equ	 NVIC_ICER_CLRENA_22,                0x00400000	    /* bit 22 */
        .equ	 NVIC_ICER_CLRENA_23,                0x00800000	    /* bit 23 */
        .equ	 NVIC_ICER_CLRENA_24,                0x01000000	    /* bit 24 */
        .equ	 NVIC_ICER_CLRENA_25,                0x02000000	    /* bit 25 */
        .equ	 NVIC_ICER_CLRENA_26,                0x04000000	    /* bit 26 */
        .equ	 NVIC_ICER_CLRENA_27,                0x08000000	    /* bit 27 */
        .equ	 NVIC_ICER_CLRENA_28,                0x10000000	    /* bit 28 */
        .equ	 NVIC_ICER_CLRENA_29,                0x20000000	    /* bit 29 */
        .equ	 NVIC_ICER_CLRENA_30,                0x40000000	    /* bit 30 */
        .equ	 NVIC_ICER_CLRENA_31,                0x80000000	    /* bit 31 */

/******************  Bit definition for NVIC_ISPR register  *******************/
        .equ	 NVIC_ISPR_SETPEND,                  0xFFFFFFFF	    /* Interrupt set-pending bits */
        .equ	 NVIC_ISPR_SETPEND_0,                0x00000001	    /* bit 0 */
        .equ	 NVIC_ISPR_SETPEND_1,                0x00000002	    /* bit 1 */
        .equ	 NVIC_ISPR_SETPEND_2,                0x00000004	    /* bit 2 */
        .equ	 NVIC_ISPR_SETPEND_3,                0x00000008	    /* bit 3 */
        .equ	 NVIC_ISPR_SETPEND_4,                0x00000010	    /* bit 4 */
        .equ	 NVIC_ISPR_SETPEND_5,                0x00000020	    /* bit 5 */
        .equ	 NVIC_ISPR_SETPEND_6,                0x00000040	    /* bit 6 */
        .equ	 NVIC_ISPR_SETPEND_7,                0x00000080	    /* bit 7 */
        .equ	 NVIC_ISPR_SETPEND_8,                0x00000100	    /* bit 8 */
        .equ	 NVIC_ISPR_SETPEND_9,                0x00000200	    /* bit 9 */
        .equ	 NVIC_ISPR_SETPEND_10,               0x00000400	    /* bit 10 */
        .equ	 NVIC_ISPR_SETPEND_11,               0x00000800	    /* bit 11 */
        .equ	 NVIC_ISPR_SETPEND_12,               0x00001000	    /* bit 12 */
        .equ	 NVIC_ISPR_SETPEND_13,               0x00002000	    /* bit 13 */
        .equ	 NVIC_ISPR_SETPEND_14,               0x00004000	    /* bit 14 */
        .equ	 NVIC_ISPR_SETPEND_15,               0x00008000	    /* bit 15 */
        .equ	 NVIC_ISPR_SETPEND_16,               0x00010000	    /* bit 16 */
        .equ	 NVIC_ISPR_SETPEND_17,               0x00020000	    /* bit 17 */
        .equ	 NVIC_ISPR_SETPEND_18,               0x00040000	    /* bit 18 */
        .equ	 NVIC_ISPR_SETPEND_19,               0x00080000	    /* bit 19 */
        .equ	 NVIC_ISPR_SETPEND_20,               0x00100000	    /* bit 20 */
        .equ	 NVIC_ISPR_SETPEND_21,               0x00200000	    /* bit 21 */
        .equ	 NVIC_ISPR_SETPEND_22,               0x00400000	    /* bit 22 */
        .equ	 NVIC_ISPR_SETPEND_23,               0x00800000	    /* bit 23 */
        .equ	 NVIC_ISPR_SETPEND_24,               0x01000000	    /* bit 24 */
        .equ	 NVIC_ISPR_SETPEND_25,               0x02000000	    /* bit 25 */
        .equ	 NVIC_ISPR_SETPEND_26,               0x04000000	    /* bit 26 */
        .equ	 NVIC_ISPR_SETPEND_27,               0x08000000	    /* bit 27 */
        .equ	 NVIC_ISPR_SETPEND_28,               0x10000000	    /* bit 28 */
        .equ	 NVIC_ISPR_SETPEND_29,               0x20000000	    /* bit 29 */
        .equ	 NVIC_ISPR_SETPEND_30,               0x40000000	    /* bit 30 */
        .equ	 NVIC_ISPR_SETPEND_31,               0x80000000	    /* bit 31 */

/******************  Bit definition for NVIC_ICPR register  *******************/
        .equ	 NVIC_ICPR_CLRPEND,                  0xFFFFFFFF	    /* Interrupt clear-pending bits */
        .equ	 NVIC_ICPR_CLRPEND_0,                0x00000001	    /* bit 0 */
        .equ	 NVIC_ICPR_CLRPEND_1,                0x00000002	    /* bit 1 */
        .equ	 NVIC_ICPR_CLRPEND_2,                0x00000004	    /* bit 2 */
        .equ	 NVIC_ICPR_CLRPEND_3,                0x00000008	    /* bit 3 */
        .equ	 NVIC_ICPR_CLRPEND_4,                0x00000010	    /* bit 4 */
        .equ	 NVIC_ICPR_CLRPEND_5,                0x00000020	    /* bit 5 */
        .equ	 NVIC_ICPR_CLRPEND_6,                0x00000040	    /* bit 6 */
        .equ	 NVIC_ICPR_CLRPEND_7,                0x00000080	    /* bit 7 */
        .equ	 NVIC_ICPR_CLRPEND_8,                0x00000100	    /* bit 8 */
        .equ	 NVIC_ICPR_CLRPEND_9,                0x00000200	    /* bit 9 */
        .equ	 NVIC_ICPR_CLRPEND_10,               0x00000400	    /* bit 10 */
        .equ	 NVIC_ICPR_CLRPEND_11,               0x00000800	    /* bit 11 */
        .equ	 NVIC_ICPR_CLRPEND_12,               0x00001000	    /* bit 12 */
        .equ	 NVIC_ICPR_CLRPEND_13,               0x00002000	    /* bit 13 */
        .equ	 NVIC_ICPR_CLRPEND_14,               0x00004000	    /* bit 14 */
        .equ	 NVIC_ICPR_CLRPEND_15,               0x00008000	    /* bit 15 */
        .equ	 NVIC_ICPR_CLRPEND_16,               0x00010000	    /* bit 16 */
        .equ	 NVIC_ICPR_CLRPEND_17,               0x00020000	    /* bit 17 */
        .equ	 NVIC_ICPR_CLRPEND_18,               0x00040000	    /* bit 18 */
        .equ	 NVIC_ICPR_CLRPEND_19,               0x00080000	    /* bit 19 */
        .equ	 NVIC_ICPR_CLRPEND_20,               0x00100000	    /* bit 20 */
        .equ	 NVIC_ICPR_CLRPEND_21,               0x00200000	    /* bit 21 */
        .equ	 NVIC_ICPR_CLRPEND_22,               0x00400000	    /* bit 22 */
        .equ	 NVIC_ICPR_CLRPEND_23,               0x00800000	    /* bit 23 */
        .equ	 NVIC_ICPR_CLRPEND_24,               0x01000000	    /* bit 24 */
        .equ	 NVIC_ICPR_CLRPEND_25,               0x02000000	    /* bit 25 */
        .equ	 NVIC_ICPR_CLRPEND_26,               0x04000000	    /* bit 26 */
        .equ	 NVIC_ICPR_CLRPEND_27,               0x08000000	    /* bit 27 */
        .equ	 NVIC_ICPR_CLRPEND_28,               0x10000000	    /* bit 28 */
        .equ	 NVIC_ICPR_CLRPEND_29,               0x20000000	    /* bit 29 */
        .equ	 NVIC_ICPR_CLRPEND_30,               0x40000000	    /* bit 30 */
        .equ	 NVIC_ICPR_CLRPEND_31,               0x80000000	    /* bit 31 */

/******************  Bit definition for NVIC_IABR register  *******************/
        .equ	 NVIC_IABR_ACTIVE,                   0xFFFFFFFF	    /* Interrupt active flags */
        .equ	 NVIC_IABR_ACTIVE_0,                 0x00000001	    /* bit 0 */
        .equ	 NVIC_IABR_ACTIVE_1,                 0x00000002	    /* bit 1 */
        .equ	 NVIC_IABR_ACTIVE_2,                 0x00000004	    /* bit 2 */
        .equ	 NVIC_IABR_ACTIVE_3,                 0x00000008	    /* bit 3 */
        .equ	 NVIC_IABR_ACTIVE_4,                 0x00000010	    /* bit 4 */
        .equ	 NVIC_IABR_ACTIVE_5,                 0x00000020	    /* bit 5 */
        .equ	 NVIC_IABR_ACTIVE_6,                 0x00000040	    /* bit 6 */
        .equ	 NVIC_IABR_ACTIVE_7,                 0x00000080	    /* bit 7 */
        .equ	 NVIC_IABR_ACTIVE_8,                 0x00000100	    /* bit 8 */
        .equ	 NVIC_IABR_ACTIVE_9,                 0x00000200	    /* bit 9 */
        .equ	 NVIC_IABR_ACTIVE_10,                0x00000400	    /* bit 10 */
        .equ	 NVIC_IABR_ACTIVE_11,                0x00000800	    /* bit 11 */
        .equ	 NVIC_IABR_ACTIVE_12,                0x00001000	    /* bit 12 */
        .equ	 NVIC_IABR_ACTIVE_13,                0x00002000	    /* bit 13 */
        .equ	 NVIC_IABR_ACTIVE_14,                0x00004000	    /* bit 14 */
        .equ	 NVIC_IABR_ACTIVE_15,                0x00008000	    /* bit 15 */
        .equ	 NVIC_IABR_ACTIVE_16,                0x00010000	    /* bit 16 */
        .equ	 NVIC_IABR_ACTIVE_17,                0x00020000	    /* bit 17 */
        .equ	 NVIC_IABR_ACTIVE_18,                0x00040000	    /* bit 18 */
        .equ	 NVIC_IABR_ACTIVE_19,                0x00080000	    /* bit 19 */
        .equ	 NVIC_IABR_ACTIVE_20,                0x00100000	    /* bit 20 */
        .equ	 NVIC_IABR_ACTIVE_21,                0x00200000	    /* bit 21 */
        .equ	 NVIC_IABR_ACTIVE_22,                0x00400000	    /* bit 22 */
        .equ	 NVIC_IABR_ACTIVE_23,                0x00800000	    /* bit 23 */
        .equ	 NVIC_IABR_ACTIVE_24,                0x01000000	    /* bit 24 */
        .equ	 NVIC_IABR_ACTIVE_25,                0x02000000	    /* bit 25 */
        .equ	 NVIC_IABR_ACTIVE_26,                0x04000000	    /* bit 26 */
        .equ	 NVIC_IABR_ACTIVE_27,                0x08000000	    /* bit 27 */
        .equ	 NVIC_IABR_ACTIVE_28,                0x10000000	    /* bit 28 */
        .equ	 NVIC_IABR_ACTIVE_29,                0x20000000	    /* bit 29 */
        .equ	 NVIC_IABR_ACTIVE_30,                0x40000000	    /* bit 30 */
        .equ	 NVIC_IABR_ACTIVE_31,                0x80000000	    /* bit 31 */

/******************  Bit definition for NVIC_PRI0 register  *******************/
        .equ	 NVIC_IPR0_PRI_0,                    0x000000FF	    /* Priority of interrupt 0 */
        .equ	 NVIC_IPR0_PRI_1,                    0x0000FF00	    /* Priority of interrupt 1 */
        .equ	 NVIC_IPR0_PRI_2,                    0x00FF0000	    /* Priority of interrupt 2 */
        .equ	 NVIC_IPR0_PRI_3,                    0xFF000000	    /* Priority of interrupt 3 */

/******************  Bit definition for NVIC_PRI1 register  *******************/
        .equ	 NVIC_IPR1_PRI_4,                    0x000000FF	    /* Priority of interrupt 4 */
        .equ	 NVIC_IPR1_PRI_5,                    0x0000FF00	    /* Priority of interrupt 5 */
        .equ	 NVIC_IPR1_PRI_6,                    0x00FF0000	    /* Priority of interrupt 6 */
        .equ	 NVIC_IPR1_PRI_7,                    0xFF000000	    /* Priority of interrupt 7 */

/******************  Bit definition for NVIC_PRI2 register  *******************/
        .equ	 NVIC_IPR2_PRI_8,                    0x000000FF	    /* Priority of interrupt 8 */
        .equ	 NVIC_IPR2_PRI_9,                    0x0000FF00	    /* Priority of interrupt 9 */
        .equ	 NVIC_IPR2_PRI_10,                   0x00FF0000	    /* Priority of interrupt 10 */
        .equ	 NVIC_IPR2_PRI_11,                   0xFF000000	    /* Priority of interrupt 11 */

/******************  Bit definition for NVIC_PRI3 register  *******************/
        .equ	 NVIC_IPR3_PRI_12,                   0x000000FF	    /* Priority of interrupt 12 */
        .equ	 NVIC_IPR3_PRI_13,                   0x0000FF00	    /* Priority of interrupt 13 */
        .equ	 NVIC_IPR3_PRI_14,                   0x00FF0000	    /* Priority of interrupt 14 */
        .equ	 NVIC_IPR3_PRI_15,                   0xFF000000	    /* Priority of interrupt 15 */

/******************  Bit definition for NVIC_PRI4 register  *******************/
        .equ	 NVIC_IPR4_PRI_16,                   0x000000FF	    /* Priority of interrupt 16 */
        .equ	 NVIC_IPR4_PRI_17,                   0x0000FF00	    /* Priority of interrupt 17 */
        .equ	 NVIC_IPR4_PRI_18,                   0x00FF0000	    /* Priority of interrupt 18 */
        .equ	 NVIC_IPR4_PRI_19,                   0xFF000000	    /* Priority of interrupt 19 */

/******************  Bit definition for NVIC_PRI5 register  *******************/
        .equ	 NVIC_IPR5_PRI_20,                   0x000000FF	    /* Priority of interrupt 20 */
        .equ	 NVIC_IPR5_PRI_21,                   0x0000FF00	    /* Priority of interrupt 21 */
        .equ	 NVIC_IPR5_PRI_22,                   0x00FF0000	    /* Priority of interrupt 22 */
        .equ	 NVIC_IPR5_PRI_23,                   0xFF000000	    /* Priority of interrupt 23 */

/******************  Bit definition for NVIC_PRI6 register  *******************/
        .equ	 NVIC_IPR6_PRI_24,                   0x000000FF	    /* Priority of interrupt 24 */
        .equ	 NVIC_IPR6_PRI_25,                   0x0000FF00	    /* Priority of interrupt 25 */
        .equ	 NVIC_IPR6_PRI_26,                   0x00FF0000	    /* Priority of interrupt 26 */
        .equ	 NVIC_IPR6_PRI_27,                   0xFF000000	    /* Priority of interrupt 27 */

/******************  Bit definition for NVIC_PRI7 register  *******************/
        .equ	 NVIC_IPR7_PRI_28,                   0x000000FF	    /* Priority of interrupt 28 */
        .equ	 NVIC_IPR7_PRI_29,                   0x0000FF00	    /* Priority of interrupt 29 */
        .equ	 NVIC_IPR7_PRI_30,                   0x00FF0000	    /* Priority of interrupt 30 */
        .equ	 NVIC_IPR7_PRI_31,                   0xFF000000	    /* Priority of interrupt 31 */

/******************  Bit definition for SCB_CPUID register  *******************/
        .equ	 SCB_CPUID_REVISION,                 0x0000000F	    /* Implementation defined revision number */
        .equ	 SCB_CPUID_PARTNO,                   0x0000FFF0	    /* Number of processor within family */
        .equ	 SCB_CPUID_Constant,                 0x000F0000	    /* Reads as 0x0F */
        .equ	 SCB_CPUID_VARIANT,                  0x00F00000	    /* Implementation defined variant number */
        .equ	 SCB_CPUID_IMPLEMENTER,              0xFF000000	    /* Implementer code. ARM is 0x41 */

/*******************  Bit definition for SCB_ICSR register  *******************/
        .equ	 SCB_ICSR_VECTACTIVE,                0x000001FF	    /* Active ISR number field */
        .equ	 SCB_ICSR_RETTOBASE,                 0x00000800	    /* All active exceptions minus the IPSR_current_exception yields the empty set */
        .equ	 SCB_ICSR_VECTPENDING,               0x003FF000	    /* Pending ISR number field */
        .equ	 SCB_ICSR_ISRPENDING,                0x00400000	    /* Interrupt pending flag */
        .equ	 SCB_ICSR_ISRPREEMPT,                0x00800000	    /* It indicates that a pending interrupt becomes active in the next running cycle */
        .equ	 SCB_ICSR_PENDSTCLR,                 0x02000000	    /* Clear pending SysTick bit */
        .equ	 SCB_ICSR_PENDSTSET,                 0x04000000	    /* Set pending SysTick bit */
        .equ	 SCB_ICSR_PENDSVCLR,                 0x08000000	    /* Clear pending pendSV bit */
        .equ	 SCB_ICSR_PENDSVSET,                 0x10000000	    /* Set pending pendSV bit */
        .equ	 SCB_ICSR_NMIPENDSET,                0x80000000	    /* Set pending NMI bit */

/*******************  Bit definition for SCB_VTOR register  *******************/
        .equ	 SCB_VTOR_TBLOFF,                    0x1FFFFF80	    /* Vector table base offset field */
        .equ	 SCB_VTOR_TBLBASE,                   0x20000000	    /* Table base in code(0) or RAM(1) */

/******************  Bit definition for SCB_AIRCR register  *******************/
        .equ	 SCB_AIRCR_VECTRESET,                0x00000001	    /* System Reset bit */
        .equ	 SCB_AIRCR_VECTCLRACTIVE,            0x00000002	    /* Clear active vector bit */
        .equ	 SCB_AIRCR_SYSRESETREQ,              0x00000004	    /* Requests chip control logic to generate a reset */

        .equ	 SCB_AIRCR_PRIGROUP,                 0x00000700	    /* PRIGROUP[2:0] bits (Priority group) */
        .equ	 SCB_AIRCR_PRIGROUP_0,               0x00000100	    /* Bit 0 */
        .equ	 SCB_AIRCR_PRIGROUP_1,               0x00000200	    /* Bit 1 */
        .equ	 SCB_AIRCR_PRIGROUP_2,               0x00000400	    /* Bit 2  */

/* prority group configuration */
        .equ	 SCB_AIRCR_PRIGROUP0,                0x00000000	    /* Priority group=0 (7 bits of pre-emption priority, 1 bit of subpriority) */
        .equ	 SCB_AIRCR_PRIGROUP1,                0x00000100	    /* Priority group=1 (6 bits of pre-emption priority, 2 bits of subpriority) */
        .equ	 SCB_AIRCR_PRIGROUP2,                0x00000200	    /* Priority group=2 (5 bits of pre-emption priority, 3 bits of subpriority) */
        .equ	 SCB_AIRCR_PRIGROUP3,                0x00000300	    /* Priority group=3 (4 bits of pre-emption priority, 4 bits of subpriority) */
        .equ	 SCB_AIRCR_PRIGROUP4,                0x00000400	    /* Priority group=4 (3 bits of pre-emption priority, 5 bits of subpriority) */
        .equ	 SCB_AIRCR_PRIGROUP5,                0x00000500	    /* Priority group=5 (2 bits of pre-emption priority, 6 bits of subpriority) */
        .equ	 SCB_AIRCR_PRIGROUP6,                0x00000600	    /* Priority group=6 (1 bit of pre-emption priority, 7 bits of subpriority) */
        .equ	 SCB_AIRCR_PRIGROUP7,                0x00000700	    /* Priority group=7 (no pre-emption priority, 8 bits of subpriority) */

        .equ	 SCB_AIRCR_ENDIANESS,                0x00008000	    /* Data endianness bit */
        .equ	 SCB_AIRCR_VECTKEY,                  0xFFFF0000	    /* Register key (VECTKEY) - Reads as 0xFA05 (VECTKEYSTAT) */

/*******************  Bit definition for SCB_SCR register  ********************/
        .equ	 SCB_SCR_SLEEPONEXIT,                0x02	    /* Sleep on exit bit */
        .equ	 SCB_SCR_SLEEPDEEP,                  0x04	    /* Sleep deep bit */
        .equ	 SCB_SCR_SEVONPEND,                  0x10	    /* Wake up from WFE */

/********************  Bit definition for SCB_CCR register  *******************/
        .equ	 SCB_CCR_NONBASETHRDENA,             0x0001	    /* Thread mode can be entered from any level in Handler mode by controlled return value */
        .equ	 SCB_CCR_USERSETMPEND,               0x0002	    /* Enables user code to write the Software Trigger Interrupt register to trigger (pend) a Main exception */
        .equ	 SCB_CCR_UNALIGN_TRP,                0x0008	    /* Trap for unaligned access */
        .equ	 SCB_CCR_DIV_0_TRP,                  0x0010	    /* Trap on Divide by 0 */
        .equ	 SCB_CCR_BFHFNMIGN,                  0x0100	    /* Handlers running at priority -1 and -2 */
        .equ	 SCB_CCR_STKALIGN,                   0x0200	    /* On exception entry, the SP used prior to the exception is adjusted to be 8-byte aligned */

/*******************  Bit definition for SCB_SHPR register ********************/
        .equ	 SCB_SHPR_PRI_N,                     0x000000FF	    /* Priority of system handler 4,8, and 12. Mem Manage, reserved and Debug Monitor */
        .equ	 SCB_SHPR_PRI_N1,                    0x0000FF00	    /* Priority of system handler 5,9, and 13. Bus Fault, reserved and reserved */
        .equ	 SCB_SHPR_PRI_N2,                    0x00FF0000	    /* Priority of system handler 6,10, and 14. Usage Fault, reserved and PendSV */
        .equ	 SCB_SHPR_PRI_N3,                    0xFF000000	    /* Priority of system handler 7,11, and 15. Reserved, SVCall and SysTick */

/******************  Bit definition for SCB_SHCSR register  *******************/
        .equ	 SCB_SHCSR_MEMFAULTACT,              0x00000001	    /* MemManage is active */
        .equ	 SCB_SHCSR_BUSFAULTACT,              0x00000002	    /* BusFault is active */
        .equ	 SCB_SHCSR_USGFAULTACT,              0x00000008	    /* UsageFault is active */
        .equ	 SCB_SHCSR_SVCALLACT,                0x00000080	    /* SVCall is active */
        .equ	 SCB_SHCSR_MONITORACT,               0x00000100	    /* Monitor is active */
        .equ	 SCB_SHCSR_PENDSVACT,                0x00000400	    /* PendSV is active */
        .equ	 SCB_SHCSR_SYSTICKACT,               0x00000800	    /* SysTick is active */
        .equ	 SCB_SHCSR_USGFAULTPENDED,           0x00001000	    /* Usage Fault is pended */
        .equ	 SCB_SHCSR_MEMFAULTPENDED,           0x00002000	    /* MemManage is pended */
        .equ	 SCB_SHCSR_BUSFAULTPENDED,           0x00004000	    /* Bus Fault is pended */
        .equ	 SCB_SHCSR_SVCALLPENDED,             0x00008000	    /* SVCall is pended */
        .equ	 SCB_SHCSR_MEMFAULTENA,              0x00010000	    /* MemManage enable */
        .equ	 SCB_SHCSR_BUSFAULTENA,              0x00020000	    /* Bus Fault enable */
        .equ	 SCB_SHCSR_USGFAULTENA,              0x00040000	    /* UsageFault enable */

/*******************  Bit definition for SCB_CFSR register  *******************/
/* MFSR */
        .equ	 SCB_CFSR_IACCVIOL,                  0x00000001	    /* Instruction access violation */
        .equ	 SCB_CFSR_DACCVIOL,                  0x00000002	    /* Data access violation */
        .equ	 SCB_CFSR_MUNSTKERR,                 0x00000008	    /* Unstacking error */
        .equ	 SCB_CFSR_MSTKERR,                   0x00000010	    /* Stacking error */
        .equ	 SCB_CFSR_MMARVALID,                 0x00000080	    /* Memory Manage Address Register address valid flag */
/* BFSR */
        .equ	 SCB_CFSR_IBUSERR,                   0x00000100	    /* Instruction bus error flag */
        .equ	 SCB_CFSR_PRECISERR,                 0x00000200	    /* Precise data bus error */
        .equ	 SCB_CFSR_IMPRECISERR,               0x00000400	    /* Imprecise data bus error */
        .equ	 SCB_CFSR_UNSTKERR,                  0x00000800	    /* Unstacking error */
        .equ	 SCB_CFSR_STKERR,                    0x00001000	    /* Stacking error */
        .equ	 SCB_CFSR_BFARVALID,                 0x00008000	    /* Bus Fault Address Register address valid flag */
/* UFSR */
        .equ	 SCB_CFSR_UNDEFINSTR,                0x00010000	    /* The processor attempt to excecute an undefined instruction */
        .equ	 SCB_CFSR_INVSTATE,                  0x00020000	    /* Invalid combination of EPSR and instruction */
        .equ	 SCB_CFSR_INVPC,                     0x00040000	    /* Attempt to load EXC_RETURN into pc illegally */
        .equ	 SCB_CFSR_NOCP,                      0x00080000	    /* Attempt to use a coprocessor instruction */
        .equ	 SCB_CFSR_UNALIGNED,                 0x01000000	    /* Fault occurs when there is an attempt to make an unaligned memory access */
        .equ	 SCB_CFSR_DIVBYZERO,                 0x02000000	    /* Fault occurs when SDIV or DIV instruction is used with a divisor of 0 */

/*******************  Bit definition for SCB_HFSR register  *******************/
        .equ	 SCB_HFSR_VECTTBL,                   0x00000002	    /* Fault occures because of vector table read on exception processing */
        .equ	 SCB_HFSR_FORCED,                    0x40000000	    /* Hard Fault activated when a configurable Fault was received and cannot activate */
        .equ	 SCB_HFSR_DEBUGEVT,                  0x80000000	    /* Fault related to debug */

/*******************  Bit definition for SCB_DFSR register  *******************/
        .equ	 SCB_DFSR_HALTED,                    0x01	    /* Halt request flag */
        .equ	 SCB_DFSR_BKPT,                      0x02	    /* BKPT flag */
        .equ	 SCB_DFSR_DWTTRAP,                   0x04	    /* Data Watchpoint and Trace (DWT) flag */
        .equ	 SCB_DFSR_VCATCH,                    0x08	    /* Vector catch flag */
        .equ	 SCB_DFSR_EXTERNAL,                  0x10	    /* External debug request flag */

/*******************  Bit definition for SCB_MMFAR register  ******************/
        .equ	 SCB_MMFAR_ADDRESS,                  0xFFFFFFFF	    /* Mem Manage fault address field */

/*******************  Bit definition for SCB_BFAR register  *******************/
        .equ	 SCB_BFAR_ADDRESS,                   0xFFFFFFFF	    /* Bus fault address field */

/*******************  Bit definition for SCB_afsr register  *******************/
        .equ	 SCB_AFSR_IMPDEF,                    0xFFFFFFFF	    /* Implementation defined */


.if 0	/* Not tested/used */
        .ifdef USE_STDPERIPH_DRIVER
          .include "stm32l1xx_conf.h"
        .endif
        .equ	SET_BIT(REG, BIT),    ((REG) |= (BIT))
        .equ	CLEAR_BIT(REG, BIT),  ((REG) &= ~(BIT))
        .equ	READ_BIT(REG, BIT),   ((REG) & (BIT))
        .equ	CLEAR_REG(REG),       ((REG) = (0x0))
        .equ	WRITE_REG(REG, VAL),  ((REG) = (VAL))
        .equ	READ_REG(REG),        ((REG))
        .equ	MODIFY_REG(REG, CLEARMASK, SETMASK)  WRITE_REG((REG), (((READ_REG(REG)) & (~(CLEARMASK))) | (SETMASK)))
.endif	// if 0


.endif	/* STM32L1XX_MD_S */

